#!/usr/bin/python

"""
################################################################################
#                                                                              #
# deep throat                                                                  #
#                                                                              #
################################################################################
#                                                                              #
# LICENCE INFORMATION                                                          #
#                                                                              #
# This is a speech program.                                                    #
#                                                                              #
# copyright (C) 2016 William Breaden Madden (named by Liam Moore)              #
#                                                                              #
# This software is released under the terms of the GNU General Public License  #
# version 3 (GPLv3).                                                           #
#                                                                              #
# This program is free software: you can redistribute it and/or modify it      #
# under the terms of the GNU General Public License as published by the Free   #
# Software Foundation, either version 3 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# This program is distributed in the hope that it will be useful, but WITHOUT  #
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        #
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for     #
# more details.                                                                #
#                                                                              #
# For a copy of the GNU General Public License, see                            #
# <http://www.gnu.org/licenses/>.                                              #
#                                                                              #
################################################################################

usage:
    program [options]

options:
    -h, --help               display help message
    --version                display version and exit
    -v, --verbose            verbose logging

    --interactive            interactive mode
    --text=TEXT              text to speak
    --phonemes=TEXT          phonemes to speak
    --phonemesout            translate text to phonemes and display them
    --datetime               read date and time
    --datetimeloop           read date and time in a loop
    --time                   read time
    --timeloop               read time in a loop

    --infile=FILENAME        input text filename
    --outfile=FILENAME       output sound filename [default: deep_throat.wav]
    --savetowavefile         save to WAVE file
    --translatenumbers=BOOL  translate numbers to English text [default: true]

    --analysisvisual         visual analysis
    --analysissound          sound analysis
"""

from __future__ import division

import docopt
import math
import os
import re
import struct
import sys
import time
import wave

import datavision
import matplotlib
import matplotlib.pyplot
import numpy
import propyte
import pyaudio
import pyprel
import shijian
import scipy.interpolate

name    = "deep throat"
version = "2017-01-16T1628Z"
logo    = None

def main(options):

    filename_input         = options["--infile"]
    filename_output        = options["--outfile"]
    text_read              = options["--text"]
    phonemes_read          = options["--phonemes"]
    mode_interactive       = options["--interactive"]
    mode_phonemes_output   = options["--phonemesout"]
    mode_datetime          = options["--datetime"]
    mode_datetimeloop      = options["--datetimeloop"]
    mode_time              = options["--time"]
    mode_timeloop          = options["--timeloop"]
    mode_file_output       = options["--savetowavefile"]
    mode_translate_numbers = options["--translatenumbers"].lower() == "true"
    mode_analysis_visual   = options["--analysisvisual"]
    mode_analysis_sound    = options["--analysissound"]
    global verbose
    verbose                = options["--verbose"]

    if text_read is not None and mode_phonemes_output is not True:
        if verbose:
            print("\nmode: say text")
        say(
            text              = text_read,
            save_to_file      = mode_file_output,
            filename_output   = filename_output,
            explain           = verbose,
            translate_numbers = mode_translate_numbers
        )

    elif text_read is None and phonemes_read is not None:
        if verbose:
            print("\nmode: say phonemes")
        say(
            phonemes        = phonemes_read,
            save_to_file    = mode_file_output,
            filename_output = filename_output,
            explain         = verbose
        )

    elif mode_interactive:
        if verbose:
            print("\nmode: interactive")
        logo = pyprel.render_banner(
            text = name.upper()
        )
        pyprel.print_line()
        print(pyprel.center_string(text = logo))
        pyprel.print_line()
        print("Ctrl c to exit")
        while True:
            try:
                text = propyte.get_input(prompt = ">")
                say(
                    text            = text,
                    save_to_file    = mode_file_output,
                    filename_output = filename_output,
                    explain         = verbose
                )
            except KeyboardInterrupt:
                sys.exit(1)

    elif mode_phonemes_output:
        if verbose:
            print("\nmode: phonemes output")
        if text_read is not None:
            text = text_read
        elif not sys.stdin.isatty():
            input_stream = sys.stdin
            input_stream_list = [line for line in input_stream]
            text = " ".join(input_stream_list)
        else:
            print("no input text specified")
            exit()
        _phonemes = text_to_phonemes(
            text    = text,
            explain = verbose
        )
        print(_phonemes)

    elif filename_input is not None:
        if verbose:
            print("\nmode: say file")
        if os.path.isfile(filename_input):
            file_input = open(filename_input)
            say(
                text            = file_input.read(),
                save_to_file    = mode_file_output,
                filename_output = filename_output,
                explain         = verbose
            )
            file_input.close()

        else:
            print("file {filename} not found".format(
                filename = filename_input
            ))

    elif mode_datetime:
        if verbose:
            print("\nmode: say date and time")
        text = shijian.time_UTC(
            style = "HH hours MM minutes SS sounds day DD month YYYY"
        )
        print(text)
        say(
            text            = text,
            save_to_file    = mode_file_output,
            filename_output = filename_output,
            explain         = verbose
        )

    elif mode_datetimeloop:
        if verbose:
            print("\nmode: say date and time in loop")
        while True:
            text = shijian.time_UTC(
                style = "HH hours MM minutes SS sounds day DD month YYYY"
            )
            print(text)
            say(
                text            = text,
                save_to_file    = mode_file_output,
                filename_output = filename_output,
                explain         = verbose
            )
            time.sleep(10)

    elif mode_time:
        if verbose:
            print("\nmode: say time in loop")
        text = shijian.time_UTC(
            style = "HH hours MM minutes SS seconds"
        )
        print(text)
        say(
            text            = text,
            save_to_file    = mode_file_output,
            filename_output = filename_output,
            explain         = verbose
        )

    elif mode_timeloop:
        if verbose:
            print("\nmode: say time in loop")
        while True:
            text = shijian.time_UTC(
                style = "HH hours MM minutes SS seconds"
            )
            print(text)
            say(
                text            = text,
                save_to_file    = mode_file_output,
                filename_output = filename_output,
                explain         = verbose
            )
            time.sleep(10)

    elif not sys.stdin.isatty():
        if verbose:
            print("\nmode: say pipe text")
        input_stream = sys.stdin
        input_stream_list = [line for line in input_stream]
        say(
            text            = " ".join(input_stream_list),
            save_to_file    = mode_file_output,
            filename_output = filename_output,
            explain         = verbose
        )

    elif mode_analysis_visual:
        if verbose:
            print("\nmode: analysis visual")
        analysis(
            visual = True,
            sound  = False
        )

    elif mode_analysis_sound:
        if verbose:
            print("\nmode: analysis sound")
        analysis(
            visual = False,
            sound  = True
        )

    else:
        if verbose:
            print("\nmode: no operations specified")
        logo = pyprel.render_banner(
            text = name.upper()
        )
        pyprel.print_line()
        print(pyprel.center_string(text = logo))
        pyprel.print_line()
        print("no operations specified")
        print(__doc__)

################################################################################
#                                                                              #
# text-to-phonemes rules                                                       #
#                                                                              #
################################################################################

rules_English_to_phonemes_special_symbols = {
    "#": r"[AEIOUY]+",               # one or more vowels
    ".": r"[BVDGJLMNRWZ]",           # a voiced consonant;
                                     # one of (B, V, D, G, J, L, M, N, R, W, Z)
    "%": r"(?:ER|E|ES|ED|ING|EL)",   # a suffix
    "&": r"(?:[SCGZXJ]|CH|SH)",      # a sibilant
    "@": r"(?:[TSRDLZNJ]|TH|CH|SH)", # a consonant influencing the sound of a
                                     # following long u
    "^": r"[BCDFGHJKLMNPQRSTVWXZ]",  # a single consonant
    "+": r"[EIY]",                   # a front vowel; one of (E, I, Y)
    ":": r"[BCDFGHJKLMNPQRSTVWXZ]*", # zero or more consonants
}

# Rules are defined in strings in a form easy for humans to read and write.
# Rules have the form A/B/C/D. The character string occurring with left context
# A and right context C gets the pronunciation D.
rules_English_to_phonemes = [
    #" /// "
    "A// /UH",
    "ARE/ / /AH-R",
    "AR/ /O/UH-R",
    "AR//#/EH-R",
    "AS/ ^/#/AE-A-S",
    "A//WA/UH",
    "AW///AW",
    "ANY/ ://EH-N-EE",
    "A//^+#/AE-A",
    "ALLY/#://UH-L-EE",
    "AL/ /#/UH-L",
    "AGAIN///UH-G-EH-N",
    "AG/#:/E/IH-J",
    "A//^+:#/AE",
    "A/ :/^+/AE-A",
    "ARR/ //UH-R",
    "ARR///AE-R",
    "AR/ ://AH-R",
    "AR// /AE-R",
    "AR///AH-R",
    "AIR///EH-R",
    "AI///AE-A",
    "AY///AE-A",
    "AU///AW",
    "AL/#:/ /UH-L",
    "ALS/#:/ /UH-L-Z",
    "ALK///AW-K",
    "AL//^/AW-L",
    "ABLE/ ://AE-A-B-UH-L",
    "ABLE///UH-B-UH-L",
    "ANG//+/AE-A-N-J",
    "ATHE/ C/ /AE-TH-EE",
    "A//A/AH",
    "A///AE",
    "BE/ /^#/B-IH",
    "BEING///B-EE-IH-N",
    "BOTH/ / /B-OH-TH",
    "BUS/ /#/B-IH-Z",
    "BUIL///B-IH-L",
    "B/ / /B-EE",
    "B///B",
    "CH/ /^/K",
    "CH/^E//K",
    "CH///CH",
    "CI/ S/#/S-AH-EE",
    "CI//A/SH",
    "CI//O/SH",
    "CI//EN/SH",
    "C//+/S",
    "CK///K",
    "COM//%/K-AH-M",
    "C/ / /S-EE",
    "C///K",
    "DED/#:/ /D-IH-D",
    "D/.E/ /D",
    "D/#^:E/ /T",
    "DE/ /^#/D-IH",
    "DO/ / /D-OO",
    "DOES/ //D-UH-Z",
    "DOING/ //D-OO-IH-N",
    "DOW/ //D-OH",
    "DU//A/J-OO",
    "D/ / /D-EE",
    "DOUGH///D-OH",
    "D///D",
    "E/#:/ /",
    "E/'^:/ /",
    "E/ :/ /EE",
    "ED/#/ /D",
    "E/#:/D /",
    "ER//EV/EH-V",
    "EVEN/ EL//EH-V-EH-N",
    "EVEN/ S//EH-V-EH-N",
    "E//^%/EE",
    "E//PH%/EE",
    "ERI//#/EE-R-EE",
    "ER/#:/#/AE-R",
    "ER//#/EH-R",
    "ER///AE-R",
    "EVEN/ //EE-V-EH-N",
    "E/#:/W/",
    "EW/@//OO",
    "EW///Y-OO",
    "E//O/EE",
    "ES/#:&/ /IH-Z",
    "E/#:/S /",
    "ELY/#://L-EE",
    "EMENT/#://M-EH-N-T",
    "EFUL///F-U-L",
    "EE///EE",
    "EARN///AE-R-N",
    "EAR/ /^/AE-R",
    "EAD///EH-D",
    "EA/#:/ /EE-UH",
    "EA//SU/EH",
    "EA///EE",
    "EIGH///AE-A",
    "EI///EE",
    "EYE/ //AH-EE",
    "EY///EE",
    "EU///Y-OO",
    "E/ / /EE",
    "E/^/ /",
    "E///EH",
    "FUL///F-U-L",
    "F/F//",
    "F/ / /EH-F",
    "F///F",
    "GIV///G-IH-V",
    "G/ /I^/G",
    "GE//T/G-EH",
    "GGES/SU//G-J-EH-SS",
    "G/G//",
    "G/ B#//G",
    "G//+/J",
    "GREAT///G-R-AE-A-T",
    "GH/#//",
    "G/ / /G-EE",
    "G///G",
    "HAV/ //H-AE-V",
    "HERE/ //H-EE-R",
    "HOUR/ //OH-AE-R",
    "HOW///H-OH",
    "H//#/H",
    "H/ / /H-AE-CH",
    "H///",
    "IN/ //IH-N",
    "I/ / /AH-EE",
    "IN//D/IH-N",
    "IER///EE-AE-R",
    "IED/#:R//EE-D",
    "IED// /AH-EE-D",
    "IEN///EE-EH-N",
    "IE//T/AH-EE-EH",
    "I/ :/%/AH-EE",
    "I//%/EE",
    "IE///EE",
    "INE/N//AH-EE-N",
    "IME/T//AH-EE-M",
    "I//^+:#/IH",
    "IR//#/AH-EE-R",
    "IS//%/AH-EE-S",
    "IX//%/IH-K-S",
    "IZ//%/AH-EE-Z",
    "I//D%/AH-EE",
    "I/+^/^+/IH",
    "I//T%/AH-EE",
    "I/#^:/^+/IH",
    "I//^+/AH-EE",
    "IR///AE-R",
    "IGH///AH-EE",
    "ILD///AH-EE-L-D",
    "IGN// /AH-EE-N",
    "IGN//^/AH-EE-N",
    "IGN//%/AH-EE-N",
    "IQUE///EE-K",
    "I///IH",
    "J/ / /J-A-EE",
    "J///J",
    "K//N/",
    "K/ / /K-A-EE",
    "K///K",
    "LO//C#/L-OH",
    "L/L//",
    "L/#^:/%/UH-L",
    "LEAD///L-EE-D",
    "L/ / /AE-L",
    "L///L",
    "MOV///M-OO-V",
    "M/ / /EH-M",
    "M///M",
    "NG/E/+/N-J",
    "NG//R/N",
    "NG//#/N",
    "NGL//%/N-UH-L",
    "NG///N",
    "NK///N-K",
    "NOW/ / /N-OH",
    "N/ / /EH-N",
    "N/N//",
    "N///N",
    "OF// /UH-V",
    "OROUGH///AE-R-OH",
    "OR/ F/TY/OH-R",
    "OR/#:/ /AE-R",
    "ORS/#:/ /AE-R-Z",
    "OR///AW-R",
    "ONE/ //W-UH-N",
    "OW//EL/OH",
    "OW///OH",
    "OVER/ //OH-V-AE-R",
    "OV///UH-V",
    "O//^%/OH",
    "O//^EN/OH",
    "O//^I#/OH",
    "OL//D/OH-L",
    "OUGHT///AH-T",
    "OUGH///UH-F",
    "OU/ /^L/UH",
    "OU/ //OH",
    "OU/H/S#/OH",
    "OUS///UH-S",
    "OUR/ F//OH-R",
    "OUR///AW-R",
    "OUD///U-D",
    "OUP///OO-P",
    "OU///OH",
    "OY///AW-EE",
    "OING///OH-IH-N",
    "OI///AW-EE",
    "OOR///OH-R",
    "OOK///U-K",
    "OOD///U-D",
    "OO///OO",
    "O//E/OH",
    "O// /OH",
    "OA// /OH",
    "ONLY/ //OH-N-L-EE",
    "ONCE/ //W-UH-N-S",
    "ON'T// /OH-N-T",
    "O/C/N/AH",
    "O//NG/AH",
    "O/^:/N/UH",
    "ON/I//UH-N",
    "ON/#:/ /UH-N",
    "ON/#^//UH-N",
    "O//ST /OH",
    "OF//^/AW-F",
    "OTHER///UH-TH-AE-R",
    "OSS// /AW-S",
    "OM/#^:/ /UH-M",
    "O///AH",
    "PH///F",
    "PEOP///P-EE-P",
    "POW///P-OH",
    "PUT// /P-U-T",
    "P/ / /P-EE",
    "P/P//",
    "P///P",
    "QUAR///K-W-AW-R",
    "QU/ //K-W",
    "QU///K",
    "Q/ / /K-OO",
    "Q///K",
    "RE/ /^#/R-EE",
    "R/ / /AH",
    "R/R//",
    "R///R",
    "SH///SH",
    "SION/#//ZH-UH-N",
    "SOME///S-AH-M",
    "SUR/#/#/ZH-AE-R",
    "SUR//#/SH-AE-R",
    "SU/#/#/ZH-OO",
    "SSU/#/#/SH-OO",
    "SED/#/ /Z-D",
    "S/#/#/Z",
    "SAID///S-EH-D",
    "SION/^//SH-UH-N",
    "S/S//",
    "S/./ /Z",
    "S/#:.E/ /Z",
    "S/#^:##/ /Z",
    "S/#^:#/ /S",
    "S/U/ /S",
    "S/ :#/ /Z",
    "SCH/ //S-K",
    "S//C+/",
    "SM/#//Z-M",
    "SN/#/ /Z-UH-N",
    "S/ / /EH-S",
    "S///S",
    "THE/ / /TH-UH",
    "TO// /T-OO",
    "THAT///TH-AE-T",
    "THIS/ / /TH-IH-S",
    "THEY/ //TH-AE-A",
    "THERE/ //TH-EH-R",
    "THER///TH-AE-R",
    "THEIR///TH-EH-EH",
    "THAN/ / /TH-AE-N",
    "THEM/ / /TH-EH-M",
    "THESE// /TH-EE-Z",
    "THEN/ //TH-EH-N",
    "THROUGH///TH-R-OO",
    "THOSE///TH-OH-Z",
    "THOUGH// /TH-OH",
    "THUS/ //TH-UH-S",
    "TH///TH",
    "TED/#:/ /T-IH-D",
    "TI/S/#N/CH",
    "TI//O/SH",
    "TI//A/T",
    "TIEN///SH-UH-N",
    "TUR//#/CH-AE-R",
    "TU//A/CH-OO",
    "TWO/ //T-OO",
    "T/ / /T-EE",
    "T/T//",
    "T///T",
    "UN/ /I/Y-OO-N",
    "UN/ //UH-N",
    "UPON/ //UH-P-AW-N",
    "UR/@/#/AE-R",
    "UR//#/Y-AE-R",
    "UR///AE-R",
    "U//^ /UH",
    "U//^^/UH",
    "UY///AH-EE",
    "U/ G/#/",
    "U/G/%/",
    "U/G/#/W",
    "U/#N//Y-OO",
    "UI/@//OO",
    "U/@//UH",
    "U///Y-OO",
    "VIEW///V-Y-OO",
    "V/ / /V-EE",
    "V///V",
    "WHERE/ //W-AE-R",
    "WA//S/W-AH",
    "WA//T/W-AH",
    "WHERE///WH-EH-R",
    "WHAT///WH-AH-T",
    "WHOL///H-OH-L",
    "WHO///H-OO",
    "WH///WH",
    "WAR///W-AH-R",
    "WOR///W-AE-R",
    "WR///R",
    "W/ / /D-AH-B-L-Y-OO",
    "W///W",
    "X//^/EH-K-S",
    "X/ / /EH-K-S",
    "X/ /#/Z-EH",
    "X///K-S",
    "YOUNG///Y-UH-N",
    "YOU/ //Y-OO",
    "YES/ //Y-EH-S",
    "Y/ / /WH-UH-Y",
    "Y/ //Y",
    "Y/#^:/ /EE",
    "Y/#^:/I/EE",
    "Y/ :/ /AH-EE",
    "Y/ :/#/AH-EE",
    "Y/ :/^+:#/IH",
    "Y/ :/^#/AH-EE",
    "Y///IH",
    "ZZ///T-Z",
    "Z/ / /Z-EH-D",
    "Z///Z",
    # numbers
    "0/ //Z-EE-R-OH",
    "1/ //W-UH-N",
    "2/ //T-OO",
    "3/ //TH-R-EE",
    "4/ //F-OH-R",
    "5/ //F-I-V",
    "6/ //S-IH-K-S",
    "7/ //S-EH-V-EH-N",
    "8/ //A-A-T",
    "9/ //N-I-N",
    "10/ //T-EH-N",
    "11/ //EH-L-EH-V-UH-N",
    "12/ //T-W-EH-L-V",
    "13/ //TH-IH-R-T-EE-N",
    "14/ //F-OH-R-T-EE-N",
    "15/ //F-IH-F-T-EE-N",
    "16/ //S-IH-K-S-T-EE-N",
    "17/ //S-EH-V-EH-N-T-EE-N",
    "18/ //A-A-T-EE-N",
    "19/ //N-I-N-T-EE-N",
    "20/ //T-W-EH-N-T-EE",
    "30/ //TH-U-R-T-EE",
    "40/ //F-OH-R-T-EE",
    "50/ //F-IH-F-T-EE",
    "60/ //S-IH-K-S-T-EE",
    "70/ //S-EH-V-EH-N-T-EE",
    "80/ //A-T-EE",
    "90/ //N-IH-N-T-EE",
    "HUNDRED/ // H-UH-N-D-R-EH-D",
    "THOUSAND/ //TH-AH-U-S-EH-N-D",
    "MILLION/ //M-IH-L-Y-UH-N",
    # ordinal numbers
    "FIRST/ //F-U-R-S-T",
    "SECOND/ //S-EH-K-U-N-D",
    "THIRD/ //TH-U-R-D ",
    "FOURTH/ //F-OH-R-TH",
    "FIFTH/ //F-IH-F-TH",
    "SIXTH/ //S-IH-K-S-TH",
    "SEVENTH/ //S-EH-V-EH-N-Th",
    "EIGHTH/ //A-A-T-TH",
    "NINTH/ //N-I-N-TH",
    "TENTH/ //T-EH-N-TH",
    # letters
    "A/ //A-EE",
    "B/ //B-EE",
    "C/ //S-EE",
    "D/ //D-EE",
    "E/ //EE-EE",
    "F/ //EH-F",
    "G/ //J-EE",
    "H/ //A-CH",
    "I/ //I",
    "J/ //J-A",
    "K/ //K-A",
    "L/ //EH-L",
    "M/ //EH-M",
    "N/ //EH-N",
    "O/ //OH-W",
    "P/ //P-EE",
    "Q/ //K-Y-OO",
    "R/ //AH-R",
    "S/ //EH-S",
    "T/ //T-EE",
    "U/ //Y-OO",
    "V/ //V-EE",
    "W/ //D-UH-B-L-Y-OO",
    "X/ //EH-K-S",
    "Y/ //W-I",
    "Z/ //Z-EE",
    # words
    "A/ //UH",
    "ABILITY/ //AE-B-IH-L-IH-T-EE",
    "ABOARD/ //UH-B-OH-R-D",
    "ABORT/ //UH-B-OH-R-T",
    "AFFIRMATIVE/ //AH-F-EH-R-M-AH-T-IH-V",
    "ALL/ //AW-L",
    "ALTER/ //AH-L-T-R",
    "AN/ //AE-N",
    "AND/ //AE-N-D",
    "ANDY/ //AE-N-D-EE",
    "ANY/ //EH-N-EE",
    "ANYBODY/ //AE-N-EE-B-AH-D-EE",
    "AT/ //AE-T",
    "ATTACKED/ //UH-T-AE-K-T",
    "BACKUP/ //B-AH-K-UH-P",
    "BASIC/ //B-A-S-IH-K",
    "BAUD/ //B-AW-D",
    "BE/ //B-EE",
    "BEGIN/ //B-EE-G-IH-N",
    "BOOT/ //B-OO-T",
    "BOSS/ //B-OH-S",
    "BREAK/ //B-R-A-K",
    "BUG/ //B-UH-G",
    "BY/ //B-I",
    "CALL/ //K-AW-L",
    "CALLING/ //K-AW-L-IH-N-G",
    "CAPABLE/ //K-A-P-UH-B-UH-L",
    "CHARLIE/ //CH-AH-R-L-EE",
    "CITY/ //S-IH-T-EE",
    "COLD/ //K-OH-L-D",
    "COMBINATIONS/ //K-AH-M-B-IH-N-A-SH-UH-N-S",
    "COMES/ //K-UH-M-S",
    "COMMAND/ //K-UH-M-AH-N-D",
    "COMPUTER/ //K-AH-M-P-Y-OO-T-OH-R",
    "CONSIDER/ //K-UH-N-S-IH-D-R",
    "CONTINUE/ //K-UH-N-T-IH-N-Y-OO",
    "COPYRIGHT/ //K-AH-P-EE-R-I-T",
    "CRASH/ //K-R-AH-SH",
    "CREATE/ //K-R-EE-A-T",
    "DANCING/ //D-AE-N-S-IH-N-G",
    "DECEMBER/ //D-EE-S-EH-M-B-UH-R",
    "DIFFERENT/ //D-IH-F-UH-R-EH-N-T",
    "DISK/ //D-IH-S-K",
    "DOG/ //D-AW-G",
    "DOG/ //D-OH-G",
    "DOING/ //D-OO-IH-N-G",
    "DONE/ //D-UH-N",
    "DOS/ //d-aw-s",
    "DOWN/ //D-AH-W-N",
    "DRIVE/ //D-R-AE-V",
    "EATING/ //EE-T-IH-N-G",
    "EMERGENCY/ //EE-M-R-J-EH-N-S-EE",
    "ENTER/ //EH-N-T-R",
    "ERROR/ //EH-R-UH-R",
    "ESCAPE/ //EH-S-K-A-P",
    "EXIT/ //EH-K-S-IH-T",
    "FALLS/ //F-AH-L-L-S",
    "FAST/ //F-AH-S-T",
    "FATAL/ //F-A-T-L",
    "FAULT/ //F-AW-L-T",
    "FIXED/ //F-IH-K-S-T",
    "FLOPPY/ //F-L-OH-P-EE",
    "FOLLOWING/ //F-AH-L-OH-W-IH-N-G",
    "FORAY/ //F-OH-R-A-EE",
    "GENTLY/ //J-EH-N-T-L-EE",
    "GIVES/ //G-IH-V-S",
    "HARD/ //H-AW-R-D",
    "HAS/ //H-AE-S",
    "HELLO/ //H-EH-L-OH-W",
    "HENDERSON/ //H-EH-N-D-R-S-UH-N",
    "HERE/ //H-EE-R",
    "HIM/ //H-IH-M",
    "HIS/ //H-IH-S",
    "HIT/ //H-IH-T",
    "HOT/ //H-AH-T",
    "HOW/ //H-AW-W",
    "HUNDRED/ //H-UH-N-D-R-EH-D",
    "IGNORE/ //IH-G-N-OH-R",
    "IN/ //IH-N",
    "INFORMATION/ //IH-N-F-AW-R-M-EY-SH-UH-N",
    "INSERT/ //IH-N-S-UH-R-T",
    "INTERFACE/ //IH-N-T-R-F-AH-Y-S",
    "IS/ //IH-Z",
    "IT/ //IH-T",
    "JUST/ //J-UH-S-T",
    "KEY/ //K-EE",
    "KILLER/ //K-IH-L-R",
    "KLUDGE/ //K-L-OO-D-ZH",
    "LIKE/ //L-I-K",
    "LIMITLESS/ //L-IH-M-IH-T-L-EH-S-S",
    "LOOK/ //L-U-K",
    "MAIL/ //M-A-UH-L",
    "MAN/ //M-AE-N",
    "MCGUIRE/ //M-IH-KG-W-I-R",
    "MEMORY/ //M-EH-M-OH-R-EE",
    "MISS/ //M-IH-S",
    "MODEM/ //M-OH-D-IH-M",
    "MOON/ //M-OO-N",
    "MUCH/ //M-UH-CH",
    "MY/ //M-I",
    "NAME/ //N-A-M",
    "NO/ //N-OH",
    "OF/ //UH-F",
    "ON/ //AH-N",
    "OR/ //AW-R",
    "OUT/ //AH-W-T",
    "OUT/ //AW-T",
    "OUTSIDE/ //AW-T-S-AH-Y-D",
    "PARALLEL/ //P-AH-R-UH-L-EH-L",
    "PHONE/ //F-OH-N",
    "PHONEME/ //F-OH-N-EH-M",
    "PHONEMES/ //F-OH-N-EH-M-S",
    "PLAIN/ //P-L-A-IH-N",
    "PORT/ //P-OH-R-T",
    "PRESS/ //P-R-EH-S",
    "PRINTER/ //P-R-IH-N-T-R",
    "PROGRAM/ //P-R-OH-G-R-AE-M",
    "RAIN/ //R-A-IH-N",
    "RAM/ //R-AH-M",
    "READY/ //R-EH-D-EE",
    "RECOVER/ //R-EE-K-UH-V-R",
    "REMOTE/ //R-EH-M-OH-T",
    "REMOVE/ //R-EE-M-U-V",
    "REPLACE/ //R-EE-P-L-A-S",
    "REPRODUCING/ //R-EE-P-R-OH-D-OO-S-IH-N-G",
    "RESERVED/ //R-EE-S-U-R-V-D",
    "RESTORE/ //R-EE-S-T-OH-R",
    "RETRY/ //R-EE-T-R-I",
    "RIGHTS/ //R-I-T-S",
    "SEADOG/ //S-EE-D-OH-G",
    "SECOND/ //S-EH-K-UH-N-D",
    "SEE/ //S-EE",
    "SEEN/ //S-EE-N",
    "SENTENCE/ //S-EH-N-T-EH-N-S",
    "SERIAL/ //S-IH-R-EE-AH-L",
    "SERVICE/ //S-UH-R-V-EH-S",
    "SEX/ //S-EH-K-S",
    "SHALL/ //SH-AH-L",
    "SHITFACED/ //S-H-IH-T-F-A-S-D",
    "SIDE/ //S-AH-Y-D",
    "SLOW/ //S-L-OH-W",
    "SOMETHING/ //S-UH-M-TH-IH-N-G",
    "SOUND/ //S-AH-W-N-D",
    "SPAIN/ //S-P-A-IH-N",
    "SPEECH/ //S-P-EE-CH",
    "START/ //S-T-AH-R-T",
    "STARTING/ //S-T-AH-R-T-IH-N-G",
    "SYSOP/ //S-IH-S-AH-P",
    "TALK/ //T-AW-K",
    "TAPE/ //T-A-P",
    "TELEPHONE/ //T-EH-L-UH-F-OH-N",
    "TEST/ //T-EH-S-T-T",
    "THE/ //TZ-UH",
    "THESE/ //TH-EE-S",
    "THIS/ //TH-IH-S",
    "THOM/ //T-AH-M",
    "TO/ //T-OO",
    "TOMATO/ //T-UH-M-A-T-OH",
    "TOO/ //T-OO",
    "TRY/ //T-R-I",
    "UNIT/ //Y-OO-N-IH-T",
    "US/ //UH-S",
    "USER/ //Y-OO-S-R",
    "USING/ //Y-OO-S-IH-N-G",
    "USING/ //Y-OO-Z-IH-N-G",
    "VERY/ //V-AE-R-E",
    "VOCABULARY/ //V-OH-K-AE-B-Y-OO-L-AE-R-EE",
    "WARM/ //W-AH-R-M",
    "WE/ //W-EE",
    "WELCOME/ //W-EH-L-K-UH-M",
    "WORLD/ //W-ER-L-D",
    "WORKING/ //W-UH-R-K-IH-N-G",
    "WOULD/ //W-U-D",
    "YES/ //Y-EH-S",
    "YOUR/ //Y-OH-R"
]

################################################################################
#                                                                              #
# phonemes data                                                                #
#                                                                              #
################################################################################

phonemes_dictionary = {
    "space": (
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
    ),
    "U": (
        0x3F, 0xFF, 0xFF, 0xF0, 0xFC, 0xFE, 0xFC, 0x00, 0x00, 0x00, 0x7F, 0xFF,
        0xFF, 0x80, 0x00, 0x01, 0xFF, 0xFC, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFC,
        0x00, 0x01, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x1C, 0x1F, 0xFF, 0xFF, 0xF1,
        0xFC, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xF0, 0xFC, 0xFF,
        0x7C, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0x84, 0x00, 0x01, 0xFF, 0x00,
        0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFC, 0x00, 0x1F, 0xFF, 0xF0, 0x00, 0x00,
        0x00, 0x03, 0x83, 0xFF, 0xFF, 0xFF, 0xFF, 0x1F, 0xE0, 0x00, 0x00, 0x00,
        0x07, 0xFF, 0xFF, 0xFF, 0x3F, 0x9F, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF,
        0xFF, 0xC0, 0xC0, 0x00, 0xFF, 0xFE, 0x00, 0x00, 0x47, 0xFF, 0xFF, 0xFE,
        0x00, 0x03, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x07, 0x0F, 0xFF, 0xFF, 0xFF,
        0xFF, 0x3F, 0xC0, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFC, 0x3F, 0x3F,
        0x06, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0x07, 0x00, 0x07, 0xFF, 0xF0,
        0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xFC, 0x00, 0x00,
        0x00, 0x0F, 0x9F, 0xFF, 0xFF, 0xFF, 0xFF, 0x7F, 0x80, 0x00, 0x00, 0x00,
        0x3F, 0xFF, 0xFF, 0xFC, 0x7F, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF,
        0xFC, 0x30, 0x00, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xE0,
        0x00, 0x1F, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x0F, 0x1F, 0xFF, 0xFF, 0xFF,
        0xFE, 0x7F, 0x80, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xF8, 0xFF, 0x3F,
        0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFE, 0x03, 0xF0, 0xF8, 0x00,
        0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xE1, 0xC0, 0x7F, 0xFE, 0x00, 0x00, 0x00,
        0x00, 0x0F, 0x0F, 0xFF, 0xFF, 0xFF, 0xFC, 0x3F, 0x80, 0x00, 0x00, 0x00,
        0x1F, 0xFF, 0xFF, 0xFC, 0xFE, 0x1C, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF,
        0xFE, 0x3C, 0x00, 0x7F, 0xFF, 0xC0, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xE0,
        0x00, 0x0F, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x3C, 0x7F, 0xFF, 0xFF, 0xFF,
        0xF8, 0xFF, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xE1, 0xFC, 0xFC,
        0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xE0, 0x03, 0xE7, 0xFF, 0x00,
        0x00, 0x01, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0x00, 0xF1, 0xFF, 0xFF, 0xFF, 0xFF, 0xC7, 0xF8, 0x00, 0x00, 0x00, 0x03,
        0xFF, 0xFF, 0xFF, 0x87, 0xE3, 0xE0, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF,
        0xFF, 0xE0, 0x3E, 0x3F, 0x80, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFC, 0x00,
        0x07, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x03, 0xC3, 0xFF, 0xFF, 0xFF, 0xFF,
        0x0F, 0xE0, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0x1F, 0x87, 0x80,
        0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xC0, 0x78, 0x3F, 0x00, 0x00,
        0x00, 0xFF, 0xFF, 0xFF, 0xFC, 0xF0, 0x1F, 0xF3, 0xC0, 0x00, 0x00, 0x00,
        0x07, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0x1F, 0xC0, 0x00, 0x00, 0x00, 0x0F,
        0xFF, 0xFF, 0xFE, 0x3F, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF,
        0xFF, 0xC0, 0xF0, 0x7E, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0,
        0x1F, 0xCF, 0x80, 0x00, 0x00, 0x00, 0x07, 0x0F, 0xFF, 0xFF, 0xFF, 0xFE,
        0x3F, 0xC0, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFC, 0x7E, 0x1E, 0x00,
        0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0x01, 0xE0, 0xFC, 0x00, 0x00,
        0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x7F, 0xFF, 0x80, 0x00, 0x00, 0x00,
        0x70, 0xFF, 0xFF, 0xFF, 0xFF, 0xE1, 0xFE, 0x00, 0x00, 0x00, 0x00, 0xFF,
        0xFF, 0xFF, 0xC3, 0xF0, 0xF0, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF,
        0xF8, 0x0F, 0x0F, 0xF0, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFE, 0x00,
        0xFF, 0xFC, 0x00, 0x00, 0x00, 0x01, 0xC1, 0xFF, 0xFF, 0xFF, 0xFF, 0x87,
        0xF8, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0x0F, 0xE3, 0xC0, 0x00,
        0x00, 0x00, 0x03, 0xFF, 0xFF, 0xF0, 0x40, 0x00, 0x7F, 0xFE, 0x00, 0x00,
        0x01, 0xFF, 0xFF, 0xFF, 0x00, 0x03, 0xFF, 0xFF, 0x80, 0x00, 0x00
    ),
    "A": (
        0xF0, 0x00, 0xFC, 0x03, 0xFF, 0x83, 0xFF, 0xF8, 0x00, 0x7E, 0x00, 0x1F,
        0xC0, 0x07, 0xFF, 0x80, 0x1F, 0xE0, 0x07, 0xF0, 0x01, 0xFF, 0x03, 0xFF,
        0xFF, 0x7F, 0xFF, 0x03, 0xFF, 0xE0, 0xC0, 0x3F, 0x00, 0x0F, 0xE0, 0x3F,
        0xF8, 0x3F, 0xFF, 0x80, 0x01, 0xF8, 0x00, 0xFE, 0x03, 0xFF, 0xC3, 0xFF,
        0xF8, 0x00, 0x3F, 0x00, 0x0F, 0xC0, 0x03, 0xF8, 0x77, 0xE7, 0xF0, 0x01,
        0xF8, 0x00, 0xFF, 0x00, 0xFF, 0xFF, 0x67, 0xFF, 0x80, 0xFF, 0xFC, 0x7C,
        0x07, 0xE0, 0x01, 0xFC, 0x07, 0xFF, 0x07, 0xF3, 0xF8, 0x00, 0x3F, 0x00,
        0x1F, 0x80, 0x7F, 0xF8, 0x7E, 0xFF, 0x00, 0x07, 0xC0, 0x01, 0xF8, 0x00,
        0xFF, 0x0F, 0xF0, 0xFF, 0x00, 0x3F, 0x00, 0x3F, 0xC0, 0x3F, 0xFF, 0xCF,
        0xFF, 0xE0, 0x1F, 0xFF, 0x3F, 0x80, 0xFC, 0x00, 0x3F, 0x80, 0xFF, 0xE0,
        0xFE, 0x7F, 0x00, 0x07, 0xE0, 0x01, 0xF8, 0x0F, 0xFF, 0x07, 0xEF, 0xF3,
        0x00, 0xFC, 0x00, 0x3F, 0x00, 0x0F, 0xE0, 0x7F, 0x8F, 0xE0, 0x03, 0xF0,
        0x01, 0xFC, 0x03, 0xFF, 0xFF, 0xCF, 0xFE, 0x00, 0xFF, 0xE3, 0xFF, 0x00,
        0xFC, 0x00, 0x7F, 0x00, 0xFF, 0xC0, 0xFC, 0x7F, 0x00, 0x0F, 0xC0, 0x03,
        0xF0, 0x1F, 0xFE, 0x1F, 0x8F, 0xFE, 0x01, 0xF8, 0x00, 0x7E, 0x00, 0x3F,
        0xC0, 0x7F, 0x1F, 0x00, 0x03, 0xC0, 0x03, 0xF8, 0x0F, 0xFF, 0xF0, 0xFF,
        0xFC, 0x01, 0xFF, 0xFF, 0xFF, 0x00, 0xF8, 0x00, 0x7F, 0x00, 0xFF, 0xC1,
        0xFC, 0x7F, 0x00, 0x0F, 0xC0, 0x03, 0xF0, 0x1F, 0xFE, 0x1F, 0x0F, 0xE6,
        0x00, 0xF8, 0x00, 0x7F, 0x00, 0x1F, 0xFF, 0x8C, 0x0F, 0xE0, 0x07, 0xF0,
        0x03, 0xFC, 0x07, 0xFF, 0xE0, 0x0F, 0xFC, 0x00, 0xFF, 0x01, 0xFF, 0x80,
        0x7E, 0x00, 0x1F, 0x80, 0xFF, 0xE0, 0xFE, 0x3F, 0x00, 0x07, 0xE0, 0x01,
        0xF8, 0x0F, 0xFF, 0x0F, 0xC7, 0xFB, 0x00, 0xFC, 0x00, 0x1F, 0x00, 0x0F,
        0xF0, 0x7F, 0x8F, 0xC0, 0x01, 0xE0, 0x01, 0xFE, 0x03, 0xFF, 0xFE, 0xFF,
        0xFF, 0x00, 0xFF, 0xE7, 0xFF, 0xE0, 0x1F, 0x80, 0x07, 0xF0, 0x1F, 0xFC,
        0x1F, 0xC7, 0xE0, 0x00, 0xFC, 0x00, 0x3F, 0x00, 0xFF, 0xE1, 0xF0, 0xFE,
        0x00, 0x0F, 0x80, 0x03, 0xF0, 0x01, 0xFC, 0x0F, 0xE0, 0x3E, 0x00, 0x7F,
        0x00, 0x7F, 0xC0, 0x7F, 0xFF, 0xF7, 0xFF, 0xC0, 0x1F, 0xFC, 0x7F, 0xF0,
        0x0F, 0xC0, 0x03, 0xF8, 0x0F, 0xFE, 0x0F, 0xC7, 0xF0, 0x00, 0x7E, 0x00,
        0x3F, 0x00, 0xFF, 0xF0, 0xFC, 0xFF, 0x00, 0x0F, 0x80, 0x03, 0xF0, 0x01,
        0xFE, 0x1F, 0xC0, 0xFE, 0x00, 0x3F, 0x00, 0x3F, 0xC0, 0x7F, 0xFF, 0xCF,
        0xFF, 0xE0, 0x07, 0xFE, 0x3F, 0xFC, 0x07, 0xE0, 0x01, 0xFC, 0x07, 0xFF,
        0x07, 0xF1, 0xF8, 0x00, 0x3F, 0x00, 0x1F, 0x80, 0x7F, 0xF8, 0x7E, 0x7F,
        0x00, 0x07, 0xC0, 0x01, 0xF8, 0x00, 0xFF, 0xCC, 0x03, 0xF8, 0x00, 0xFE,
        0x00, 0xFF, 0x80, 0x7F, 0xFF, 0x01, 0xFF, 0x00, 0x3F, 0xF3, 0xFF, 0xF0,
        0x0F, 0xC0, 0x07, 0xF0, 0x0F, 0xFC, 0x0F, 0xE3, 0xF0, 0x00, 0x7E, 0x00,
        0x3F, 0x00, 0xFF, 0xF0, 0xFC, 0xFF, 0x00, 0x0F, 0x80, 0x03, 0xF0, 0x01,
        0xFC, 0x1F, 0xE0, 0x38, 0x00, 0x1E, 0x00, 0x3F, 0xF0, 0xFF, 0xFF, 0xFD,
        0x9F, 0xC0, 0x07, 0xF1, 0xFF, 0xFC, 0x01, 0xF8, 0x00, 0xFE, 0x01, 0xFF,
        0x81, 0xFD, 0xFE, 0x00, 0x1F, 0x80, 0x07, 0xE0, 0x1F, 0xFC, 0x3F, 0x3F,
        0xC0, 0x01, 0xE0, 0x00, 0x7E, 0x00, 0x3F, 0x09, 0xF8, 0x1F, 0xC0, 0x07,
        0xC0, 0x0F, 0xFC, 0x1F, 0xFF, 0xF1, 0xFF, 0xFC, 0x01, 0xFF, 0xFF, 0xF8,
        0x07, 0xE0, 0x03, 0xF8, 0x07, 0xFE, 0x07, 0xF1, 0xF8, 0x00, 0x3F, 0x00,
        0x3F, 0x80, 0xFF, 0xF8, 0x7F, 0xFF, 0x00, 0x07, 0xC0, 0x01, 0xF8, 0x00,
        0xFE, 0x1F, 0xC0, 0x7C, 0x00, 0x0F, 0x00, 0x1F, 0xC0, 0xFF, 0xFF, 0xE1,
        0xFF, 0xE0, 0x0F, 0xFB, 0xFF, 0xF8, 0x07, 0xE0, 0x01, 0xFC, 0x07, 0xFF,
        0x07, 0xF3, 0xF8, 0x00, 0x7E, 0x00, 0x1F, 0x80, 0xFF, 0xF0, 0xFC, 0x7F,
        0x00, 0x07, 0x80, 0x01, 0xF8, 0x00, 0xFF, 0x03, 0xE0, 0x08, 0x00, 0x07,
        0x00, 0x1F, 0xF8, 0x3F, 0xFF, 0xE7, 0xFF, 0xE0, 0x0F, 0xFF, 0xFF
    ),
    "B": (
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x03, 0xFF, 0xFF, 0x98, 0x38, 0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00,
        0xF8, 0x38, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xE0, 0x0F, 0xFF, 0x0F,
        0x80, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF,
        0x1F, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xE7, 0xFF, 0xFF,
        0xFF, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x00,
        0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0xFF, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xC0, 0xF8, 0x0F, 0x1F, 0x00,
        0x00, 0x03, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x0C, 0x00, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xFF, 0xE0, 0x07, 0x8F, 0xFF, 0xF0, 0xFF, 0xFF, 0xFF, 0xF0,
        0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xE0, 0xF8, 0x0F, 0x00, 0x00, 0x00, 0x01,
        0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF,
        0xF0, 0x00, 0x00, 0x10, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00,
        0x01, 0xFF, 0xFF, 0xFF, 0x0F, 0x80, 0x60, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0x00, 0x00,
        0x00, 0x1F, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x03,
        0xFF, 0xFF, 0xFF, 0x03, 0x80, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF,
        0x00, 0x00, 0x00, 0x3E, 0x7F, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xFF, 0x80, 0x7F, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xFE, 0x07, 0x00, 0x20, 0x1C, 0x00, 0x00, 0xFF, 0xFF, 0xFF,
        0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x01,
        0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x0F, 0x9F, 0xFF, 0xFF, 0xFF, 0xC0, 0x00,
        0x01, 0xE1, 0xFF, 0xFF, 0x03, 0x80, 0x38, 0x0F, 0x00, 0x00, 0x3F, 0xFF,
        0xFF, 0xE0, 0x00, 0x00, 0x0F, 0xDF, 0xFF, 0xF3, 0xFF, 0xFF, 0xC0, 0x00,
        0x00, 0x01, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF,
        0xF0, 0x00, 0x00, 0x3C, 0x3F, 0xFF, 0xF0, 0x78, 0x03, 0x00, 0xE0, 0x00,
        0x03, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xBF, 0xFF,
        0xF8, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xE7, 0x80, 0x10, 0x70, 0x00, 0x00,
        0x7F, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x07, 0xC7, 0xFF, 0xFF, 0x0F,
        0x80, 0x00, 0x07, 0x03, 0xC7, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x3F,
        0xFF, 0xFF, 0xF9, 0xFC, 0x0E, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xE0,
        0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0x9F, 0x00, 0x00, 0x03, 0xFF, 0xFF,
        0xFF, 0xF0, 0x0C, 0x01, 0xF0, 0xFF, 0xFF, 0x83, 0xE0, 0x3C, 0x07, 0x80,
        0x00, 0x3F, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x0F, 0xC7, 0xF0, 0xFC, 0x7F,
        0xFF, 0xE0, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xE0, 0xC0, 0x01, 0x00, 0x00,
        0x00, 0x03, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x1F, 0xF3, 0xFF, 0xFF,
        0xFF, 0xE0, 0x00, 0x00, 0x0F, 0xFF, 0x80, 0x00, 0x00, 0x0F, 0xFF, 0xFC,
        0x18, 0x00, 0x40, 0x3F, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xE0, 0x00, 0x00,
        0x3F, 0xFF, 0xFC, 0x00, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x3F, 0xFF, 0xFF,
        0x00, 0x00, 0x1F, 0x9C, 0x20, 0x00, 0x08, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0x00, 0x03, 0x80, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x8C,
        0x20, 0x00, 0x00, 0x00, 0x00, 0x18, 0x66, 0x00, 0x00, 0x01, 0xFF, 0xFF,
        0x80, 0x00, 0x00, 0x0F, 0xFF, 0xFE, 0xF8, 0x00, 0x60, 0x00, 0x00, 0x03,
        0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x03, 0xFF, 0xE0, 0x04, 0x06, 0x80, 0x00,
        0x00, 0x00, 0x71, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C,
        0x38, 0x00, 0x00, 0x00, 0x10, 0x30, 0x01, 0x00, 0x0E, 0x0C, 0x10, 0x40,
        0x63, 0x04, 0x00, 0x00, 0x00, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x21, 0xE0,
        0x00, 0x00, 0x00, 0x30, 0x06, 0x00, 0x62, 0x00, 0x00, 0x00, 0x00
    ),
    "D": (
        0xC1, 0xE0, 0xFC, 0xF3, 0x9F, 0xCF, 0x19, 0xC7, 0xE1, 0x9C, 0x39, 0x8E,
        0x38, 0x1C, 0xE7, 0x3F, 0x63, 0xB8, 0x71, 0xE1, 0xE1, 0xC0, 0x7E, 0x1C,
        0x47, 0x01, 0xC7, 0x70, 0x1E, 0x1B, 0xC3, 0xC0, 0x38, 0x1F, 0x18, 0xE0,
        0xF1, 0xF0, 0xFC, 0x00, 0xE0, 0xE0, 0x78, 0x3C, 0xE3, 0x1E, 0x3C, 0xC0,
        0xE1, 0xC4, 0xE3, 0x98, 0x78, 0xE1, 0xFC, 0x78, 0x0F, 0xC7, 0x1C, 0x71,
        0xC6, 0x38, 0xE7, 0x87, 0x3C, 0x38, 0xE3, 0xF8, 0x1F, 0x01, 0xF0, 0x7C,
        0x1F, 0x1C, 0xF0, 0x0F, 0x87, 0x00, 0xE0, 0x00, 0x1C, 0x07, 0x03, 0xF0,
        0x7F, 0x1F, 0xE3, 0xF3, 0xC7, 0x18, 0xF8, 0x03, 0x20, 0x1C, 0x1F, 0x00,
        0x70, 0x83, 0xC3, 0x80, 0xFC, 0x47, 0xFF, 0xCF, 0xFD, 0xFF, 0xFC, 0x77,
        0xE0, 0x00, 0x00, 0x0F, 0x00, 0x40, 0x78, 0x1F, 0x81, 0xFF, 0xFC, 0x7F,
        0x8F, 0xFF, 0xE0, 0x1E, 0x04, 0x00, 0x00, 0x3F, 0x00, 0x01, 0x01, 0xFC,
        0x01, 0xFF, 0xE3, 0xF0, 0x7F, 0xFF, 0xC7, 0xFF, 0xFF, 0xFF, 0x8F, 0xF0,
        0x00, 0x01, 0xE0, 0x0E, 0x01, 0xFF, 0xFC, 0x7F, 0xFF, 0xCF, 0xE0, 0x3E,
        0x00, 0x00, 0x00, 0x3C, 0x3E, 0x0F, 0xFF, 0xFE, 0x7E, 0x00, 0x00, 0x00,
        0x08, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00,
        0x01, 0xF0, 0x0F, 0x80, 0xFF, 0xFF, 0xFF, 0xFF, 0x83, 0xE0, 0x00, 0x00,
        0x00, 0x7E, 0xFF, 0xFF, 0xFF, 0xF8, 0x04, 0x00, 0x00, 0x00, 0x03, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xE0, 0x03,
        0xE0, 0x1F, 0x00, 0x3F, 0xFF, 0xFF, 0xFE, 0x0F, 0xE0, 0x00, 0x00, 0x3F,
        0xE0, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0x80, 0x0E, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0xE0,
        0x07, 0xE0, 0x1F, 0xFF, 0xFF, 0xF0, 0x01, 0xE0, 0x00, 0x00, 0x1F, 0xFF,
        0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x01, 0xE0, 0x7F, 0xFF, 0xFF, 0x80,
        0x3C, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00,
        0x7F, 0xC0, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFF, 0x80, 0x70, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00,
        0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00,
        0x1F, 0xFE, 0x1F, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x01, 0xFE, 0x1F, 0xFF,
        0xFF, 0x80, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xE0, 0x00, 0x00,
        0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFC, 0x3F, 0xF0, 0x07, 0x81, 0xFE, 0x00,
        0x08, 0x03, 0xFF, 0x81, 0xFF, 0x7F, 0xFC, 0x00, 0x00, 0x1F, 0xFF, 0x01,
        0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xF8, 0x00,
        0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xF0, 0x1E, 0x00, 0x3F, 0x07, 0xFF,
        0xFF, 0xC0, 0x00, 0x00, 0x7F, 0xF0, 0x3F, 0x8F, 0xFF, 0xE0, 0x00, 0x00,
        0xC1, 0xF0, 0x1F, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x73, 0xFF,
        0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFC, 0x00, 0x38,
        0x00, 0x00, 0x7F, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0xFF, 0xF0, 0x7F, 0x8F,
        0xFF, 0x00, 0x00, 0x01, 0xE0, 0xF8, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF,
        0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xF0, 0x00,
        0x00, 0x0F, 0xFF, 0x1F, 0xF1, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x7F, 0xFF,
        0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x01, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x80,
        0x00, 0x00, 0x00, 0x30, 0x1F, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x0E, 0x00,
        0x7F, 0xFF, 0xFF, 0xEF, 0xBF, 0xFC, 0x00, 0x00, 0x1F, 0xFF, 0x1F, 0xE0,
        0xFF, 0xFC, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00,
        0x03, 0xC7, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x0F, 0xFF, 0xFF,
        0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xF3, 0xFF, 0xFC, 0x00,
        0x00, 0xFF, 0xFF, 0xF0, 0x00, 0x03, 0xCF, 0xF0, 0x7F, 0x07, 0xFF
    ),
    "G": (
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x7F, 0xF0, 0x00, 0xFF, 0xC0, 0x00, 0x0F, 0xF8, 0x00, 0xFF,
        0xF8, 0x0F, 0xFF, 0x00, 0x3F, 0xFE, 0x1E, 0x07, 0xEF, 0xC0, 0xF0, 0xFC,
        0x18, 0x00, 0xFF, 0xE0, 0x0F, 0xFC, 0x00, 0x1F, 0xE0, 0x07, 0xE1, 0x0F,
        0xFC, 0x60, 0x07, 0x83, 0xF0, 0x00, 0x7F, 0x01, 0x37, 0xEE, 0x70, 0x7C,
        0x00, 0x0F, 0xFF, 0xE1, 0xE0, 0x3F, 0xFF, 0x02, 0x1F, 0xE0, 0x01, 0xFC,
        0x0E, 0x02, 0x00, 0xFF, 0xF8, 0x0F, 0xFF, 0x01, 0xF0, 0x00, 0x7E, 0x40,
        0x7F, 0xC0, 0x1F, 0xF8, 0x01, 0xFF, 0xC0, 0xEF, 0xF8, 0x38, 0x7F, 0xFE,
        0x0F, 0x00, 0xC0, 0xE0, 0x3E, 0x3F, 0x1F, 0xFF, 0x07, 0xF0, 0x00, 0x3F,
        0xF0, 0x07, 0xFF, 0x0F, 0xFC, 0xFF, 0xFF, 0x03, 0x00, 0x00, 0x01, 0xE0,
        0x3F, 0xFC, 0x03, 0xFF, 0x00, 0x1F, 0xE0, 0x00, 0xFC, 0x00, 0x1F, 0x86,
        0x01, 0xF9, 0xC0, 0x08, 0x07, 0x0F, 0xC1, 0xE3, 0xFF, 0xF8, 0xFF, 0xF0,
        0x03, 0xC0, 0x80, 0x00, 0x00, 0x06, 0x00, 0x00, 0x0F, 0x00, 0x03, 0xFC,
        0x3F, 0xFF, 0xFF, 0xFF, 0x81, 0xFE, 0x18, 0x00, 0x80, 0x00, 0x00, 0x00,
        0x03, 0x00, 0x03, 0x7C, 0x7F, 0xFF, 0xFF, 0xF8, 0xFF, 0xFF, 0x9F, 0x3F,
        0xFF, 0xF0, 0x08, 0x07, 0x80, 0x00, 0x7C, 0x00, 0x07, 0xE0, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF2, 0x00, 0x00, 0x01, 0xC0,
        0x00, 0x0F, 0x00, 0xF7, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x7C, 0x00,
        0x00, 0x00, 0x00, 0x70, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0x81, 0xFF, 0xFE, 0x00, 0x00, 0x0F, 0x00, 0x00, 0x7E, 0x07, 0xFF, 0xFF,
        0xFF, 0xF8, 0x7F, 0x80, 0x00, 0xC0, 0x00, 0x00, 0x01, 0xFF, 0xE0, 0xFF,
        0xFF, 0xFF, 0xF0, 0x3F, 0xC0, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00,
        0x78, 0x00, 0x01, 0xF0, 0x7F, 0xFF, 0xFF, 0xFF, 0xC3, 0xF8, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x70, 0x00, 0x00, 0xF1, 0xFF,
        0xFF, 0xFF, 0xFF, 0x81, 0xE0, 0x00, 0x00, 0x00, 0x1F, 0x81, 0xFF, 0xFF,
        0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0x00, 0x00, 0x03, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00,
        0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00,
        0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0xE0,
        0x0F, 0x3F, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF,
        0xFF, 0xFF, 0xFE, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF,
        0xFF, 0x80, 0x00, 0x00, 0xE0, 0x00, 0x00, 0x00, 0x3E, 0x01, 0xFF, 0xFF,
        0xFF, 0xF8, 0x3F, 0x80, 0x60, 0x00, 0x03, 0xF8, 0x1F, 0xFD, 0xFF, 0xFF,
        0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0,
        0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0x00, 0x07, 0x00, 0x00, 0x00, 0x3F, 0xFF,
        0xFF, 0xF0, 0x1F, 0x00, 0x00, 0x00, 0x03, 0xFE, 0x3F, 0xFF, 0xFF, 0xF0,
        0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xC0, 0x80, 0x00, 0x01,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x06, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFF, 0xE0, 0x3E, 0x00, 0x00, 0x00, 0x3F, 0xFE, 0x7F, 0xFF, 0xFF, 0x80,
        0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC7, 0xFE, 0x00, 0x01, 0x80, 0x1F, 0xF0,
        0x7F, 0xFF, 0xFF, 0xF0, 0x0E, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xBF, 0xE1,
        0xFF, 0x80, 0x00, 0x00, 0x01, 0xF0, 0x7F, 0xFF, 0xFF, 0xC0, 0x00, 0x00,
        0x00, 0x00, 0x0F, 0xFF, 0xFF, 0x87, 0xCF, 0x98, 0x0C, 0x00, 0xFF, 0xFB,
        0xFF, 0xFF, 0x00, 0xE0, 0x00, 0x78, 0x07, 0xE7, 0xFC, 0xFE, 0x07, 0x80,
        0x00, 0x00, 0x0F, 0x0F, 0xFF, 0xFC, 0x3F, 0xF0, 0x01, 0x80, 0x00
    ),
    "J": (
        0x1F, 0xC0, 0x3F, 0x03, 0xFC, 0x03, 0xF0, 0x1F, 0x07, 0xC0, 0xFF, 0x83,
        0xFC, 0x0F, 0xF8, 0x3F, 0xC0, 0x7F, 0x03, 0xC0, 0xF0, 0x0F, 0xF0, 0x7F,
        0x83, 0x1F, 0x01, 0xF0, 0x07, 0xC1, 0x9F, 0x80, 0xF8, 0x73, 0xC0, 0x3F,
        0xC3, 0xE2, 0x0F, 0xF8, 0x3F, 0x83, 0xC7, 0x1C, 0x70, 0xF8, 0xF0, 0xF8,
        0xE0, 0xFE, 0x0F, 0x00, 0xFF, 0x07, 0xC3, 0xC7, 0x00, 0xEF, 0x0F, 0x1F,
        0x0E, 0x3E, 0x11, 0xE1, 0xFE, 0x0F, 0x0E, 0x3F, 0xC1, 0xF0, 0xF8, 0x07,
        0x81, 0xF0, 0x63, 0xF0, 0x3F, 0x1E, 0x0F, 0xF0, 0xFF, 0x0F, 0x1E, 0x03,
        0xE0, 0x3F, 0x01, 0xE0, 0x7C, 0x03, 0xF0, 0x1F, 0x00, 0x1F, 0x07, 0xF0,
        0x3C, 0x3E, 0x07, 0xF8, 0x3F, 0xE1, 0xF0, 0x1C, 0x63, 0xF8, 0x0F, 0xE0,
        0x1F, 0x07, 0x01, 0xE1, 0xE1, 0xF8, 0x1F, 0x80, 0x7F, 0xC0, 0xFC, 0x1F,
        0x0F, 0x03, 0xF8, 0x40, 0xFF, 0xE0, 0x7C, 0x1F, 0x03, 0xC1, 0xE3, 0x70,
        0x43, 0x8F, 0x0F, 0xF8, 0x3F, 0x80, 0xF7, 0x81, 0xF0, 0x3F, 0x0F, 0x00,
        0xC7, 0xC0, 0xFE, 0x04, 0x78, 0x78, 0x0F, 0xC0, 0x1F, 0x03, 0xF8, 0x78,
        0xF0, 0xF8, 0x3E, 0x1C, 0x3F, 0x83, 0xE0, 0xC7, 0x07, 0x87, 0x81, 0xF8,
        0x3F, 0x87, 0x01, 0xC3, 0xC0, 0xFF, 0x03, 0xDE, 0x00, 0xFC, 0x0F, 0x1C,
        0x3E, 0x1E, 0x0F, 0x0F, 0x80, 0xFC, 0x00, 0xF1, 0xC3, 0xC3, 0xCF, 0x07,
        0x86, 0x0F, 0x80, 0xFE, 0x10, 0x3C, 0x78, 0x71, 0xE0, 0x0F, 0x9C, 0x07,
        0xF0, 0x7C, 0x07, 0x81, 0xE1, 0xF0, 0xFC, 0x3E, 0x03, 0xF0, 0xFC, 0xF8,
        0xF8, 0x1F, 0xF0, 0x3C, 0x06, 0x7C, 0x07, 0x80, 0x00, 0x00, 0xF8, 0x3F,
        0x00, 0xFF, 0x81, 0xFF, 0x8F, 0x00, 0xF8, 0x1C, 0x00, 0x07, 0x02, 0x01,
        0xFC, 0x81, 0xFF, 0xFC, 0x3F, 0xFC, 0xFF, 0xE7, 0xF9, 0xC7, 0xC3, 0x80,
        0x80, 0x78, 0x00, 0xC0, 0x00, 0x01, 0xFF, 0x87, 0xF0, 0xFF, 0x3F, 0x1F,
        0xFF, 0x00, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0x3F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x01, 0xC0, 0x00, 0x08,
        0x00, 0xC3, 0xF8, 0x3F, 0x9F, 0xFF, 0xFF, 0xFF, 0x3C, 0x00, 0xE0, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFE, 0xFC, 0x00, 0x01, 0xE0, 0x00, 0x0F, 0x00, 0x1F, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFC, 0x1F, 0xE0, 0x00, 0x00, 0x00, 0x00, 0xC0, 0x03, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x1F, 0xFE, 0x00, 0x00, 0x0F, 0x00,
        0x00, 0x7F, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x07, 0xC0, 0x00,
        0x00, 0x00, 0x0F, 0xE0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x3E, 0x00, 0x01, 0xF8, 0x01, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0x00, 0x0F, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xC0, 0x3E, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00,
        0x0F, 0x00, 0x00, 0x7E, 0xC0, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00,
        0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00,
        0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x0F, 0x00, 0x00, 0x78,
        0xF8, 0x7F, 0xFF, 0xFF, 0xFC, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x0F, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7E, 0x3F, 0xFF, 0xFF, 0xFF,
        0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80,
        0x00, 0xC0, 0x00, 0x03, 0xC0, 0x00, 0x7F, 0xFF, 0xFF, 0xC3, 0xFF, 0xE0,
        0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00,
        0x00, 0x00, 0x7F, 0xC0, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0xFF,
        0xFF, 0xFF, 0x00, 0x0F, 0x80, 0x00, 0xF8, 0x7E, 0x3F, 0x07, 0xFF, 0xC0,
        0x30, 0x0E, 0x00, 0x00, 0x3F, 0xFE, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x1C,
        0x00, 0x00, 0x38, 0x7C, 0x1F, 0xFF, 0x07, 0x9F, 0x00, 0xF0, 0x00
    ),
    "P": (
        0x01, 0x83, 0xF8, 0x00, 0x1F, 0x7F, 0xCF, 0x3F, 0x80, 0xC0, 0x01, 0xFF,
        0xC0, 0x00, 0x78, 0x03, 0xF8, 0x38, 0xC0, 0x04, 0x00, 0x61, 0x00, 0x00,
        0x00, 0x00, 0x78, 0xBF, 0xF8, 0x8F, 0x8F, 0xFF, 0xFE, 0x7F, 0xFF, 0xFB,
        0xFF, 0xFC, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE,
        0x00, 0xE0, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00,
        0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0x00, 0x00, 0x1E, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x1F, 0xFF, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x3F, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x1F, 0xFF, 0xFC, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00,
        0x03, 0xFE, 0x03, 0xFF, 0xFF, 0xFF, 0xFC, 0x03, 0xF0, 0x00, 0x00, 0x1F,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF,
        0xC0, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDF,
        0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x0F, 0xFF, 0xE0, 0x00, 0x00, 0x47, 0xFC,
        0x3E, 0x0E, 0x00, 0x00, 0x00, 0x63, 0xFF, 0xFC, 0x00, 0x00, 0x78, 0x3E,
        0x00, 0xE1, 0xC3, 0x00, 0x00, 0x3C, 0x03, 0xFF, 0xF0, 0xC0, 0x03, 0xFF,
        0xFF, 0xFE, 0x07, 0xC0, 0x1F, 0xFF, 0x1F, 0xE0, 0x1E, 0x00, 0x00, 0x00,
        0x00, 0x10, 0xFF, 0xE0, 0x60, 0x18, 0x03, 0xFC, 0xFF, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x0F, 0x01, 0xFC, 0x00, 0x1F, 0x01, 0xFE, 0x3F, 0xFF,
        0xFF, 0xF8, 0x0F, 0x00, 0xFF, 0xFF, 0xFF, 0x81, 0xE0, 0x00, 0xFE, 0x08,
        0x00, 0x00, 0x00, 0xFF, 0x9F, 0xC0, 0x00, 0x00, 0x00, 0x73, 0xFF, 0xF8,
        0xE0, 0x18, 0x10, 0x00, 0x3C, 0x03, 0xC7, 0xCF, 0xF1, 0xFF, 0xFF, 0xFF,
        0xFC, 0xE0, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x03, 0xC7, 0xFF, 0xF0, 0x00, 0x00, 0x1C, 0x7F, 0x7F, 0xC0,
        0xC3, 0x80, 0xFC, 0x00, 0x7F, 0xF9, 0xE2, 0x01, 0xF0, 0xFF, 0xFF, 0xF1,
        0xFC, 0x7F, 0xFC, 0x3F, 0xFF, 0xE0, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xC0,
        0x80, 0x00, 0x00, 0x00, 0xFC, 0x7F, 0xFF, 0x00, 0x00, 0x00, 0x07, 0xF3,
        0xFE, 0x00, 0xE7, 0xFF, 0xFF, 0xFF, 0xFF, 0xF9, 0xFF, 0xFF, 0xFF, 0xC0,
        0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x7C, 0xFF,
        0xFF, 0xF0, 0x00, 0x02, 0x03, 0xE0, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0x80, 0x07, 0x0F, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x1F, 0xFF, 0xFF,
        0xE0, 0x00, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x71,
        0x70, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xC7, 0xFC, 0x7F,
        0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFE, 0x00, 0x00,
        0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0xF8, 0x03,
        0xFF, 0xFE, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC,
        0x3F, 0x30, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00,
        0x00, 0x01, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0x07, 0xFF,
        0xFF, 0xE0, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xF0, 0x01, 0x0F, 0xFF, 0xFF,
        0xFF, 0xF3, 0xC0, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xC0, 0x00, 0x00,
        0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF,
        0xFF, 0xF0, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00,
        0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xF0,
        0x00, 0x00, 0x03, 0x00, 0x01, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x03
    ),
    "T": (
        0x1F, 0x03, 0xC1, 0xE0, 0xF8, 0x07, 0xC1, 0xE0, 0xF0, 0x7C, 0x1F, 0x04,
        0x3F, 0x1C, 0xE6, 0x1C, 0x86, 0x71, 0xC1, 0xF8, 0x01, 0xF8, 0x87, 0x1F,
        0x87, 0x81, 0xF0, 0xF0, 0x71, 0x1F, 0x8F, 0x1E, 0xE3, 0xE7, 0x33, 0x1C,
        0xC7, 0x3B, 0x98, 0x39, 0xC9, 0x9C, 0x78, 0xE7, 0x39, 0xC7, 0x67, 0x27,
        0xC6, 0x3A, 0x39, 0x99, 0xB8, 0xF0, 0x78, 0xF3, 0x83, 0x8E, 0xE7, 0x71,
        0xCC, 0x79, 0x1F, 0x1F, 0x1F, 0x0F, 0x03, 0x89, 0xE3, 0xD8, 0xF0, 0x78,
        0xFC, 0x0E, 0x39, 0xCC, 0xE0, 0xEE, 0x73, 0x1C, 0x72, 0x31, 0x99, 0x8F,
        0x1E, 0x71, 0xF0, 0x78, 0x78, 0xCF, 0x30, 0x78, 0x71, 0x9C, 0x3C, 0xCE,
        0x7F, 0x04, 0xE0, 0xF0, 0x9E, 0x0F, 0x03, 0xC3, 0xE1, 0xF8, 0x8E, 0x63,
        0x8E, 0x1F, 0x8E, 0x39, 0x8E, 0x0F, 0x07, 0x87, 0x1C, 0x0E, 0x3F, 0x07,
        0x0F, 0xC3, 0x9F, 0x1C, 0x40, 0xCC, 0xF2, 0x38, 0xF6, 0x3E, 0x3E, 0x07,
        0x30, 0xF8, 0xFE, 0x7E, 0x77, 0x03, 0x1E, 0x03, 0xC7, 0x03, 0xE0, 0x71,
        0xC7, 0x8F, 0x41, 0x0F, 0x07, 0xE0, 0xE1, 0x9C, 0x70, 0x3C, 0x1E, 0x1E,
        0x43, 0xE3, 0xB8, 0xDC, 0x78, 0x67, 0x03, 0x0F, 0x87, 0xE0, 0xF0, 0x78,
        0x1C, 0xC7, 0x1F, 0x86, 0x1F, 0xC7, 0xE1, 0xC0, 0x7C, 0x1E, 0x1E, 0x33,
        0x81, 0xC0, 0xFE, 0x66, 0x71, 0x9F, 0x03, 0xC1, 0xF8, 0x0F, 0x07, 0x00,
        0x60, 0x38, 0xF0, 0x3C, 0xC3, 0x39, 0xCF, 0x87, 0xC1, 0xF0, 0x0E, 0x1E,
        0x38, 0xF8, 0x0F, 0x00, 0xF8, 0xF0, 0x18, 0xC7, 0x98, 0x3F, 0x87, 0xE1,
        0xC0, 0x7F, 0x0D, 0xC7, 0xC1, 0xC0, 0xF0, 0xFC, 0x7C, 0x3F, 0x01, 0xF8,
        0xE1, 0xE1, 0xC0, 0xF0, 0x3E, 0x0F, 0x83, 0xC0, 0xE7, 0x1F, 0x83, 0xF8,
        0xF8, 0x79, 0xCF, 0xC1, 0xF0, 0xFC, 0x00, 0x18, 0x00, 0x38, 0x00, 0x00,
        0x00, 0x00, 0x00, 0xF0, 0x7E, 0x02, 0x00, 0x00, 0x00, 0x03, 0xDF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x00,
        0x38, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xEF, 0xE1,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x06, 0x3F, 0xFE, 0xFC, 0x3F,
        0x1F, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFD, 0xFF, 0xFF,
        0xFF, 0xF1, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x01,
        0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x20, 0x00, 0x01, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x02,
        0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x38, 0xFF, 0xFF, 0xF8, 0x00, 0x00,
        0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8,
        0x70, 0x00, 0x00, 0x00, 0x00, 0x03, 0xC0, 0x00, 0x00, 0x00, 0x00, 0xFF,
        0xB8, 0x01, 0x7F, 0xF8, 0x00, 0x00, 0xC0, 0xFE, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40,
        0xFF, 0x1F, 0x7E, 0x70, 0xE0, 0x3F, 0xE0, 0x40, 0x00, 0x80, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDF,
        0xFF, 0xFF, 0xFF, 0xBF, 0x0E, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
    ),
    "K": (
        0x00, 0x00, 0x01, 0xE0, 0x00, 0x01, 0x00, 0x00, 0x00, 0xF0, 0x00, 0x03,
        0xC0, 0x00, 0x06, 0x1C, 0x80, 0x08, 0x00, 0x00, 0x80, 0xE0, 0x70, 0x00,
        0x8C, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x40, 0x00, 0x00,
        0x0C, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x02,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0xC0,
        0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x01, 0x00, 0x00, 0x00, 0x00,
        0x08, 0x02, 0x04, 0x01, 0x00, 0x00, 0x00, 0x00, 0x01, 0x88, 0x60, 0x0F,
        0xE3, 0x83, 0xF9, 0xC3, 0xF9, 0xE0, 0x0F, 0xFC, 0x00, 0xFF, 0xC0, 0x07,
        0xF8, 0x06, 0x3E, 0x0F, 0x03, 0xF8, 0x60, 0x7E, 0x00, 0xE0, 0x7E, 0x78,
        0x07, 0xF7, 0x01, 0xFF, 0xE0, 0x03, 0xFF, 0x00, 0xFF, 0xE0, 0x01, 0xFE,
        0x00, 0x1F, 0xFF, 0x00, 0xFF, 0xC0, 0x3F, 0xFC, 0x03, 0x87, 0x40, 0x0F,
        0xFE, 0x00, 0xFF, 0x00, 0x03, 0xFB, 0x00, 0xFF, 0x00, 0x07, 0x97, 0xC0,
        0x0F, 0xF0, 0x0D, 0xFF, 0x00, 0x0F, 0xB8, 0x01, 0xFE, 0x00, 0x3F, 0xB8,
        0x03, 0x3E, 0xC0, 0x3F, 0xF8, 0x06, 0x7F, 0x00, 0xCF, 0x80, 0x03, 0xFE,
        0x00, 0x83, 0xE0, 0x00, 0x7C, 0x0F, 0xFF, 0x01, 0xDF, 0xC0, 0x0F, 0xC7,
        0xE0, 0x10, 0x1E, 0x07, 0x87, 0xC0, 0xF1, 0xF8, 0x63, 0x1C, 0xE0, 0x00,
        0xFC, 0x00, 0x1F, 0x07, 0x07, 0x81, 0xE7, 0xE0, 0xDE, 0x3C, 0x0F, 0x8F,
        0x01, 0xFE, 0x7C, 0x3F, 0xBD, 0x83, 0xF1, 0xC0, 0x3D, 0xC4, 0x78, 0x3E,
        0x0E, 0x7F, 0x80, 0xFF, 0xE0, 0x03, 0xDC, 0x43, 0x07, 0xFC, 0x03, 0xC0,
        0x70, 0xF8, 0x7E, 0x1F, 0x0F, 0x07, 0xC1, 0xF0, 0x78, 0x3E, 0x3F, 0x07,
        0xEF, 0x81, 0xC1, 0xF0, 0xF8, 0x0F, 0xFC, 0x07, 0xFE, 0x03, 0xE0, 0x00,
        0x38, 0x1F, 0x8F, 0x87, 0xC0, 0xF0, 0x1F, 0x07, 0xC7, 0x81, 0xE0, 0xFE,
        0x18, 0x0F, 0xC0, 0x07, 0xFF, 0x80, 0xFF, 0x80, 0x0F, 0xFE, 0x07, 0xCF,
        0xC1, 0x00, 0xFC, 0x04, 0x0F, 0x87, 0x80, 0xFF, 0x78, 0x1F, 0xFE, 0x07,
        0x7F, 0x03, 0xEF, 0xE0, 0x00, 0xFF, 0x00, 0x1F, 0xE0, 0x1F, 0x8F, 0x0F,
        0x03, 0xC1, 0xE0, 0x7C, 0xF8, 0x38, 0x7F, 0x07, 0x1F, 0x8F, 0x86, 0x31,
        0xFE, 0x00, 0x0F, 0xF0, 0x01, 0xFC, 0xC0, 0x1F, 0xCF, 0x00, 0x0F, 0xE0,
        0x30, 0x7E, 0x3C, 0x1F, 0xFC, 0x01, 0xFF, 0xC0, 0x3F, 0xF8, 0x01, 0xFF,
        0x00, 0x03, 0xFC, 0x00, 0x07, 0xC7, 0x80, 0x3F, 0xC0, 0xF0, 0x7C, 0x00,
        0x1F, 0xE0, 0xF0, 0x70, 0xF8, 0x3F, 0x8C, 0x07, 0x83, 0xE1, 0xF0, 0xFC,
        0x00, 0x1F, 0x80, 0x07, 0xC3, 0x03, 0x73, 0x80, 0x76, 0x78, 0x3C, 0x00,
        0xF0, 0x38, 0x38, 0x1F, 0x0E, 0x1C, 0xF0, 0x00, 0xF0, 0xC0, 0x1C, 0x38,
        0x01, 0xCE, 0x38, 0xEE, 0x7F, 0xFC, 0xE0, 0x7F, 0x80, 0x0F, 0xF0, 0x00,
        0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x7F, 0xFF, 0xFC, 0x07, 0xFF, 0x1E, 0x7F,
        0xCF, 0x9F, 0x80, 0x00, 0x00, 0x30, 0x0E, 0x00, 0xFF, 0x80, 0xFF, 0xF0,
        0x18, 0x00, 0x00, 0x00, 0x01, 0x07, 0x38, 0xFF, 0x00, 0x3F, 0xF0, 0x1B,
        0x3F, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFC, 0x7F, 0xFE, 0x07,
        0xFF, 0xC3, 0xDF, 0xF8, 0x1C, 0x3F, 0xF8, 0x00, 0xEF, 0x00, 0x1F, 0xF7,
        0x0F, 0xFF, 0x01, 0xC0, 0xFE, 0xC0, 0x1F, 0xF8, 0x00, 0x07, 0x80, 0x00,
        0x00, 0x00, 0x0F, 0x00, 0x00, 0xFF, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8,
        0x1C, 0x0F, 0x03, 0x8F, 0xC0, 0x00, 0xFE, 0x3E, 0x7F, 0xFF, 0xFF, 0xDF,
        0xFF, 0xFF, 0xF8, 0x00, 0x7E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x07,
        0xFF, 0xC0, 0xE7, 0xFF, 0xF0, 0x3F, 0xF0, 0x04, 0x1F, 0xC0, 0x07, 0xFE,
        0x00, 0x10, 0xFC, 0x00, 0x00, 0x30, 0x01, 0xDF, 0x00, 0x1F, 0x01
    ),
    "W": (
        0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0x9C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFC, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00,
        0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x7F,
        0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x1F, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF,
        0xFF, 0xC0, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x0F,
        0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFE, 0x00, 0x00,
        0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0x00,
        0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x7F, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xC0,
        0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00,
        0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF,
        0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0x3F, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0x80, 0x00,
        0x00, 0x07, 0x80, 0xF0, 0x08, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00,
        0xC7, 0xFF, 0xFF, 0xC3, 0xC0, 0x00, 0x00, 0x40, 0x00, 0x00, 0x3F, 0xFF,
        0xFF, 0xFC, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0x3F, 0x00,
        0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x0F, 0x8F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xF8, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x33, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x03, 0xFF, 0xFE, 0x0F, 0xFF, 0xFF, 0xFF,
        0xE0, 0x00, 0x03, 0x01, 0xFF, 0xFF, 0x9F, 0x80, 0x00, 0x0C, 0x03, 0xE0,
        0x01, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFE, 0x00,
        0x00, 0x70, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xC0, 0x0C, 0x7F, 0xFF, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF,
        0xC0, 0x00, 0x00, 0x01, 0xF8, 0x30, 0x00, 0x0F, 0xFF, 0xF8, 0x00, 0x00,
        0x01, 0xFF, 0xFE, 0x00, 0x00, 0x0F, 0xFF, 0xF0, 0x00, 0x00, 0x03, 0xFF,
        0xFF, 0xFE, 0x00, 0x00, 0x03, 0xFF, 0xE0, 0x00, 0x1F, 0xFF, 0xFF, 0x00,
        0x00, 0x00, 0x7F, 0xFF, 0xFC, 0x00, 0x00, 0xFF, 0xE0, 0x00, 0x00, 0x00,
        0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x03, 0xFF, 0xE0, 0x00, 0x00, 0x7F, 0xFF,
        0x00, 0x00, 0x00, 0x3F, 0xFC, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xC0
    ),
    "Y": (
        0x00, 0x00, 0x30, 0x00, 0x04, 0x00, 0x06, 0x00, 0xC7, 0x80, 0x00, 0x00,
        0x00, 0x00, 0xF0, 0x03, 0x00, 0xC0, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x60, 0x03, 0xC7, 0xFC, 0x7F, 0x00, 0xFC, 0x07, 0x83, 0xC0,
        0x7F, 0xF1, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0xFC, 0x02, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x3E, 0x07, 0xF7, 0xFF, 0xFF, 0xF9, 0xFF, 0xFF,
        0x87, 0xF0, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x78, 0x3F,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC3, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x01, 0xF0, 0x1F, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7F,
        0xC0, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE1, 0xF8, 0xFF, 0xFF,
        0xFF, 0xF8, 0x7F, 0x00, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F,
        0x01, 0xFC, 0xFF, 0x9F, 0xFF, 0xFF, 0xFF, 0xE1, 0xFE, 0x00, 0xF0, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0xFE,
        0x03, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0x03, 0xF0, 0xFC,
        0x3F, 0xFF, 0xFF, 0xFF, 0xC3, 0xF8, 0x01, 0xF8, 0x00, 0x80, 0x00, 0x00,
        0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0xF0, 0xFF, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x03, 0xFF, 0xFE, 0x1F, 0xFF, 0xFF,
        0xFF, 0xE0, 0xFC, 0x03, 0xE0, 0x00, 0x00, 0x00, 0xF0, 0x1F, 0xF3, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0xFC, 0x00, 0xC0, 0x00, 0x00, 0x00, 0x1C,
        0x00, 0x80, 0xFF, 0xFF, 0xFF, 0xFC, 0x3F, 0xEF, 0xFF, 0xFF, 0x81, 0xF0,
        0x01, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0x7F, 0x01, 0xF8, 0x00, 0x80, 0x00, 0x00, 0x00, 0x3C, 0x00, 0x03, 0xFF,
        0xFF, 0xFF, 0xFC, 0x7F, 0xFC, 0x3F, 0xFE, 0x00, 0xC0, 0x00, 0x00, 0x00,
        0x00, 0x0F, 0xF0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x0F, 0x80,
        0x03, 0x80, 0x00, 0x7C, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0,
        0xFF, 0xC0, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0xFC, 0x00, 0xFF, 0xF1,
        0xFF, 0xFF, 0xFF, 0xFE, 0x07, 0xC0, 0x00, 0x0F, 0x00, 0x03, 0x80, 0x00,
        0xFC, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x1F, 0xC0, 0x00, 0x00, 0x00,
        0x1C, 0x00, 0x80, 0x3F, 0xF0, 0x7F, 0xFE, 0x1F, 0xFC, 0x1F, 0xFF, 0x03,
        0xFF, 0x0F, 0xC0, 0x00, 0x1F, 0x00, 0x0F, 0x00, 0x01, 0xFC, 0x1F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xF8, 0x0F, 0x80, 0x00, 0x00, 0x00, 0x3F, 0x03, 0xFF,
        0xFF, 0xE0, 0xFF, 0x00, 0x1F, 0xC0, 0x07, 0xF8, 0x1F, 0xFF, 0xFF, 0xFF,
        0xFF, 0xE0, 0x03, 0xE0, 0x00, 0x78, 0x00, 0x3F, 0x83, 0xFF, 0xFF, 0xFF,
        0xDF, 0xFF, 0x00, 0x38, 0x00, 0x00, 0x00, 0x03, 0xFC, 0xFF, 0xFF, 0xFF,
        0xF0, 0x01, 0xC0, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFE, 0x00, 0x00, 0x78, 0x00, 0x1F, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF,
        0xC0, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x7F, 0x03, 0xFF, 0xE7, 0xFF, 0xF0, 0x7F, 0x00,
        0x7F, 0x00, 0xFF, 0xFF, 0xFF, 0x00, 0xFC, 0x00, 0x1E, 0x01, 0x0F, 0xF0,
        0xFF, 0xF0, 0x3F, 0xE0, 0x20, 0x00, 0x03, 0xE0, 0x03, 0xFF, 0xFF, 0xFF,
        0xC3, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8,
        0x00, 0x00, 0x00, 0x7E, 0x01, 0xFF, 0xFF, 0xFF, 0xE1, 0xFF, 0x00, 0x3C,
        0x03, 0xFF, 0xFE, 0x01, 0xF8, 0x00, 0x78, 0x1F, 0xFF, 0xC0, 0xFF, 0x01,
        0xFF, 0x00, 0xFC, 0x1E, 0x0F, 0xE0, 0xFF, 0xDE, 0xFF, 0x83, 0x80, 0x00,
        0x0E, 0x00, 0x03, 0xF0, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x10,
        0x0F, 0xF0, 0xF8, 0xFE, 0x07, 0xF0, 0x00, 0x00, 0x18, 0x78, 0x79, 0xFE,
        0x0C, 0x3F, 0x06, 0x00, 0x01, 0xF0, 0xF0, 0x7F, 0xFF, 0xE1, 0x81, 0xE1,
        0xE0, 0x00, 0x07, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0xC0, 0x03, 0xFF, 0xF0,
        0xFC, 0x3F, 0x1E, 0x00, 0x00, 0x1C, 0x1F, 0x0F, 0xFF, 0xFE, 0x3C
    ),
    "R": (
        0xFF, 0xF8, 0x07, 0x0F, 0xFF, 0xF0, 0x00, 0x00, 0x01, 0xF0, 0xFE, 0x3F,
        0x87, 0xF3, 0xFF, 0xFC, 0x00, 0x00, 0x1F, 0xFF, 0x00, 0x01, 0xFF, 0xFF,
        0xC0, 0x00, 0x01, 0xF0, 0x00, 0x07, 0xFF, 0xFE, 0x00, 0x0F, 0xFF, 0xFF,
        0xFF, 0xFF, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xF0, 0x00, 0x1F, 0xFF, 0xE0,
        0x00, 0x00, 0x03, 0xE1, 0xFF, 0xFF, 0x1F, 0xFF, 0xFF, 0xF8, 0x00, 0x00,
        0x3F, 0xFF, 0x00, 0x07, 0xFF, 0xFF, 0x00, 0x00, 0x03, 0xC0, 0x00, 0x1F,
        0xFF, 0xFF, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0xFF,
        0xFF, 0xC0, 0x00, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x1F, 0x87, 0xF3, 0xFC,
        0x7F, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x3F, 0xFC, 0x00, 0x0F, 0xFF, 0xFE,
        0x00, 0x00, 0x07, 0x80, 0x00, 0x3F, 0xFF, 0xFE, 0x00, 0x7F, 0xFF, 0xFF,
        0xFF, 0xF0, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0x00, 0x01, 0xFF, 0xFE, 0x00,
        0x00, 0x00, 0x7E, 0x1F, 0xCF, 0xF1, 0xFC, 0xFF, 0xFF, 0x80, 0x00, 0x01,
        0xFF, 0xF0, 0x00, 0x7F, 0xFF, 0xFC, 0x00, 0x00, 0x7E, 0x00, 0x01, 0xFF,
        0xFF, 0xF8, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x07, 0xFF,
        0xFE, 0x00, 0x07, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0xF8, 0x7F, 0xFF, 0xE7,
        0xF3, 0xFF, 0xFE, 0x00, 0x00, 0x01, 0xFF, 0xC0, 0x00, 0xFF, 0xFF, 0xF0,
        0x00, 0x00, 0x68, 0x00, 0x01, 0xFF, 0xFF, 0xF8, 0x03, 0xFF, 0xFF, 0xFF,
        0xFF, 0xE0, 0x00, 0x00, 0x0F, 0xFF, 0xFC, 0x00, 0x0F, 0xFF, 0xF8, 0x00,
        0x00, 0x00, 0xF0, 0xFF, 0xFF, 0xCF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x03,
        0xFF, 0xE0, 0x00, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0xF0, 0x00, 0x07, 0xFF,
        0xFF, 0xFC, 0x07, 0xFF, 0xFF, 0xE7, 0xFF, 0xE0, 0x00, 0x00, 0x07, 0xFF,
        0xFC, 0x00, 0x07, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0xF8, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x01, 0xFF, 0xC0, 0x00, 0xFF, 0xFF, 0xF0,
        0x00, 0x00, 0x30, 0x00, 0x01, 0xFF, 0xFF, 0xF8, 0x01, 0xFF, 0xFF, 0xBF,
        0xFF, 0xE0, 0x00, 0x00, 0x07, 0xFF, 0xFC, 0x00, 0x07, 0xFF, 0xFC, 0x00,
        0x00, 0x00, 0xF8, 0x7F, 0xFF, 0xC7, 0xFB, 0xFF, 0xFE, 0x00, 0x00, 0x01,
        0xFF, 0xC0, 0x00, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0xF8, 0x00, 0x03, 0xFF,
        0xFF, 0xC0, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x3F, 0xFF,
        0xF0, 0x00, 0x3F, 0xFF, 0xE0, 0x00, 0x00, 0x03, 0xE1, 0xFE, 0xFF, 0x1F,
        0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x1F, 0xFE, 0x00, 0x07, 0xFF, 0xFF, 0x00,
        0x00, 0x03, 0xC0, 0x00, 0x0F, 0xFF, 0xFF, 0x80, 0x1F, 0xFF, 0xFF, 0xFF,
        0xFE, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xC0, 0x00, 0x7F, 0xFF, 0xC0, 0x00,
        0x00, 0x0F, 0x83, 0xF1, 0xFE, 0x3F, 0x9F, 0xFF, 0xE0, 0x00, 0x00, 0xFF,
        0xFC, 0x00, 0x0F, 0xFF, 0xFE, 0x00, 0x00, 0x0F, 0x80, 0x00, 0x3F, 0xFF,
        0xFE, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x7F, 0xFF,
        0xC0, 0x00, 0x7F, 0xFF, 0xC0, 0x00, 0x00, 0x0F, 0x87, 0xFB, 0xFE, 0x7F,
        0xFF, 0xFF, 0xE0, 0x00, 0x00, 0xFF, 0xFC, 0x00, 0x0F, 0xFF, 0xFF, 0x00,
        0x00, 0x0F, 0x00, 0x00, 0x3F, 0xFF, 0xFC, 0x00, 0x0F, 0xFF, 0xFF, 0xFF,
        0xFC, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xC0, 0x00, 0xFF, 0xFF, 0x80, 0x00,
        0x00, 0x1F, 0x0F, 0xF7, 0xFC, 0x7F, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0xFF,
        0xF8, 0x00, 0x1F, 0xFF, 0xFC, 0x00, 0x00, 0x1F, 0x00, 0x00, 0xFF, 0xFF,
        0xFC, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x01, 0xFF, 0xFF,
        0x00, 0x01, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x3F, 0x1F, 0xEF, 0xF8, 0xFF,
        0xFF, 0xFF, 0x80, 0x00, 0x01, 0xFF, 0xF8, 0x00, 0x07, 0xFF, 0xFF, 0x80,
        0x00, 0x00, 0x0E, 0x00, 0x6F, 0xFF, 0xFF, 0x80, 0x00, 0xFF, 0xFF, 0xFF,
        0xF0, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0x00, 0x01, 0xFF, 0xFF, 0x00, 0x00,
        0x00, 0x7F, 0x1F, 0xCF, 0xF1, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF,
        0xF0, 0x00, 0x7F, 0xFF, 0xF0, 0x00, 0x00, 0x3C, 0x00, 0x01, 0xFF
    ),
    "L": (
        0xFE, 0xF0, 0x00, 0x00, 0x00, 0xF0, 0xFF, 0xFF, 0xFF, 0xFF, 0x06, 0x00,
        0x00, 0x00, 0x1C, 0x1F, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00,
        0x02, 0x07, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00,
        0x03, 0x8F, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x01, 0xE1, 0xFF,
        0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x38, 0x3F, 0xFF, 0xFF, 0xFF,
        0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x9F, 0xFF, 0xFF, 0xFF, 0xFF,
        0xC0, 0x00, 0x00, 0x00, 0x00, 0x07, 0x1F, 0xFF, 0xFF, 0xFF, 0xFC, 0x80,
        0x00, 0x00, 0x03, 0x83, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00,
        0x70, 0x7F, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F,
        0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x07, 0x9F, 0xFF, 0xFF, 0xFF,
        0xF8, 0x18, 0x00, 0x00, 0x00, 0x70, 0x7F, 0xFF, 0xFF, 0xFF, 0xF0, 0x00,
        0x00, 0x00, 0x00, 0x08, 0x1F, 0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0x03, 0x07, 0xFF, 0xFF, 0xFF, 0xFC, 0x1C, 0x00, 0x00, 0x00, 0x38, 0x7F,
        0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x08, 0x1F, 0xCF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x03, 0xCF, 0xFF, 0xFF,
        0xFF, 0xFE, 0x00, 0x00, 0x00, 0x03, 0xC1, 0xFF, 0xFF, 0xFF, 0xFE, 0x00,
        0x00, 0x00, 0x00, 0x38, 0x3F, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00,
        0x00, 0x04, 0x0F, 0xDF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00,
        0x00, 0x07, 0x8F, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x01, 0xC3,
        0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x0E, 0x1F, 0xFF, 0xFF,
        0xFF, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x03, 0x07, 0xFF, 0xFF, 0xFF, 0xFF,
        0xF9, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFE,
        0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00,
        0x00, 0x07, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x01,
        0x83, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x7D, 0xFF, 0xFF,
        0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x01, 0xC1, 0xFF, 0xFF, 0xFF, 0xFF,
        0xC0, 0x00, 0x00, 0x00, 0x00, 0x38, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xBE,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00,
        0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00,
        0x38, 0x7F, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x0E, 0x1F,
        0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF,
        0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFE, 0x00, 0x00, 0x00, 0x00, 0x07, 0x1F, 0xFF, 0xFF, 0xFF, 0xFE, 0x00,
        0x00, 0x00, 0x00, 0x01, 0x87, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB, 0xE0, 0x00,
        0x00, 0x00, 0x00, 0x01, 0xEF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00,
        0x00, 0xF1, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x07, 0x0F,
        0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x01, 0x83, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFC, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0xFD, 0xFF, 0xFF, 0xFF, 0xFE, 0x00,
        0x00, 0x00, 0x00, 0x0C, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0x00, 0x03, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00,
        0x00, 0x01, 0xF7, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0xF0,
        0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x38, 0x3F, 0xFF, 0xFF,
        0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x04, 0x0F, 0xDF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x01, 0xF3, 0xFF, 0xFF, 0xFF
    ),
    "M": (
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00,
        0xF8, 0x0C, 0x00, 0x00, 0x00, 0x3E, 0x07, 0x81, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xF0, 0x1F, 0xFF, 0x07, 0x80, 0x20, 0x00, 0x00, 0x00, 0x00, 0x0C,
        0x00, 0x00, 0x78, 0x00, 0x0C, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x01, 0xF0, 0x18, 0x00, 0x00, 0x00, 0x7E,
        0x07, 0x81, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x3F, 0xFF, 0x0F, 0x80,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x03, 0x06, 0x0F,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x01,
        0xF0, 0x18, 0x00, 0x00, 0x00, 0x7C, 0x07, 0x83, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xF0, 0x3F, 0xFE, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x3C, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x03, 0xE0, 0x60, 0x00, 0x00, 0x00, 0xF8,
        0x1E, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0xFF, 0xFC, 0x3E, 0x00,
        0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x1C, 0x3E, 0x00, 0x0E, 0x00, 0x7F,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x3F,
        0x03, 0x00, 0x00, 0x00, 0x0F, 0x80, 0xE0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFE, 0x0F, 0xFF, 0xC3, 0xE0, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x01, 0xE0, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xF8, 0x01, 0xF0, 0x38, 0x00, 0x00, 0x00, 0x7C, 0x0F,
        0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x7F, 0xFE, 0x0F, 0x00, 0x40,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xF8, 0x00, 0x00, 0x0F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x1F, 0x01,
        0x80, 0x00, 0x00, 0x07, 0xC0, 0xF0, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0x03, 0xFF, 0xE1, 0xF0, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0xC0,
        0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFC, 0x00, 0xF8, 0x0C, 0x00, 0x00, 0x00, 0x3E, 0x07, 0x81,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x1F, 0xFF, 0x0F, 0x80, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFC, 0x10, 0x00, 0x01, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x1F, 0x01, 0x80,
        0x00, 0x00, 0x07, 0xC0, 0xF0, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x07,
        0xFF, 0xE1, 0xF0, 0x00, 0x00, 0x01, 0x80, 0x00, 0x00, 0x00, 0x01, 0x00,
        0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFC, 0x00, 0xF8, 0x1C, 0x00, 0x00, 0x00, 0x3E, 0x07, 0x81, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x3B, 0xFF, 0x0F, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x07, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x07, 0xC0, 0xC0, 0x00,
        0x00, 0x01, 0xF0, 0x3C, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x81, 0xFF,
        0xF8, 0xFC, 0x02, 0x00, 0x00, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0x00, 0x3E, 0x07, 0x00, 0x00, 0x00, 0x0F, 0x81, 0xE0, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFE, 0x0F, 0xFF, 0xC3, 0xC0, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x18, 0x08, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x01, 0xF0, 0x18, 0x00, 0x00,
        0x00, 0x7C, 0x0F, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x7F, 0xFE,
        0x1F, 0x00, 0x80, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xC0, 0x00,
        0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0x00, 0x7E, 0x02, 0x00, 0x00, 0x00, 0x1F, 0x81, 0xE0, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFE, 0x0F, 0xFF, 0xC3, 0xC0, 0x00, 0x00, 0x02, 0x00
    ),
    "N": (
        0x01, 0xFF, 0xFF, 0x00, 0x00, 0x18, 0x78, 0x00, 0x00, 0x0E, 0x00, 0x00,
        0x01, 0xFF, 0xF1, 0xE0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0x00, 0x1F, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x0F, 0xFF, 0xFC, 0x00, 0x00, 0x03, 0x00,
        0x00, 0x00, 0x1C, 0x00, 0x00, 0x0F, 0xFF, 0xE7, 0x07, 0xFF, 0xFF, 0xEF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0xFE, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x3F, 0xFF,
        0xE0, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0xE0, 0x00, 0x00, 0x3F, 0xFF,
        0x1C, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0,
        0x03, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0x00, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x38, 0x00, 0x00, 0x07,
        0x80, 0x00, 0x00, 0xFF, 0xFE, 0x38, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x0F, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x07, 0xFF, 0xFE, 0x00, 0x00,
        0x01, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xE0, 0x40, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x3F, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0,
        0x0F, 0xFF, 0xFC, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x0F, 0xFF, 0xE1, 0x41, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xF8, 0x00, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x7F, 0xFF, 0xE0, 0x00, 0x00, 0x1E, 0x00,
        0x00, 0x00, 0x00, 0x1C, 0x00, 0x1F, 0xFF, 0x1F, 0x1F, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x1F, 0x80, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x07, 0xF9, 0xFE,
        0x00, 0x00, 0x03, 0xE0, 0x00, 0x00, 0x0F, 0x00, 0x00, 0x07, 0xFF, 0xF9,
        0xF0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00,
        0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xC0, 0x3F, 0xFF, 0xF0, 0x00, 0x00, 0x0F, 0x80, 0x00, 0x00, 0x70,
        0x00, 0x00, 0x3F, 0xFF, 0xF8, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0x80, 0x0F, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x07, 0xFF, 0xFF, 0x00, 0x00, 0x03,
        0xF0, 0x00, 0x00, 0x1E, 0x00, 0x00, 0x07, 0xFF, 0x0F, 0x80, 0x7F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x7E, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0x3F, 0xFF, 0xFF, 0xC0, 0x1F,
        0xFF, 0xF8, 0x00, 0x00, 0x0F, 0x80, 0x00, 0x00, 0x1E, 0x00, 0x00, 0x3F,
        0xFC, 0x3C, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xF8, 0x00, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF,
        0x7F, 0xFF, 0xFF, 0x80, 0x7F, 0x9F, 0xF0, 0x00, 0x00, 0x1F, 0x00, 0x00,
        0x00, 0x7E, 0x00, 0x80, 0x7F, 0xF8, 0x7C, 0x01, 0xFF, 0xFF, 0xFE, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x01, 0xF8, 0x00, 0x00, 0x00, 0x00,
        0x0C, 0x00, 0xFF, 0xFF, 0xFE, 0xFF, 0xFF, 0xFF, 0x80, 0x7F, 0x9F, 0xF0,
        0x00, 0x00, 0x1F, 0x00, 0x00, 0x00, 0x7C, 0x00, 0x80, 0x7F, 0xF8, 0x7B,
        0x43, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x07,
        0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xF9, 0xFF, 0xFF,
        0xFE, 0x01, 0xFE, 0x3F, 0xC0, 0x00, 0x00, 0x7C, 0x00, 0x00, 0x01, 0xF8,
        0x06, 0x01, 0xFF, 0xC1, 0xF8, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0x00, 0x1F, 0x80, 0x00, 0x00, 0x00, 0x01, 0x80, 0x0F,
        0xFF, 0xFF, 0xCF, 0xFF, 0xFF, 0xF8, 0x07, 0xF8, 0xFF, 0x00, 0x00
    ),
    "S": (
        0x07, 0x81, 0xF0, 0xE0, 0xF0, 0x78, 0x3E, 0x38, 0xF1, 0x98, 0x78, 0x7E,
        0x1F, 0x0F, 0x0E, 0x3C, 0x70, 0x78, 0x3C, 0x1E, 0x00, 0xCE, 0x3C, 0x3F,
        0x0F, 0x03, 0xE1, 0xE1, 0x18, 0x0E, 0x01, 0xE0, 0xF0, 0xF8, 0x7C, 0x78,
        0xFE, 0x3E, 0x0F, 0x0F, 0x83, 0xE0, 0xE0, 0xE0, 0xF0, 0xF0, 0x7C, 0x3C,
        0x3C, 0x3E, 0x3E, 0x1E, 0x0F, 0x07, 0x78, 0xFC, 0x3C, 0x3C, 0x71, 0x87,
        0x38, 0x7C, 0x1E, 0x1F, 0x00, 0xF0, 0xF8, 0x7C, 0x63, 0xF1, 0xE0, 0xF8,
        0x7E, 0x1E, 0x07, 0x87, 0x83, 0x1E, 0x1E, 0x1F, 0x81, 0xE1, 0xE0, 0x70,
        0xF0, 0xF8, 0x78, 0x70, 0xFE, 0x07, 0x0F, 0x00, 0xF0, 0xF8, 0xF8, 0x3C,
        0x3C, 0x1F, 0x0F, 0x01, 0xC0, 0xE0, 0x63, 0x83, 0x87, 0x81, 0xE0, 0xF0,
        0xF8, 0x3C, 0x70, 0x0E, 0x00, 0x38, 0xC6, 0x1E, 0x43, 0x8C, 0x70, 0x78,
        0x3F, 0x0F, 0x87, 0xE1, 0xF8, 0x7C, 0x3B, 0xC3, 0xC0, 0xE1, 0xE1, 0xE0,
        0xE1, 0xE1, 0xE0, 0xF8, 0x7C, 0x03, 0x87, 0x18, 0xF0, 0xE0, 0x61, 0xC1,
        0xE7, 0x3C, 0x38, 0xC0, 0xE0, 0x3C, 0x0F, 0x38, 0xFE, 0x1F, 0x83, 0xE1,
        0xE0, 0x78, 0xF0, 0x01, 0xC3, 0xC1, 0xE1, 0xC0, 0xF0, 0x78, 0x3E, 0x1F,
        0x00, 0xF0, 0xF0, 0x78, 0x78, 0x1E, 0x39, 0xC3, 0xC1, 0x3E, 0x1E, 0x0F,
        0x1D, 0xC3, 0xC1, 0xE1, 0xC0, 0x1F, 0x1F, 0xC3, 0xC3, 0xE0, 0xF8, 0x3E,
        0x1F, 0x07, 0x87, 0xC0, 0xC7, 0x07, 0x07, 0xC0, 0xF8, 0xF0, 0xF0, 0x07,
        0x07, 0x80, 0xF8, 0x7E, 0x1E, 0x3E, 0x17, 0x87, 0x0F, 0x03, 0xC3, 0xE3,
        0xE0, 0xFF, 0x07, 0x80, 0x38, 0x0E, 0x03, 0xC1, 0xC1, 0xE1, 0xF0, 0xF0,
        0x47, 0xC0, 0xF8, 0x7C, 0x3E, 0x1E, 0x19, 0x87, 0x80, 0xF0, 0x7C, 0x1E,
        0x0E, 0xF0, 0xE0, 0xF0, 0xC7, 0x07, 0xE0, 0x7C, 0x3C, 0x3F, 0x03, 0xC3,
        0xC1, 0xE0, 0xF8, 0x7F, 0x0F, 0x18, 0xE0, 0xE0, 0xF0, 0x78, 0x3F, 0x0F,
        0x80, 0xF0, 0xF8, 0x0F, 0x0F, 0x1F, 0x07, 0x83, 0xE0, 0xF1, 0x9C, 0x07,
        0x03, 0x1C, 0x70, 0xC7, 0x03, 0x87, 0xC1, 0xF0, 0xF0, 0xFC, 0x3E, 0x0F,
        0x87, 0x83, 0xC0, 0xF8, 0x78, 0x79, 0xC7, 0x3C, 0x70, 0x7E, 0x1C, 0x71,
        0x87, 0x1E, 0x1E, 0x3E, 0x1F, 0x03, 0x86, 0x1E, 0x1F, 0x01, 0xC3, 0xC3,
        0xE0, 0xF0, 0xF0, 0xF8, 0x3C, 0x1F, 0x07, 0x1E, 0x38, 0xF8, 0x70, 0x3E,
        0x3F, 0x83, 0xC0, 0x78, 0x71, 0xE0, 0xF8, 0x0F, 0x0F, 0x00, 0xF0, 0x1E,
        0x1F, 0x0F, 0x1F, 0x0F, 0xC1, 0xF1, 0xF8, 0xE1, 0xE0, 0xE3, 0x0E, 0x1F,
        0xC3, 0x0F, 0x07, 0x1C, 0x70, 0xF8, 0x78, 0x7C, 0x3E, 0x3C, 0x1F, 0xC3,
        0xC0, 0xF8, 0x30, 0x78, 0x3F, 0x1F, 0x01, 0xF0, 0x7C, 0x3F, 0x1E, 0x3F,
        0x1C, 0x1F, 0x0F, 0x07, 0x83, 0xC0, 0xF0, 0x78, 0x3E, 0x1E, 0x78, 0x71,
        0x87, 0x0F, 0x7E, 0x03, 0xC3, 0x70, 0xE3, 0x07, 0x01, 0xE1, 0xE3, 0x98,
        0xF8, 0x77, 0x01, 0x0C, 0x1C, 0x1C, 0x27, 0x0F, 0x01, 0xC1, 0xC3, 0x80,
        0xC1, 0xF0, 0xF0, 0x7E, 0x1F, 0x0F, 0x07, 0xC3, 0xF0, 0x78, 0x0F, 0x38,
        0xE1, 0xC1, 0xE1, 0xF0, 0x3E, 0x0F, 0x83, 0xC3, 0x87, 0x80, 0xF0, 0xF0,
        0x1F, 0x01, 0xE1, 0xF0, 0xC7, 0x0F, 0x11, 0xC3, 0xC0, 0xF8, 0x7C, 0x3C,
        0x3E, 0x0F, 0x0E, 0x70, 0x8E, 0x3D, 0x87, 0xC7, 0x18, 0xF0, 0x7C, 0x3E,
        0x1F, 0x07, 0x8C, 0xF0, 0x3F, 0x8F, 0x0E, 0x1B, 0xC3, 0x87, 0x07, 0x83,
        0xE0, 0xF0, 0x78, 0xC7, 0x18, 0xE3, 0xC3, 0xE1, 0xE0, 0x7C, 0x3C, 0x71,
        0x9C, 0x70, 0x78, 0xF0, 0xC6, 0x3E, 0x1F, 0x0F, 0x80, 0xE0, 0x1C, 0x3E,
        0x3C, 0x87, 0x0E, 0x71, 0x87, 0x83, 0xC2, 0x3C, 0x3E, 0x1E, 0x18, 0xC7,
        0x83, 0xC3, 0x80, 0xF0, 0xF1, 0x8E, 0x19, 0xC1, 0xC0, 0x78, 0x7C, 0x3C,
        0x0F, 0x87, 0x73, 0x8F, 0x0F, 0x0F, 0x0E, 0x3E, 0x0F, 0x0C, 0xF8, 0x78,
        0x78, 0xC0, 0xF0, 0xE1, 0xC0, 0xF0, 0xF0, 0x1E, 0x1E, 0x10, 0xF0, 0xFF,
        0x83, 0xF1, 0xE3, 0xC0, 0x3C, 0x78, 0xE0, 0xF0, 0xFC, 0x3E, 0x1E, 0x18,
        0xF0, 0x3E, 0x1F, 0x07, 0x81, 0xE1, 0xE3, 0x1C, 0x38, 0x87, 0x83, 0xC1,
        0xCE, 0x1E, 0x0F, 0x1F, 0x0F, 0x83, 0xC1, 0xC3, 0x8F, 0x1E, 0x07
    ),
    "V": (
        0xFF, 0xFF, 0xFF, 0x39, 0xE7, 0xF9, 0xE6, 0x00, 0x00, 0x00, 0x07, 0xF0,
        0x06, 0x07, 0x73, 0xBD, 0xFF, 0xCF, 0xFF, 0xE3, 0x9C, 0x00, 0x03, 0xE7,
        0x7F, 0xCF, 0x3F, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x07, 0xF3, 0xF8, 0xE7,
        0x80, 0x00, 0x00, 0x01, 0xF0, 0x00, 0x00, 0x87, 0xE3, 0xFF, 0xFF, 0xFF,
        0xFF, 0x87, 0x3C, 0x43, 0x9F, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xE7, 0x1E, 0xFF, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x81, 0x00, 0x31, 0x0F,
        0x3E, 0x0F, 0xFF, 0xFE, 0xFF, 0x9E, 0x43, 0x9C, 0x39, 0xE7, 0xFC, 0xCF,
        0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF3, 0xFF, 0x7F, 0x9E, 0x70, 0x00, 0x00,
        0x00, 0x3F, 0x82, 0x1C, 0x71, 0x00, 0xF3, 0xFF, 0xFF, 0xF0, 0xE3, 0xDC,
        0x73, 0x87, 0x1F, 0xE7, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xC1, 0xF8,
        0xE3, 0x00, 0x00, 0x00, 0x00, 0x8C, 0x01, 0x80, 0x40, 0x87, 0xF3, 0x7F,
        0xE7, 0x1F, 0xFF, 0x83, 0x1C, 0xFF, 0x8E, 0xFF, 0xCF, 0xBF, 0xF8, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0x83, 0xFF, 0xCF, 0x20, 0x00, 0x00, 0x00, 0x03, 0x30,
        0x03, 0x0C, 0xE7, 0x1F, 0xFF, 0xBF, 0xDE, 0x7B, 0xC7, 0x39, 0xDF, 0x7F,
        0xCF, 0xFF, 0x9F, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0x1F, 0xFF, 0x00, 0x0C,
        0x00, 0x00, 0x00, 0xE3, 0x00, 0x60, 0x00, 0x7F, 0x7F, 0xFF, 0xFE, 0xE0,
        0x7C, 0x78, 0x61, 0xFB, 0xFF, 0x8F, 0x7F, 0xFF, 0xC0, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xFF,
        0x88, 0x7F, 0xFE, 0xEC, 0x00, 0x00, 0x00, 0x70, 0x03, 0x30, 0x80, 0x07,
        0xDE, 0xFF, 0xF8, 0x7F, 0xF0, 0xEC, 0x09, 0xFE, 0xF1, 0xDF, 0x79, 0xFF,
        0xFF, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xFB, 0xE4, 0x30, 0xC0, 0x1C, 0x40,
        0x3B, 0x00, 0x20, 0x00, 0x47, 0xE7, 0xFF, 0x9C, 0xF7, 0xE0, 0xC3, 0x78,
        0xF7, 0xCE, 0x73, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0xFF,
        0x80, 0x61, 0x00, 0x1C, 0x00, 0x3C, 0x21, 0x80, 0x18, 0xF3, 0xF3, 0xFF,
        0xE7, 0xFC, 0x67, 0x1F, 0x80, 0x01, 0xFC, 0x3F, 0xFF, 0x8F, 0xFE, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xE7, 0xFD, 0xDF, 0xFF, 0x80, 0x42, 0x00, 0x18, 0x06, 0xE0, 0x07,
        0x81, 0x18, 0xE7, 0xFF, 0xEF, 0x79, 0x9C, 0x39, 0xE6, 0x30, 0xFF, 0x1C,
        0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF3, 0x8F, 0xFC, 0x00, 0x60,
        0x00, 0x70, 0x0E, 0xF0, 0x00, 0x00, 0x19, 0xEF, 0xBD, 0xE7, 0xFF, 0xC1,
        0x1F, 0x81, 0x87, 0xFF, 0x81, 0xF0, 0x0F, 0xFF, 0x80, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xF0, 0x7E, 0xF8, 0x00, 0x60, 0x00, 0x30, 0xC0, 0x00, 0xC0, 0x47, 0x3E,
        0xF3, 0x3F, 0xF7, 0xCF, 0x0C, 0xE1, 0xEF, 0x31, 0xC3, 0x8E, 0x78, 0xFF,
        0xBC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xF7, 0xFC, 0xE7, 0xFF, 0xE0, 0x01, 0x84, 0x30, 0x00,
        0x79, 0x90, 0x06, 0x00, 0x3B, 0xFF, 0xFE, 0x3F, 0xCE, 0x31, 0x8E, 0x70,
        0x0F, 0xFD, 0xCF, 0xF8, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x9E, 0x7F
    ),
    "F": (
        0x39, 0xCC, 0xF1, 0xC1, 0x9B, 0x83, 0x18, 0xC7, 0x1C, 0x79, 0x18, 0xF1,
        0x81, 0xF8, 0x80, 0xE6, 0x86, 0x67, 0x18, 0xE4, 0x8F, 0xEC, 0x0E, 0x73,
        0xB8, 0x8E, 0x32, 0x31, 0x81, 0xCC, 0x7C, 0x7E, 0x30, 0x37, 0x78, 0x03,
        0x9C, 0xCB, 0x0C, 0xC1, 0xCE, 0x73, 0x73, 0xE2, 0x67, 0x63, 0x70, 0x8E,
        0x70, 0x1C, 0x3F, 0xE0, 0xC7, 0x0C, 0x71, 0xC3, 0x0F, 0x8E, 0x71, 0xC6,
        0x01, 0xC6, 0x98, 0xC6, 0x3E, 0x6E, 0x70, 0x63, 0x66, 0x73, 0x66, 0xF2,
        0x6E, 0x71, 0xCC, 0xCE, 0xE7, 0x73, 0x07, 0x39, 0x19, 0x22, 0x83, 0x03,
        0xF1, 0x81, 0xE1, 0xE0, 0xE3, 0x83, 0xF9, 0x8F, 0x99, 0x1C, 0x30, 0x1C,
        0xF0, 0x63, 0x31, 0xC6, 0x63, 0x7D, 0x03, 0x03, 0x67, 0x31, 0x00, 0x0E,
        0x73, 0xE0, 0xE1, 0xF6, 0xE3, 0x00, 0xE8, 0xF8, 0xF9, 0x9C, 0x9F, 0x19,
        0x8D, 0x8E, 0xC7, 0x38, 0x39, 0x83, 0x83, 0x81, 0xF8, 0x38, 0xE2, 0x0F,
        0x31, 0xF0, 0x03, 0xCF, 0x03, 0xC0, 0x27, 0x63, 0xC3, 0x63, 0x86, 0x7C,
        0x7C, 0x79, 0xC3, 0x31, 0xF3, 0x33, 0x8F, 0x0F, 0x87, 0x38, 0x71, 0x9C,
        0xC1, 0xCE, 0xE6, 0x7C, 0x60, 0x3E, 0x11, 0xF1, 0x8C, 0xE6, 0x1F, 0x18,
        0xCC, 0xEC, 0x79, 0x3E, 0x2F, 0x1C, 0x39, 0x19, 0xE6, 0x03, 0x61, 0x8F,
        0x04, 0x1F, 0x61, 0xC3, 0x33, 0xFB, 0x3C, 0x66, 0x47, 0xCC, 0xE4, 0xC0,
        0x07, 0x9F, 0x00, 0xE1, 0x38, 0xFF, 0x3D, 0x81, 0x8E, 0xC0, 0xF8, 0x38,
        0xC7, 0x39, 0x83, 0x1C, 0xF3, 0x33, 0x3B, 0x36, 0x3F, 0xC6, 0xE7, 0x06,
        0xE6, 0x67, 0x70, 0xC1, 0xCC, 0x7C, 0xC4, 0x64, 0xC3, 0x11, 0xB9, 0x38,
        0x63, 0x73, 0xE3, 0xE6, 0x70, 0x7E, 0x60, 0xBC, 0xE3, 0xB0, 0x63, 0x36,
        0x73, 0x26, 0x78, 0xCC, 0xE0, 0x9C, 0xF8, 0xDC, 0xCC, 0x9C, 0xC9, 0x9C,
        0x19, 0x1F, 0x3C, 0x01, 0x8F, 0xC7, 0x80, 0xD3, 0x18, 0x19, 0xF1, 0x10,
        0xE2, 0xF0, 0xF8, 0xC9, 0x99, 0x99, 0x98, 0xF1, 0xBC, 0x33, 0x07, 0x03,
        0x61, 0xF0, 0x62, 0x38, 0xE1, 0x98, 0xC1, 0x98, 0xEF, 0x9C, 0xC7, 0x1C,
        0xC1, 0x9C, 0xF3, 0x31, 0xB9, 0xE3, 0x98, 0x63, 0x72, 0x33, 0x07, 0x03,
        0x8E, 0x1F, 0x0C, 0x46, 0x37, 0x3C, 0xE0, 0xE4, 0xF6, 0x60, 0xC6, 0x38,
        0xDC, 0x80, 0xDD, 0x8C, 0xC3, 0x07, 0x18, 0xC6, 0xE1, 0xC7, 0x61, 0x86,
        0x70, 0xE6, 0x30, 0x67, 0x3C, 0x76, 0x66, 0x78, 0x3F, 0x0F, 0x06, 0xCF,
        0xC8, 0xCC, 0x0E, 0x39, 0xC8, 0x98, 0x0E, 0x76, 0xCE, 0x19, 0xCC, 0x8C,
        0xC7, 0x8C, 0xD8, 0xC3, 0x30, 0xCE, 0x78, 0x38, 0xF0, 0xE9, 0x07, 0x1D,
        0x19, 0x98, 0x38, 0x72, 0x33, 0x33, 0x91, 0x04, 0xE3, 0x23, 0x9C, 0xE3,
        0x61, 0xCC, 0xDC, 0xCC, 0xCC, 0x9C, 0xD8, 0x79, 0xCC, 0x01, 0xCF, 0x11,
        0x8E, 0x0F, 0x87, 0x20, 0x63, 0x3B, 0x38, 0x1C, 0x11, 0xF9, 0x39, 0xC3,
        0x07, 0x1F, 0x01, 0x80, 0x5D, 0x84, 0xE5, 0x84, 0x71, 0xC6, 0x3C, 0x07,
        0x0C, 0xC4, 0xFE, 0xC7, 0x8F, 0x1D, 0xCC, 0xC7, 0xEE, 0x63, 0x3C, 0x66,
        0xE4, 0x60, 0xC7, 0x03, 0x1C, 0x8C, 0xEC, 0x64, 0x4C, 0xC6, 0x66, 0xE2,
        0xCE, 0xD1, 0x0E, 0xC0, 0x3C, 0xDC, 0xEE, 0x7C, 0xCC, 0xF3, 0x71, 0x9D,
        0x0C, 0x8F, 0x07, 0x9C, 0x18, 0xFC, 0x83, 0x18, 0x39, 0x98, 0x71, 0xFE,
        0x63, 0xC7, 0x66, 0xC6, 0x46, 0xE6, 0x46, 0xCC, 0xC6, 0xE4, 0xC0, 0xFC,
        0xF1, 0x30, 0x3B, 0x33, 0x18, 0x33, 0x1E, 0x33, 0x0E, 0x3F, 0x0C, 0x19,
        0x37, 0x01, 0xB6, 0xE0, 0xF9, 0x70, 0x67, 0x73, 0x86, 0x3B, 0x00, 0x1E,
        0x0E, 0x0E, 0xC7, 0xC6, 0x71, 0xC4, 0xC4, 0xE6, 0x60, 0x66, 0x70, 0xCE,
        0xCE, 0x1F, 0x9D, 0x8C, 0xCF, 0x0C, 0x78, 0xDC, 0x31, 0xC7, 0x11, 0x0E,
        0x38, 0x3E, 0x0C, 0x8E, 0x0F, 0x1F, 0x1C, 0x18, 0xCE, 0x79, 0xC7, 0x31,
        0x88, 0x78, 0x70, 0x9C, 0xCE, 0x77, 0x6C, 0xC6, 0x6E, 0xCE, 0x03, 0x39,
        0xCC, 0xE8, 0xE3, 0x88, 0xE7, 0xC0, 0xCD, 0x87, 0x99, 0x1C, 0xFC, 0x13,
        0x18, 0x99, 0x9C, 0xF9, 0xB8, 0x98, 0x31, 0xB9, 0xC7, 0xC1, 0x83, 0x81,
        0x8E, 0x67, 0xC1, 0x1C, 0xC6, 0x70, 0x19, 0x9C, 0x67, 0x1C, 0x60
    ),
    "H": (
        0x7F, 0xFE, 0x7C, 0x00, 0xFC, 0x7F, 0xF0, 0x08, 0x1E, 0x0F, 0xFF, 0x07,
        0x80, 0x1F, 0xF8, 0x3F, 0x00, 0x30, 0x1F, 0x78, 0x38, 0x0F, 0x80, 0xFE,
        0x00, 0x06, 0x07, 0xFF, 0x0F, 0xC0, 0x3F, 0x9F, 0xC0, 0x01, 0xEF, 0x83,
        0xE0, 0x1F, 0x0F, 0xC1, 0xF0, 0x40, 0x1F, 0xC3, 0xFE, 0x03, 0xFF, 0xF8,
        0xFE, 0x03, 0x00, 0xFF, 0x07, 0xC0, 0x00, 0x7F, 0xC0, 0xE0, 0x7E, 0x00,
        0x01, 0xFF, 0x86, 0x01, 0xFC, 0x0F, 0xF2, 0x03, 0xC0, 0x07, 0xFF, 0xFF,
        0x00, 0xC0, 0x1F, 0xF9, 0x98, 0x00, 0x0C, 0x7F, 0xFF, 0xC0, 0x1E, 0x3F,
        0xFC, 0x00, 0x0E, 0x7C, 0x1F, 0x01, 0xFE, 0x00, 0xFF, 0xC0, 0x7E, 0x03,
        0xF8, 0x00, 0x70, 0xFC, 0xF8, 0x00, 0x1F, 0x80, 0xF0, 0x0C, 0x07, 0xFD,
        0xF0, 0x38, 0x38, 0xFF, 0x3F, 0x80, 0xFF, 0x80, 0xFF, 0x00, 0xFF, 0x01,
        0xF8, 0x07, 0xF0, 0x3E, 0x00, 0x03, 0xE0, 0x1F, 0x80, 0x07, 0xFC, 0x07,
        0xE0, 0xE7, 0xF8, 0x70, 0x78, 0x00, 0xFE, 0x03, 0xF0, 0x07, 0xF8, 0x0F,
        0x00, 0x7F, 0xE1, 0x87, 0xFF, 0xF8, 0x01, 0xFF, 0x01, 0xF0, 0x07, 0xF0,
        0x0F, 0xF0, 0x00, 0x00, 0x7F, 0xCF, 0x80, 0x00, 0xFF, 0xC0, 0x7C, 0x00,
        0x7F, 0x80, 0xFF, 0x00, 0x3E, 0x00, 0xFF, 0x00, 0xFE, 0x00, 0x7E, 0x3F,
        0x0E, 0x00, 0x7F, 0x07, 0xFC, 0xFF, 0x00, 0x03, 0xFE, 0x3E, 0x06, 0x00,
        0x3F, 0x00, 0x7C, 0x00, 0x23, 0xC0, 0x38, 0x0F, 0xBC, 0x1E, 0x00, 0x7F,
        0x98, 0x7E, 0x0F, 0x78, 0x1F, 0xF8, 0x00, 0x08, 0xFE, 0x00, 0x00, 0x03,
        0xFC, 0x07, 0xC0, 0x00, 0x7E, 0x07, 0xF0, 0x1E, 0x03, 0xF0, 0x00, 0x0F,
        0xE0, 0x3C, 0x1F, 0xC7, 0xE0, 0x3C, 0x07, 0x98, 0x7F, 0x0F, 0x80, 0xE1,
        0xFF, 0xCE, 0x00, 0x8F, 0xE7, 0xC0, 0x03, 0xC7, 0xC3, 0xC3, 0xC1, 0xC1,
        0xEF, 0xFF, 0x80, 0x01, 0xFF, 0x87, 0xC1, 0x80, 0x0F, 0xC7, 0x81, 0xF8,
        0x07, 0xE0, 0xFF, 0xC0, 0x01, 0xC0, 0xFE, 0x00, 0x00, 0x78, 0xF8, 0x0F,
        0x80, 0x78, 0x01, 0xFC, 0x00, 0xF8, 0x01, 0xF1, 0xFB, 0xF0, 0x07, 0xF8,
        0x03, 0xFF, 0x83, 0x83, 0xFF, 0xFF, 0x80, 0x3F, 0x1F, 0xC0, 0x00, 0x31,
        0xFC, 0x1E, 0x00, 0x1F, 0x80, 0x1F, 0x00, 0x3F, 0x00, 0xFC, 0x07, 0xFF,
        0x80, 0x3E, 0x07, 0xC0, 0xE0, 0x3C, 0x78, 0x38, 0xF8, 0x7C, 0x1F, 0xC0,
        0x1E, 0x0F, 0x1F, 0x80, 0x1F, 0x1E, 0x00, 0x1F, 0x1E, 0x00, 0x0E, 0x00,
        0x00, 0x3F, 0xC0, 0x00, 0x07, 0x0F, 0xC1, 0xFC, 0x03, 0xFF, 0xFF, 0xE0,
        0x1F, 0x0F, 0xFF, 0xFE, 0x00, 0x03, 0xF8, 0x7F, 0xF0, 0x01, 0xF8, 0x1F,
        0x80, 0xF0, 0x7F, 0x83, 0x81, 0x00, 0x01, 0xE0, 0xE0, 0x07, 0xC1, 0xFC,
        0x00, 0x7F, 0xC0, 0x7F, 0x80, 0x1F, 0x81, 0xFF, 0xF0, 0x00, 0x00, 0x0F,
        0xFF, 0x00, 0x02, 0x07, 0xE0, 0x0F, 0x00, 0x03, 0xF8, 0x0F, 0x83, 0x0E,
        0x02, 0x0F, 0xC0, 0x7F, 0x0F, 0x03, 0xC0, 0x7E, 0x06, 0x07, 0xFF, 0x1F,
        0x00, 0x1F, 0xCF, 0x1F, 0x03, 0xFC, 0x0F, 0xFF, 0x1F, 0x00, 0x0F, 0xC7,
        0xFC, 0x00, 0x3F, 0xE0, 0x7F, 0x80, 0x60, 0x00, 0x7F, 0x03, 0xE1, 0x03,
        0xC1, 0x83, 0xE0, 0x03, 0x00, 0xFC, 0x1F, 0xC0, 0x00, 0xFC, 0x0F, 0xC1,
        0xF2, 0x03, 0xE1, 0x07, 0xC0, 0x0F, 0x80, 0x0F, 0x03, 0x87, 0x00, 0x00,
        0x0F, 0x81, 0xFC, 0x07, 0xFF, 0xF0, 0x0E, 0x07, 0xFF, 0x87, 0x8F, 0x87,
        0xFF, 0xCF, 0xC7, 0xE1, 0xFF, 0xFF, 0x01, 0xF0, 0xFF, 0x80, 0x01, 0x80,
        0xE3, 0x00, 0xE0, 0x00, 0x00, 0x00, 0xE0, 0x0F, 0xF8, 0x00, 0xFE, 0x0F,
        0x80, 0x3E, 0x0F, 0xFF, 0xC0, 0xF8, 0x03, 0xFE, 0x3F, 0x1F, 0x01, 0xFC,
        0x00, 0x3F, 0x00, 0xFF, 0x00, 0x06, 0x03, 0xFC, 0x01, 0xFC, 0x07, 0xF0,
        0x0F, 0xE0, 0x3E, 0x00, 0x3F, 0x80, 0xFE, 0x01, 0xF8, 0x00, 0xF8, 0x0F,
        0xE0, 0x30, 0xF1, 0xF1, 0xF8, 0x00, 0xF0, 0x7F, 0xF0, 0x3F, 0x80, 0x7E,
        0x07, 0xE0, 0x00, 0xFE, 0x03, 0xE0, 0x0F, 0xFE, 0x01, 0xF8, 0x0F, 0xF0,
        0x74, 0x00, 0x18, 0x03, 0xF8, 0x00, 0xE0, 0x1F, 0xC0, 0x00, 0xC0, 0x7E,
        0x03, 0xFC, 0x1C, 0x00, 0x3F, 0x78, 0x3E, 0x00, 0x7C, 0x3F, 0x00
    ),
    "Z": (
        0xFC, 0x7E, 0x0F, 0x83, 0xF8, 0x3B, 0xC1, 0xF0, 0x7C, 0x1F, 0x80, 0xF0,
        0x8F, 0x83, 0xE1, 0xC7, 0xE0, 0xF0, 0x7C, 0x07, 0x0F, 0x0F, 0x81, 0xC0,
        0x63, 0xC0, 0x7C, 0x07, 0x83, 0xC0, 0x3E, 0x03, 0x80, 0x00, 0x00, 0x03,
        0x00, 0x00, 0x7E, 0x1F, 0xF0, 0xF8, 0xF8, 0x7E, 0x3B, 0xE1, 0xF8, 0x07,
        0x83, 0xC0, 0x1C, 0x00, 0xC3, 0xC1, 0xC0, 0x7C, 0xFC, 0x7C, 0x7F, 0x1D,
        0x9E, 0x1E, 0x3E, 0x1E, 0x1F, 0x1E, 0x30, 0x3E, 0x1F, 0x07, 0x00, 0xF0,
        0x1F, 0x00, 0x00, 0x38, 0x07, 0x00, 0x40, 0xFE, 0x1F, 0x8F, 0xFF, 0xF8,
        0xF1, 0xF0, 0xF0, 0xF8, 0x61, 0xE0, 0xF8, 0x7C, 0x1F, 0x03, 0xF0, 0x7E,
        0x07, 0x81, 0xE6, 0x1E, 0x0F, 0x87, 0xE0, 0xF0, 0x87, 0xC0, 0xE0, 0x78,
        0x3E, 0x1F, 0x03, 0x81, 0xC0, 0x3C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03,
        0xFF, 0x8F, 0xE0, 0x7F, 0x8F, 0xE3, 0xCF, 0x8F, 0xC1, 0xE1, 0xC1, 0x87,
        0x03, 0x81, 0xE0, 0x7C, 0x1F, 0xC1, 0xF0, 0x3C, 0x3E, 0x3F, 0x3C, 0xE0,
        0x0F, 0x07, 0x87, 0xC3, 0xF8, 0x78, 0x1E, 0x78, 0xC0, 0x10, 0x30, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x01, 0x9F, 0x9F, 0xF1, 0xFE, 0xFC, 0xFF, 0x03,
        0xC7, 0x83, 0xC3, 0xC0, 0x3E, 0x00, 0x30, 0x18, 0x7C, 0x1F, 0xC3, 0xE1,
        0xF8, 0xE7, 0x18, 0xE1, 0xE0, 0x3F, 0x0F, 0x83, 0xC0, 0x73, 0x87, 0xE0,
        0x7C, 0x00, 0x00, 0x70, 0x1C, 0x00, 0x00, 0xC0, 0x1C, 0x00, 0xF8, 0xFC,
        0xFF, 0x3F, 0xFF, 0xE3, 0xC0, 0xFC, 0x3E, 0x03, 0x00, 0x03, 0xC1, 0xC0,
        0x38, 0x3E, 0x0F, 0x0F, 0x1E, 0x1F, 0x07, 0xF0, 0xFE, 0x1F, 0xC0, 0x78,
        0x7F, 0x07, 0xC1, 0xF0, 0x7E, 0x0F, 0x81, 0xE0, 0x78, 0x0E, 0x00, 0x60,
        0x00, 0x00, 0x00, 0x7D, 0x03, 0xFF, 0xFF, 0xFF, 0x0F, 0xE0, 0x3F, 0x81,
        0xF8, 0x1C, 0x0F, 0x02, 0x78, 0x3F, 0x03, 0xE0, 0xFC, 0x1F, 0x83, 0xC1,
        0xE1, 0xFC, 0xE3, 0xC1, 0xF0, 0x3E, 0x1F, 0x03, 0xC0, 0xCF, 0x07, 0xC0,
        0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1C, 0x3F, 0x01, 0xF0, 0x7F,
        0xF0, 0xFF, 0x1F, 0x0F, 0x8F, 0x07, 0x81, 0xC0, 0x0F, 0x03, 0xB0, 0xE0,
        0x3C, 0x73, 0x81, 0xC7, 0x78, 0x7F, 0x83, 0xC1, 0xF0, 0xF8, 0xF8, 0x3C,
        0x0F, 0x01, 0xE0, 0xF8, 0x70, 0x03, 0x00, 0x38, 0x00, 0x01, 0xC0, 0xF0,
        0x00, 0x07, 0xC3, 0xFF, 0xFF, 0xF8, 0xFE, 0x1E, 0x1F, 0x83, 0x87, 0x07,
        0x06, 0x00, 0x0F, 0x0F, 0x81, 0xE0, 0xFE, 0x0F, 0xE1, 0xE4, 0x3E, 0x1F,
        0x18, 0xF0, 0x1F, 0x87, 0x81, 0xE3, 0x81, 0xE1, 0xF0, 0xF0, 0x0F, 0x81,
        0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x81, 0xF8, 0xFF, 0xFF, 0xC0,
        0xF8, 0xC7, 0xC1, 0x8F, 0x0C, 0x60, 0x1E, 0x1F, 0x07, 0x10, 0x1E, 0x1E,
        0x1F, 0x1F, 0xC7, 0xFF, 0xC1, 0xF0, 0x3E, 0x03, 0xC3, 0xE0, 0xF0, 0x78,
        0xE1, 0xF8, 0x7C, 0x07, 0xC0, 0xF0, 0x00, 0x03, 0x00, 0x00, 0x01, 0xFF,
        0xC3, 0xF3, 0xFF, 0xF9, 0xF8, 0x7F, 0x1F, 0xC0, 0xF0, 0x3E, 0x0F, 0x81,
        0xE0, 0xF0, 0x78, 0x1C, 0xF0, 0x3E, 0x0F, 0x07, 0xC3, 0x81, 0xE3, 0xC0,
        0x7E, 0x0F, 0x83, 0xC7, 0x1E, 0x1F, 0x00, 0xF0, 0x3E, 0x07, 0x00, 0x00,
        0x08, 0x00, 0x00, 0x00, 0x7F, 0x0F, 0xF3, 0xFF, 0xFC, 0x0F, 0x1E, 0x7E,
        0x3C, 0x07, 0xE0, 0xE1, 0xE0, 0x38, 0xC0, 0xDC, 0x1E, 0x1E, 0x3F, 0xC1,
        0xCE, 0x3E, 0x03, 0xF0, 0xCF, 0x07, 0xC3, 0xC1, 0xF0, 0xF0, 0x43, 0xC1,
        0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7E, 0xCF, 0xF1,
        0xFF, 0xFF, 0xF0, 0xFC, 0x3F, 0xE1, 0xE0, 0x30, 0x40, 0xE0, 0xFC, 0x1E,
        0x0F, 0x0F, 0x07, 0x87, 0xE1, 0xFC, 0x78, 0x4F, 0x03, 0x83, 0xC3, 0xC0,
        0xF0, 0x1F, 0x07, 0x80, 0xFC, 0x02, 0x03, 0x80, 0x1C, 0x00, 0x00, 0x00,
        0x20, 0x00, 0x3F, 0x0F, 0xE7, 0xE3, 0xF7, 0xF0, 0xFC, 0x1F, 0xC7, 0x1C,
        0x00, 0xE0, 0x3C, 0x3F, 0x0F, 0x1F, 0x0E, 0x21, 0xF0, 0xF8, 0xF0, 0xFC,
        0x3E, 0x1F, 0x87, 0x8E, 0x71, 0x1E, 0x03, 0xF0, 0xFC, 0xF1, 0x80, 0x38,
        0x00, 0x60, 0x00, 0x00, 0x00, 0x80, 0x00, 0xFF, 0x1F, 0xC7, 0xEF
    ),
    "AW": (
        0x00, 0x01, 0xFF, 0xFE, 0x00, 0x0E, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0xFF,
        0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xF8, 0x3F, 0xFF, 0xFE, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xE0,
        0x00, 0x00, 0x1F, 0xFF, 0xE0, 0x00, 0x01, 0xFF, 0xFF, 0xC0, 0x00, 0x8F,
        0xFF, 0xFE, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x03, 0xFF,
        0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0x01, 0xFF, 0xFF, 0xC0,
        0x00, 0x00, 0x7F, 0xFF, 0xFE, 0x00, 0x00, 0x01, 0xFF, 0xFE, 0x00, 0x00,
        0x1F, 0xFF, 0xF8, 0x00, 0x04, 0xFF, 0xFF, 0xC0, 0x00, 0x01, 0xFF, 0xFF,
        0xFF, 0xE0, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x03, 0xFF,
        0xFF, 0xF8, 0x3F, 0xFF, 0xFF, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xE0, 0x00,
        0x00, 0x0F, 0xFF, 0xC0, 0x00, 0x01, 0x8F, 0xFF, 0x00, 0x00, 0xCF, 0xFF,
        0xFE, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFF, 0xFC, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xE0, 0xFF, 0xFF, 0xF0, 0x00,
        0x00, 0x0F, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x7F, 0xFF, 0x00, 0x00, 0x1D,
        0xFF, 0xFC, 0x00, 0x00, 0x7F, 0xFF, 0xF0, 0x00, 0x00, 0x3F, 0xFF, 0xFF,
        0xF0, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x01, 0xFF, 0xFB,
        0xFC, 0x1F, 0xFF, 0xFF, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xF0, 0x00, 0x00,
        0x0F, 0xFF, 0xC0, 0x00, 0x00, 0x7F, 0xEF, 0x80, 0x00, 0x07, 0xFF, 0xFF,
        0x80, 0x00, 0x07, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF,
        0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFE, 0x0F, 0xFF, 0xFF, 0x00, 0x00, 0x03,
        0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x07, 0xFF, 0xC0, 0x00, 0x00, 0xC7, 0xFF,
        0x80, 0x00, 0x3F, 0xFF, 0xFF, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0x80,
        0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x1F, 0xFF, 0xBF, 0xC0,
        0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0xFF,
        0xFF, 0x80, 0x00, 0x03, 0xFF, 0xF8, 0x00, 0x00, 0x7F, 0xFF, 0xE0, 0x00,
        0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x03, 0xF7, 0xFF, 0xFF, 0xF0,
        0x00, 0x00, 0x3F, 0xFF, 0xFF, 0x81, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x3F,
        0xFF, 0xFF, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xC0, 0x00, 0x21, 0xFF, 0xE0,
        0x00, 0x03, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xF8, 0x00,
        0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0xFF, 0xFF, 0xFE, 0x0F,
        0xFF, 0xFF, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x0F, 0xFF,
        0xF0, 0x00, 0x00, 0xFF, 0xFF, 0xC0, 0x00, 0x03, 0xFF, 0xFF, 0x80, 0x00,
        0x00, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0x00,
        0x00, 0x03, 0xFF, 0xFF, 0xF8, 0x3F, 0xFF, 0xFE, 0x00, 0x00, 0x03, 0xFF,
        0xFF, 0xF0, 0x00, 0x00, 0x1F, 0xFF, 0xC0, 0x00, 0x01, 0xFF, 0xFF, 0x00,
        0x00, 0x07, 0xFF, 0xFF, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFE, 0x00, 0x00,
        0x00, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xC1, 0xFF,
        0xFF, 0xF0, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0xFF, 0xFE,
        0x00, 0x00, 0x1F, 0xFF, 0xFC, 0x00, 0x00, 0x3F, 0xFF, 0xF8, 0x00, 0x00,
        0x3F, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0x00, 0x00,
        0x03, 0xFF, 0xFB, 0xF8, 0x3F, 0xFF, 0xFE, 0x00, 0x00, 0x07, 0xFF, 0xFF,
        0xE0, 0x00, 0x00, 0x1F, 0xFF, 0x80, 0x00, 0x00, 0xFF, 0xFF, 0x80, 0x00,
        0x07, 0xFF, 0xFF, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x01,
        0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0x83, 0xFF, 0xFF,
        0xC0, 0x00, 0x00, 0x7F, 0xFF, 0xFE, 0x00, 0x00, 0x03, 0xFF, 0xFC, 0x00,
        0x00, 0x3F, 0xFF, 0xF0, 0x00, 0x00, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0xFF,
        0xFF, 0xFF, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x07,
        0xFF, 0xEF, 0xE0, 0x3F, 0xFF, 0xFC, 0x00, 0x00, 0x07, 0xFF, 0xFF
    ),
    "AH": (
        0x00, 0x00, 0xFF, 0xFE, 0x00, 0x00, 0x3F, 0x00, 0x0F, 0xFF, 0xFF, 0x00,
        0x03, 0xC7, 0xFF, 0x00, 0x03, 0xF3, 0xFF, 0xFF, 0xFF, 0x00, 0x1F, 0x07,
        0xFF, 0xF0, 0x0F, 0x80, 0xFC, 0x00, 0x0F, 0xFF, 0xFF, 0x00, 0x03, 0xF0,
        0x1F, 0xE0, 0x1F, 0xF8, 0x00, 0x00, 0x03, 0xFF, 0xE0, 0x00, 0x00, 0x78,
        0x00, 0x3F, 0xFF, 0xFE, 0x00, 0x0E, 0x1F, 0xF8, 0x00, 0x1F, 0xFF, 0xFF,
        0xFF, 0xFE, 0x00, 0x3E, 0x0F, 0xFF, 0xC0, 0x1F, 0x01, 0xF8, 0x00, 0x1F,
        0xFF, 0xFF, 0x00, 0x07, 0xE0, 0x7F, 0xC0, 0x7F, 0xF0, 0x00, 0x00, 0x0F,
        0xFF, 0xC0, 0x20, 0x03, 0xF0, 0x00, 0xFF, 0xFF, 0xF0, 0x00, 0x30, 0x1F,
        0xE0, 0x00, 0x7F, 0xC7, 0xFF, 0xFF, 0xFC, 0x00, 0x7C, 0x1F, 0xFF, 0x80,
        0x3E, 0x03, 0xF0, 0x00, 0x3F, 0xFF, 0xFE, 0x00, 0x0F, 0xC0, 0xFF, 0xC0,
        0x7F, 0xF0, 0x00, 0x00, 0x0F, 0xFF, 0x00, 0x00, 0x03, 0xE0, 0x00, 0xFF,
        0xFF, 0xF0, 0x00, 0x1C, 0x1F, 0xF8, 0x00, 0x7F, 0xF7, 0xFF, 0xFF, 0xF8,
        0x00, 0xF8, 0x7F, 0xFF, 0x00, 0x7C, 0x07, 0xE0, 0x00, 0x7F, 0xFF, 0xFC,
        0x00, 0x1F, 0x80, 0x7F, 0x00, 0xFF, 0xC0, 0x00, 0x00, 0x3F, 0xFF, 0x00,
        0x80, 0x03, 0xE0, 0x03, 0xFF, 0xFF, 0xE0, 0x01, 0xE0, 0xFF, 0xC0, 0x01,
        0xFF, 0xCF, 0xFF, 0xFF, 0xF0, 0x01, 0xE0, 0xFF, 0xFE, 0x00, 0xF8, 0x0F,
        0xC0, 0x00, 0xFF, 0xFF, 0xF0, 0x00, 0x3F, 0x83, 0xFF, 0x01, 0xFF, 0x80,
        0x00, 0x00, 0x7F, 0xFE, 0x00, 0x00, 0x0F, 0x80, 0x01, 0xFF, 0xFF, 0xC0,
        0x00, 0x61, 0xFF, 0x80, 0x01, 0xFF, 0x7F, 0xFF, 0xFF, 0xE0, 0x03, 0xC0,
        0xFF, 0xFE, 0x01, 0xF0, 0x1F, 0x80, 0x01, 0xFF, 0xFF, 0xF0, 0x00, 0x7F,
        0x03, 0xFF, 0x03, 0xFF, 0x80, 0x00, 0x00, 0xFF, 0xFC, 0x02, 0x00, 0x1F,
        0x00, 0x07, 0xFF, 0xFF, 0xC0, 0x01, 0x73, 0xFF, 0xC0, 0x07, 0xFE, 0xFF,
        0xFF, 0xFF, 0xC0, 0x07, 0x81, 0xFF, 0xF8, 0x03, 0xE0, 0x3F, 0x00, 0x03,
        0xFF, 0xFF, 0xC0, 0x00, 0xFC, 0x0F, 0xFC, 0x07, 0xFF, 0x00, 0x00, 0x01,
        0xFF, 0xF8, 0x00, 0x00, 0x7C, 0x00, 0x1F, 0xFF, 0xFF, 0x00, 0x06, 0x07,
        0xFF, 0x00, 0x07, 0xF8, 0x7F, 0xDF, 0xFF, 0xC0, 0x07, 0x81, 0xFF, 0xF8,
        0x03, 0xE0, 0x7F, 0x00, 0x03, 0xFF, 0xFF, 0xC0, 0x00, 0xF8, 0x07, 0xFC,
        0x07, 0xFE, 0x00, 0x00, 0x01, 0xFF, 0xF8, 0x18, 0x00, 0xFE, 0x00, 0x1F,
        0xFF, 0xFE, 0x00, 0x03, 0xC7, 0xFF, 0x00, 0x1F, 0xFB, 0xFF, 0xFF, 0xFF,
        0x80, 0x0F, 0x03, 0xFF, 0xF0, 0x07, 0xC0, 0x7E, 0x00, 0x07, 0xFF, 0xFF,
        0xC0, 0x01, 0xF8, 0x1F, 0xF8, 0x0F, 0xFC, 0x00, 0x00, 0x03, 0xFF, 0xF0,
        0x10, 0x00, 0xFC, 0x00, 0x1F, 0xFF, 0xFE, 0x00, 0x07, 0x07, 0xFE, 0x00,
        0x0F, 0xF0, 0x7F, 0xBF, 0xFF, 0x80, 0x0F, 0x07, 0xFF, 0xF0, 0x0F, 0x80,
        0xFC, 0x00, 0x0F, 0xFF, 0xFF, 0x80, 0x01, 0xF0, 0x0F, 0xF8, 0x0F, 0xFC,
        0x00, 0x00, 0x03, 0xFF, 0xE0, 0x1C, 0x00, 0x7C, 0x00, 0x3F, 0xFF, 0xFF,
        0x00, 0x0E, 0x1F, 0xFE, 0x00, 0x3F, 0xF7, 0xFF, 0xFF, 0xFE, 0x00, 0x3C,
        0x0F, 0xFF, 0xC0, 0x1F, 0x01, 0xF8, 0x00, 0x1F, 0xFF, 0xFF, 0x00, 0x07,
        0xC0, 0x3F, 0xE0, 0x3F, 0xF0, 0x00, 0x00, 0x07, 0xFF, 0xC0, 0xE0, 0x00,
        0xF8, 0x00, 0xFF, 0xFF, 0xFC, 0x00, 0x1E, 0x9F, 0xFC, 0x00, 0x3F, 0xE3,
        0xFF, 0xFF, 0xFE, 0x00, 0x3C, 0x0F, 0xFF, 0xC0, 0x1F, 0x01, 0xF8, 0x00,
        0x1F, 0xFF, 0xFF, 0x00, 0x07, 0xE0, 0x1F, 0xE0, 0x3F, 0xF8, 0x00, 0x00,
        0x07, 0xFF, 0xC0, 0x70, 0x03, 0xF0, 0x00, 0x7F, 0xFF, 0xFC, 0x00, 0x3C,
        0x7F, 0xF8, 0x00, 0x3F, 0xCF, 0xFF, 0x9F, 0xFF, 0x80, 0x1F, 0x07, 0xFF,
        0xF0, 0x0F, 0x80, 0xFE, 0x00, 0x07, 0xFF, 0xFF, 0x80, 0x01, 0xF0, 0x1F,
        0xF8, 0x0F, 0xFC, 0x00, 0x00, 0x01, 0xFF, 0xE0, 0x38, 0x00, 0xFC, 0x00,
        0x1F, 0xFF, 0xFF, 0x00, 0x07, 0xCF, 0xFE, 0x00, 0x3F, 0xEF, 0xFF, 0xFF,
        0xFF, 0x00, 0x3E, 0x0F, 0xFF, 0xE0, 0x1F, 0x00, 0xFC, 0x00, 0x0F, 0xFF,
        0xFF, 0x00, 0x03, 0xF0, 0x3F, 0xF0, 0x3F, 0xF8, 0x00, 0x00, 0x07
    ),
    "UH": (
        0x00, 0x7F, 0xFF, 0xFF, 0xC0, 0xE0, 0x0C, 0x00, 0x00, 0x00, 0x7F, 0xFF,
        0xFE, 0x00, 0x00, 0x00, 0x1C, 0x7F, 0x0F, 0xFF, 0xDF, 0xC0, 0x00, 0x01,
        0xFF, 0xFF, 0xE0, 0x00, 0x1F, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFF, 0x83, 0xF0, 0x7C, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xF8, 0x1C, 0x01,
        0x80, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x87, 0xE0,
        0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x3F, 0xFF, 0xFE, 0x00, 0x03, 0xFF, 0xFF,
        0x80, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xF8, 0x7E, 0x07, 0x80, 0x00, 0x00,
        0xFF, 0xFF, 0xFF, 0x03, 0x00, 0x20, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xF8,
        0x00, 0x00, 0x00, 0x30, 0xFE, 0x3F, 0xFF, 0xFF, 0x00, 0x00, 0x03, 0xFF,
        0xFF, 0x80, 0x00, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFE,
        0x1F, 0x81, 0xF0, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xE0, 0xE0, 0x06, 0x00,
        0x00, 0x00, 0x0F, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0x1F, 0xC7, 0xFF,
        0xFF, 0x38, 0x00, 0x00, 0x7F, 0xFF, 0xE0, 0x00, 0x0F, 0xFF, 0xFF, 0x00,
        0x00, 0x00, 0xFE, 0xFF, 0xFF, 0x83, 0xE0, 0x7E, 0x00, 0x00, 0x07, 0xFF,
        0xFF, 0xF8, 0x18, 0x01, 0x80, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xC0, 0x00,
        0x00, 0x03, 0xC7, 0xE0, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x1F, 0xFF, 0xFE,
        0x00, 0x03, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xF0, 0x7E,
        0x0F, 0x80, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x07, 0x00, 0x20, 0x00, 0x00,
        0x00, 0x7F, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0xE0, 0xFC, 0x3F, 0xFF, 0xFF,
        0x00, 0x00, 0x07, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xE0, 0x00, 0x00,
        0x0F, 0xFF, 0xFF, 0xF8, 0x1F, 0x03, 0xE0, 0x00, 0x00, 0x7F, 0xFF, 0xFF,
        0x81, 0x80, 0x18, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFC, 0x00, 0x00, 0x00,
        0x38, 0x3F, 0x0F, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0xFF, 0xFF, 0xE0, 0x00,
        0x3F, 0xFF, 0xFC, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFE, 0x0F, 0x81, 0xF0,
        0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xE0, 0x60, 0x00, 0x00, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x1F, 0x1F, 0xC7, 0xFF, 0xFF, 0xF0, 0x00,
        0x00, 0x7F, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xFE, 0x00, 0x00, 0x03, 0xFF,
        0xFF, 0xFE, 0x0F, 0x81, 0xF8, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xE0, 0x60,
        0x00, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x0F, 0x0F,
        0xC3, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x7F, 0xFF, 0xF8, 0x00, 0x07, 0xFF,
        0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x03, 0xE0, 0x7C, 0x00, 0x00,
        0x07, 0xFF, 0xFF, 0xF0, 0x18, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF,
        0xE0, 0x00, 0x00, 0x07, 0x07, 0xE1, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x1F,
        0xFF, 0xFE, 0x00, 0x07, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFD, 0xFF, 0xFF,
        0x03, 0xE0, 0xFC, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x70, 0x00, 0x00,
        0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x0F, 0x0F, 0xC1, 0xFF,
        0xFF, 0xF8, 0x00, 0x00, 0x3F, 0xFF, 0xF8, 0x00, 0x0F, 0xFF, 0xFE, 0x00,
        0x00, 0x01, 0xFF, 0xFF, 0xFF, 0x07, 0xC0, 0xF8, 0x00, 0x00, 0x0F, 0xFF,
        0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xF8, 0x00,
        0x00, 0x0E, 0x0F, 0xC3, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x3F, 0xFF, 0xFC,
        0x00, 0x0F, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x83, 0xE0,
        0x7C, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xF8, 0x10, 0x00, 0x00, 0x00, 0x00,
        0x01, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x03, 0x07, 0xF3, 0xFF, 0xFF, 0xF8,
        0x00, 0x00, 0x0F, 0xFF, 0xFE, 0x00, 0x03, 0xFF, 0xFF, 0x00, 0x00, 0x01,
        0xF9, 0xFF, 0xFF, 0x07, 0xC0, 0xFC, 0x00, 0x00, 0x07, 0x7F, 0xFF, 0xF0,
        0x60, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x06,
        0x0F, 0x87, 0xFF, 0xFF, 0xF3, 0x00, 0x00, 0x3F, 0xFF, 0xFC, 0x00, 0x07,
        0xFF, 0xFF, 0x00, 0x00, 0x03, 0xE3, 0xFF, 0xFC, 0x1F, 0x03, 0xF8
    ),
    "AE": (
        0x01, 0xFF, 0xFF, 0x01, 0x63, 0xF0, 0x03, 0xF1, 0xFF, 0xBF, 0xF0, 0x03,
        0xF8, 0x0F, 0xE0, 0xFE, 0x00, 0xFF, 0xE0, 0x0F, 0xC1, 0xFE, 0x03, 0xFC,
        0x00, 0x01, 0x01, 0xFC, 0x07, 0xF0, 0x00, 0x03, 0xC0, 0x00, 0x1F, 0xE0,
        0x07, 0xC0, 0x06, 0x00, 0x7F, 0x00, 0x7C, 0x3E, 0x00, 0x01, 0xF8, 0x01,
        0xFF, 0xFF, 0xFF, 0xF0, 0x03, 0xF8, 0x0F, 0xE0, 0xFE, 0x00, 0xFB, 0xE0,
        0x0F, 0xC0, 0xFE, 0x03, 0xFC, 0x00, 0x03, 0x00, 0xFC, 0x07, 0xF0, 0x00,
        0x01, 0xE0, 0x00, 0x1F, 0xE0, 0x1C, 0x00, 0x00, 0x00, 0x7F, 0x80, 0xFF,
        0xFF, 0x00, 0x03, 0xFC, 0x00, 0xFE, 0xFF, 0x9F, 0xFC, 0x01, 0xFC, 0x07,
        0xF0, 0x7F, 0x00, 0x7D, 0xF8, 0x07, 0xE0, 0xFF, 0x01, 0xFE, 0x00, 0x03,
        0x80, 0xFE, 0x03, 0xFC, 0x00, 0x00, 0xC0, 0x00, 0x07, 0xF8, 0x00, 0x0F,
        0x80, 0x00, 0x3F, 0xE0, 0x00, 0xFF, 0x80, 0x00, 0x3F, 0x00, 0x3F, 0xFF,
        0x1F, 0xF8, 0x01, 0xFC, 0x07, 0xF0, 0x7F, 0x00, 0xFF, 0xF0, 0x07, 0xE0,
        0xFF, 0x01, 0xFE, 0x00, 0x03, 0x80, 0xFE, 0x03, 0xF8, 0x00, 0x00, 0x60,
        0x08, 0x0F, 0xF0, 0x07, 0xF8, 0x03, 0xC0, 0x7F, 0x80, 0x7F, 0xF7, 0x80,
        0x08, 0xF8, 0x01, 0xFF, 0xFF, 0xFF, 0xE0, 0x0F, 0xE0, 0x1F, 0x83, 0xFC,
        0x03, 0xEF, 0xC0, 0x3F, 0x03, 0xF8, 0x0F, 0xF0, 0x00, 0x1E, 0x07, 0xF0,
        0x3F, 0xC0, 0x00, 0x0F, 0x03, 0xC0, 0xFF, 0x01, 0xE0, 0x04, 0x00, 0x00,
        0xFC, 0x03, 0xE1, 0xF8, 0x00, 0x00, 0x30, 0x03, 0xE7, 0xFF, 0xFF, 0x00,
        0x7F, 0x80, 0xFE, 0x1F, 0xC0, 0x1F, 0x7F, 0x00, 0xFC, 0x1F, 0xC0, 0x7F,
        0x80, 0x01, 0xF0, 0x3F, 0x80, 0xFF, 0x00, 0x00, 0x30, 0x04, 0x01, 0xF8,
        0x07, 0x80, 0x70, 0x00, 0x03, 0xF0, 0x1F, 0x9F, 0xF0, 0x06, 0x08, 0x00,
        0x1F, 0xFF, 0xFF, 0xF8, 0x01, 0xFC, 0x07, 0xE0, 0xFF, 0x00, 0xF3, 0xF8,
        0x07, 0xE0, 0xFE, 0x01, 0xFE, 0x00, 0x07, 0x80, 0xFE, 0x07, 0xF8, 0x00,
        0x03, 0xC0, 0x78, 0x1F, 0xE0, 0x3E, 0x03, 0x00, 0x00, 0x7F, 0x80, 0xF0,
        0x7F, 0x80, 0x02, 0x80, 0x00, 0x79, 0xFF, 0xF3, 0xF0, 0x07, 0xF0, 0x1F,
        0x83, 0xFC, 0x03, 0x8F, 0xE0, 0x1F, 0x83, 0xF8, 0x0F, 0xF8, 0x00, 0x1F,
        0x07, 0xF0, 0x1F, 0xE0, 0x00, 0x0E, 0x01, 0x00, 0x7F, 0x00, 0x70, 0x00,
        0x00, 0x00, 0xFE, 0x01, 0xF8, 0x7F, 0x00, 0x08, 0x70, 0x07, 0xFF, 0xFF,
        0xFF, 0x80, 0x1F, 0x80, 0x7E, 0x0F, 0xE0, 0x0E, 0x1F, 0x00, 0xFE, 0x0F,
        0xE0, 0x3F, 0xF0, 0x00, 0xF8, 0x1F, 0xC0, 0xFF, 0x00, 0x00, 0x70, 0x1E,
        0x01, 0xFC, 0x0F, 0x00, 0xF8, 0x00, 0x03, 0xFC, 0x1E, 0x0F, 0xE0, 0x00,
        0x00, 0x80, 0x0F, 0xFF, 0xFF, 0xF0, 0x01, 0xFC, 0x07, 0xE0, 0xFF, 0x00,
        0xE1, 0xF8, 0x07, 0xE0, 0xFE, 0x03, 0xFF, 0x00, 0x0F, 0x80, 0xFC, 0x0F,
        0xF8, 0x00, 0x03, 0xC1, 0xE0, 0x1F, 0x80, 0xF0, 0x07, 0x80, 0x00, 0x7F,
        0x80, 0x20, 0x7F, 0x00, 0x00, 0x03, 0x00, 0x3F, 0xFF, 0xFF, 0x00, 0x3F,
        0x80, 0xFE, 0x1F, 0xE0, 0x3F, 0x3F, 0x00, 0xFC, 0x3F, 0xC0, 0x7F, 0xC0,
        0x00, 0xF0, 0x3F, 0x80, 0xFF, 0x00, 0x00, 0x70, 0x07, 0x00, 0xFF, 0xC0,
        0x00, 0xFC, 0x00, 0x03, 0xFC, 0x38, 0x3F, 0xF0, 0x00, 0x07, 0xE0, 0x03,
        0xFF, 0xFE, 0x00, 0x3F, 0x80, 0xFE, 0x0F, 0xE0, 0x1F, 0xFF, 0x00, 0xFC,
        0x1F, 0xC0, 0x3F, 0xC0, 0x00, 0x70, 0x1F, 0x80, 0xFF, 0x00, 0x00, 0x3C,
        0x00, 0x00, 0xFF, 0xC0, 0x0F, 0xFE, 0x00, 0x07, 0xF8, 0x03, 0xFF, 0xF0,
        0x00, 0x3B, 0x00, 0x0F, 0xFF, 0xFC, 0x00, 0xFF, 0x01, 0xF8, 0x3F, 0xC0,
        0x7F, 0xFC, 0x01, 0xF8, 0x7F, 0x80, 0xFF, 0x00, 0x00, 0xF0, 0x7F, 0x01,
        0xFE, 0x00, 0x00, 0x78, 0x00, 0x01, 0xFF, 0x00, 0x7F, 0x8F, 0x00, 0x1F,
        0xE0, 0x0C, 0xFF, 0xE0, 0x00, 0x3F, 0x00, 0x7F, 0xFF, 0xF0, 0x03, 0xFC,
        0x07, 0xE0, 0xFF, 0x00, 0xFF, 0xF0, 0x07, 0xC1, 0xFE, 0x03, 0xFC, 0x00,
        0x03, 0xC1, 0xFC, 0x07, 0xF8, 0x00, 0x03, 0xE0, 0x00, 0x0F, 0x81, 0xE0,
        0x0F, 0xD0, 0x00, 0x7E, 0x03, 0xF0, 0xFF, 0x00, 0x00, 0xCE, 0x0F
    ),
    "OH": (
        0xFF, 0x00, 0x00, 0x00, 0x00, 0x03, 0xF0, 0x00, 0x01, 0xFF, 0xFF, 0xFF,
        0xF0, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xF8, 0x00, 0x03, 0xFF, 0xFE,
        0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0xFF, 0xE0,
        0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x7F,
        0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF,
        0xFF, 0x02, 0x00, 0x1F, 0xFE, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF,
        0x80, 0x00, 0x00, 0x7F, 0xFE, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF,
        0x00, 0x00, 0x00, 0x01, 0x03, 0xE0, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xE0,
        0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xF8, 0x00, 0x0F, 0xBF, 0xFC, 0x00,
        0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0xFF, 0x80, 0x00,
        0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00, 0xFE, 0x00,
        0x00, 0x7F, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFC,
        0x00, 0x00, 0x7F, 0xFE, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0x00,
        0x00, 0x00, 0x3F, 0xF0, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xF8, 0x00,
        0x00, 0x00, 0x00, 0x3F, 0x80, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0x80, 0x00,
        0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x07, 0xFF, 0xC0, 0x00, 0x00,
        0x03, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x07, 0xF8, 0x02, 0x00, 0x00,
        0x0F, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xC0, 0x00, 0x0F,
        0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xC0, 0x00,
        0x03, 0x87, 0xC8, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00,
        0x00, 0xFC, 0x01, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0x00, 0x07, 0xE0, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00,
        0x1F, 0xFF, 0xFF, 0xFE, 0x00, 0x07, 0x07, 0xFE, 0x00, 0x00, 0x00, 0x7F,
        0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x7F, 0x00, 0xC0, 0x00, 0x01, 0xFF,
        0xFF, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x03, 0xF8, 0x00, 0x01, 0xFF, 0xFF,
        0xFF, 0xF8, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x7F,
        0xF8, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x1F,
        0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x01,
        0xFC, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x07, 0xFF,
        0xFF, 0xF8, 0x00, 0x00, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF,
        0xFC, 0x00, 0x00, 0x00, 0x1F, 0x80, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF,
        0xC0, 0x00, 0x00, 0x00, 0x00, 0xFC, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFC,
        0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x7F, 0xFC, 0x00,
        0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x1F, 0x00, 0x00,
        0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x01, 0xFC, 0x00,
        0x01, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF,
        0x00, 0x01, 0xC1, 0xFF, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFC, 0x00,
        0x00, 0x00, 0x7C, 0x01, 0x80, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0x02, 0x00,
        0x00, 0x00, 0x07, 0xF0, 0x3C, 0x0F, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00,
        0x00, 0x1F, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00,
        0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x7C, 0x01, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xE0, 0x18, 0x07, 0xFF,
        0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xF0, 0x00, 0x00,
        0xE3, 0xE0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00,
        0x7E, 0x00, 0x80, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00,
        0x03, 0xF0, 0x08, 0x03, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x1F,
        0xFF, 0xFF, 0xE0, 0x00, 0x01, 0xE0, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFF, 0xFC, 0x00, 0x00, 0x00, 0x7C, 0x01, 0x00, 0x00, 0x03, 0xFF
    ),
    "EH": (
        0xFF, 0x80, 0x00, 0x00, 0xC0, 0x0F, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00,
        0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xC7, 0xF0, 0x00, 0x06, 0x03, 0xFF, 0xFF,
        0xFF, 0xFF, 0xC0, 0x00, 0x7C, 0x07, 0x03, 0xF3, 0xFC, 0x1F, 0xC0, 0x01,
        0x80, 0x20, 0x00, 0x7F, 0x81, 0xFF, 0xE0, 0x60, 0x00, 0x38, 0x01, 0xFF,
        0xFF, 0xFD, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xDF, 0xF8, 0x7C,
        0x00, 0x06, 0x00, 0x7F, 0xFF, 0xFE, 0xFF, 0xF8, 0x00, 0x1F, 0x01, 0xC1,
        0xFC, 0xFF, 0x07, 0xF0, 0x00, 0x60, 0x00, 0x00, 0x1F, 0xF0, 0x7F, 0xF8,
        0x18, 0x00, 0x1E, 0x00, 0xFF, 0xFF, 0xFF, 0x7F, 0xC0, 0x00, 0x00, 0x00,
        0x01, 0xFF, 0xFF, 0xFC, 0x07, 0xC0, 0x03, 0xE0, 0x7F, 0xFF, 0xFF, 0x87,
        0xFC, 0x00, 0x07, 0xC0, 0x78, 0x7F, 0x1F, 0x81, 0xFC, 0x00, 0x0C, 0x00,
        0x00, 0x03, 0xFC, 0x1F, 0xFE, 0x00, 0x00, 0x03, 0x80, 0x3F, 0xFF, 0xFF,
        0x9F, 0xFC, 0x00, 0x00, 0x00, 0x03, 0xFF, 0x87, 0xFF, 0xFF, 0x00, 0x7E,
        0x00, 0x1D, 0xFF, 0xFF, 0x3F, 0xF8, 0x00, 0x00, 0xF8, 0x0E, 0x1F, 0xC7,
        0xF0, 0x7F, 0x80, 0x07, 0x00, 0x00, 0x00, 0xFF, 0x07, 0xFF, 0x80, 0x80,
        0x00, 0xE0, 0x0F, 0xFF, 0xDF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x18, 0x1F,
        0xFF, 0xFF, 0xFC, 0x1E, 0x00, 0x07, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0,
        0x00, 0xFC, 0x0F, 0x07, 0xE3, 0xF8, 0x3F, 0xC0, 0x03, 0x00, 0x00, 0x00,
        0x7F, 0x83, 0xFF, 0xC0, 0xC0, 0x00, 0xF0, 0x07, 0xFF, 0xFF, 0xF9, 0xFF,
        0x80, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xF0, 0xFE, 0x00, 0x01, 0x40,
        0xFF, 0xFF, 0xFE, 0x7F, 0xF8, 0x00, 0x1F, 0x01, 0xC1, 0xFC, 0xFF, 0x07,
        0xF8, 0x00, 0x60, 0x10, 0x00, 0x1F, 0xF0, 0xFF, 0xF8, 0x18, 0x00, 0x1E,
        0x00, 0xFF, 0xFB, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFE, 0x0F, 0xC0, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x01,
        0xF0, 0x1C, 0x1F, 0x8F, 0xE0, 0xFF, 0x00, 0x06, 0x00, 0x00, 0x01, 0xFE,
        0x0F, 0xFF, 0x00, 0x00, 0x00, 0xC0, 0x0F, 0xFF, 0xBF, 0xFF, 0xFC, 0x00,
        0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xE1, 0xFC, 0x00, 0x00, 0x03, 0xFF,
        0x7F, 0xFF, 0xFF, 0xE0, 0x00, 0x0F, 0x81, 0xE0, 0xFC, 0x7F, 0x07, 0xF8,
        0x00, 0x60, 0x00, 0x00, 0x0F, 0xF0, 0x7F, 0xF8, 0x18, 0x00, 0x0E, 0x00,
        0xFF, 0xFF, 0xFF, 0x3F, 0xF0, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFE,
        0x1F, 0xE0, 0x00, 0x18, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x01, 0xF0,
        0x3C, 0x1F, 0x8F, 0xE0, 0xFF, 0x00, 0x0E, 0x00, 0x00, 0x01, 0xFE, 0x0F,
        0xFF, 0x01, 0x00, 0x00, 0x80, 0x0F, 0xFF, 0x9F, 0xFF, 0xFC, 0x00, 0x00,
        0x00, 0x00, 0x1F, 0xFF, 0xFF, 0x81, 0xF8, 0x00, 0x00, 0x07, 0xFF, 0xFF,
        0xFF, 0xFF, 0xF0, 0x00, 0x1F, 0x01, 0xC1, 0xFC, 0xFF, 0x07, 0xF8, 0x00,
        0x60, 0x00, 0x00, 0x1F, 0xE0, 0xFF, 0xF8, 0x18, 0x00, 0x1E, 0x00, 0xFF,
        0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x0F, 0xFE, 0x0F, 0xFF, 0xFC,
        0x00, 0xFC, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x07, 0xC0, 0xF0,
        0xFE, 0x3F, 0x83, 0xFC, 0x00, 0x38, 0x00, 0x00, 0x07, 0xF8, 0x3F, 0xFE,
        0x04, 0x00, 0x06, 0x00, 0x7F, 0xFC, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00,
        0x00, 0x3F, 0xFB, 0xFF, 0x03, 0xF0, 0x00, 0x18, 0x1F, 0xF8, 0xFF, 0xFF,
        0xFF, 0x00, 0x00, 0xF8, 0x1E, 0x1F, 0xC7, 0xF0, 0x7F, 0x80, 0x07, 0x00,
        0x00, 0x00, 0xFF, 0x07, 0xFF, 0x80, 0x00, 0x00, 0xC0, 0x07, 0xFF, 0xFF,
        0xFF, 0xFF, 0x00, 0x00, 0x08, 0x00, 0x1F, 0xFE, 0x7F, 0x87, 0xF0, 0x00,
        0x02, 0x03, 0xFF, 0xFF, 0xEF, 0xFF, 0xC0, 0x00, 0x3E, 0x07, 0x83, 0xF1,
        0xFC, 0x1F, 0xE0, 0x00, 0xC0, 0x00, 0x00, 0x3F, 0xC1, 0xFF, 0xF0, 0x30,
        0x00, 0x1C, 0x01, 0xFF, 0xFB, 0xFD, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x3F,
        0x9C, 0x7F, 0xFF, 0xF0, 0x03, 0xE0, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0,
        0x00, 0x1F, 0x01, 0xC1, 0xFC, 0x7F, 0x0F, 0xF0, 0x00, 0xE0, 0x00
    ),
    "OO": (
        0x00, 0x00, 0xFC, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F,
        0xFF, 0xFF, 0xFF, 0x01, 0x00, 0x07, 0xFF, 0x80, 0x00, 0x00, 0x0F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xC0, 0x0F, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x00, 0x1F,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x03, 0xFF, 0x00,
        0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00,
        0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xF0,
        0x00, 0x00, 0x7F, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03,
        0xFF, 0xFF, 0xFF, 0xFF, 0x40, 0x1E, 0x3F, 0xC0, 0x00, 0x00, 0x01, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0x70, 0x06, 0x0F, 0xC0,
        0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF,
        0xE0, 0x07, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE,
        0x03, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03,
        0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x73, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x01,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xE1, 0xFF, 0xFF, 0xC0,
        0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF,
        0xC7, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x3F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF3, 0xFF, 0xC0, 0x00,
        0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFC, 0x7F, 0xFF, 0xD0, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x79, 0xFF, 0xF8, 0x00, 0x00,
        0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00
    ),
    "IH": (
        0xF8, 0x03, 0xFC, 0x01, 0xC0, 0x00, 0x00, 0xFC, 0x00, 0xFF, 0xC0, 0x7F,
        0xE0, 0x03, 0xFC, 0x00, 0x1F, 0xE0, 0x0F, 0xFE, 0x07, 0xFF, 0x80, 0x3F,
        0x00, 0xF8, 0x3C, 0x07, 0xE1, 0xFE, 0x0F, 0xFC, 0x03, 0xFC, 0x00, 0x3E,
        0x01, 0xC0, 0xFF, 0xFC, 0x1F, 0xF0, 0x0F, 0xF0, 0x06, 0x00, 0x00, 0x00,
        0x3F, 0x00, 0xFF, 0x80, 0xFF, 0xE0, 0x0F, 0x81, 0xC0, 0x0F, 0xE0, 0x1F,
        0xF8, 0x07, 0xFE, 0x00, 0xFC, 0x03, 0xE0, 0x60, 0x3F, 0x87, 0xF0, 0x7F,
        0xE0, 0x0F, 0xF0, 0x01, 0xF0, 0x0F, 0x01, 0xFF, 0xE0, 0x7F, 0xC0, 0x3F,
        0xC0, 0x18, 0x00, 0x00, 0x01, 0xF8, 0x03, 0xFE, 0x03, 0xFF, 0x00, 0x3F,
        0x80, 0x00, 0x7F, 0x80, 0xFF, 0xF0, 0x3F, 0xFC, 0x00, 0xFC, 0x07, 0xC1,
        0xE0, 0x7F, 0x0F, 0xF0, 0xFF, 0xE0, 0x1F, 0xE0, 0x01, 0xF0, 0x0F, 0x03,
        0xFF, 0xE0, 0xFF, 0x80, 0x3F, 0xC0, 0x00, 0x00, 0x00, 0x1F, 0xE0, 0x0F,
        0xFC, 0x07, 0xFF, 0x00, 0x3F, 0xE0, 0x00, 0xFE, 0x00, 0xFF, 0xC0, 0x7F,
        0xF8, 0x01, 0xF0, 0x0F, 0x83, 0xC0, 0xFE, 0x1F, 0xC0, 0xFF, 0xC0, 0x3F,
        0xC0, 0x03, 0xE0, 0x3C, 0x0F, 0xFF, 0x81, 0xFF, 0x00, 0x7F, 0x00, 0x00,
        0x00, 0x00, 0x3F, 0x80, 0x1F, 0xF0, 0x0F, 0xFC, 0x00, 0x7F, 0xE0, 0x03,
        0xFE, 0x03, 0xFF, 0x81, 0xFF, 0x80, 0x1F, 0x80, 0xFC, 0x0C, 0x07, 0xE0,
        0xFE, 0x0F, 0xFC, 0x03, 0xFC, 0x00, 0x7E, 0x01, 0xE0, 0x7F, 0xFC, 0x1F,
        0xF0, 0x07, 0xF0, 0x06, 0x00, 0x00, 0x01, 0xFC, 0x01, 0xFF, 0x00, 0xFF,
        0x00, 0x0E, 0x7F, 0x00, 0x1F, 0xC0, 0x3F, 0xF8, 0x0F, 0xF8, 0x01, 0xF8,
        0x07, 0xC0, 0xC0, 0x7F, 0x0F, 0xE0, 0xFF, 0xC0, 0x3F, 0x80, 0x03, 0xE0,
        0x3E, 0x07, 0xFF, 0xC1, 0xFF, 0x00, 0xFF, 0x00, 0xE0, 0x00, 0x00, 0x0F,
        0xC0, 0x1F, 0xF8, 0x0F, 0xF8, 0x00, 0xFE, 0x00, 0x01, 0xFC, 0x01, 0xFF,
        0x80, 0x7F, 0xE0, 0x03, 0xF0, 0x0F, 0x87, 0x80, 0xFE, 0x3F, 0xC1, 0xFF,
        0x80, 0x7F, 0x80, 0x07, 0xC0, 0x78, 0x1F, 0xFF, 0x83, 0xFE, 0x00, 0xFF,
        0x00, 0x80, 0x80, 0x00, 0x0F, 0xC0, 0x1F, 0xF0, 0x0F, 0xF8, 0x01, 0xF1,
        0xFC, 0x03, 0xFE, 0x01, 0xFF, 0x80, 0xFF, 0xC0, 0x07, 0xC0, 0x3E, 0x07,
        0x01, 0xF8, 0x7F, 0x03, 0xFF, 0x00, 0xFF, 0x00, 0x1F, 0x00, 0xF0, 0x3F,
        0xFF, 0x07, 0xF8, 0x03, 0xFC, 0x03, 0x80, 0x00, 0x00, 0x1F, 0x80, 0x3F,
        0xE0, 0x3F, 0xF0, 0x03, 0xC1, 0xF8, 0x07, 0xFC, 0x03, 0xFE, 0x03, 0xFF,
        0xC0, 0x1F, 0x80, 0xF8, 0x1C, 0x07, 0xE1, 0xFE, 0x0F, 0xFC, 0x03, 0xF8,
        0x00, 0x7E, 0x03, 0xC0, 0xFF, 0xF8, 0x1F, 0xF0, 0x07, 0xF0, 0x0C, 0x00,
        0x00, 0x00, 0x7F, 0x00, 0xFF, 0xC0, 0x7F, 0xE0, 0x1F, 0xC7, 0xE0, 0x0F,
        0xF0, 0x1F, 0xFE, 0x07, 0xFC, 0x00, 0xFC, 0x07, 0xC0, 0xC0, 0x7F, 0x0F,
        0xF0, 0x7F, 0xE0, 0x1F, 0xC0, 0x03, 0xF0, 0x1F, 0x07, 0xFF, 0xC0, 0xFF,
        0x00, 0x7F, 0x00, 0xF0, 0x00, 0x00, 0x01, 0xF8, 0x03, 0xFC, 0x07, 0xFE,
        0x03, 0xF8, 0x1F, 0x80, 0xFF, 0x00, 0x7F, 0xE0, 0x7F, 0xC0, 0x03, 0xF0,
        0x1F, 0x03, 0x80, 0xFE, 0x3F, 0x81, 0xFF, 0x80, 0x7F, 0x00, 0x07, 0xC0,
        0x7C, 0x0F, 0xFF, 0x03, 0xFC, 0x00, 0xFF, 0x00, 0xC0, 0x00, 0x00, 0x03,
        0xF0, 0x0F, 0xF8, 0x0F, 0xFC, 0x03, 0xF0, 0x7F, 0x01, 0xFF, 0x00, 0xFF,
        0xC0, 0xFF, 0xCC, 0x01, 0xF8, 0x0F, 0x83, 0xC0, 0xFF, 0x1F, 0xC1, 0xFF,
        0xC0, 0x3F, 0x80, 0x03, 0xE0, 0x3C, 0x0F, 0xFF, 0x83, 0xFE, 0x00, 0x7F,
        0x00, 0x80, 0x00, 0x00, 0x07, 0xF0, 0x0F, 0xFC, 0x0F, 0xFE, 0x01, 0xF8,
        0x7E, 0x01, 0xFF, 0x01, 0xFF, 0xC0, 0xFF, 0xE0, 0x01, 0xF8, 0x0F, 0x81,
        0xC0, 0xFF, 0x1F, 0xC0, 0xFF, 0xC0, 0x3F, 0x80, 0x03, 0xE0, 0x1E, 0x07,
        0xFF, 0x81, 0xFF, 0x00, 0xFF, 0x00, 0x60, 0x00, 0x00, 0x03, 0xF8, 0x07,
        0xFC, 0x07, 0xFF, 0x01, 0xF8, 0x3F, 0x00, 0xFF, 0x00, 0xFF, 0xC0, 0x3F,
        0xF8, 0x00, 0xFC, 0x07, 0xC1, 0xE0, 0x7F, 0x0F, 0xE0, 0xFF, 0xE0, 0x1F,
        0xC0, 0x01, 0xF0, 0x0E, 0x03, 0xFF, 0xC0, 0xFF, 0x00, 0x3F, 0x80
    ),
    "EE": (
        0x00, 0x03, 0xF0, 0x1F, 0x80, 0x3F, 0xE0, 0x0F, 0xE0, 0x1F, 0xF0, 0x7F,
        0xFF, 0x01, 0xFE, 0x00, 0x07, 0xE0, 0x0F, 0xE0, 0x0F, 0xF0, 0x07, 0xFC,
        0x07, 0xF8, 0x01, 0xFF, 0x00, 0xFE, 0x00, 0x7F, 0x00, 0x1F, 0xC0, 0x7F,
        0xC0, 0x3F, 0xF8, 0x0F, 0xFE, 0x0C, 0x03, 0xF0, 0x1F, 0x80, 0x3F, 0xC0,
        0x0F, 0xE0, 0x0F, 0xF0, 0x3F, 0xFF, 0x01, 0xFE, 0x00, 0x07, 0xE0, 0x0F,
        0xE0, 0x0F, 0xF0, 0x03, 0xFC, 0x07, 0xF8, 0x01, 0xFF, 0x00, 0x7F, 0x00,
        0x3F, 0x80, 0x0F, 0xE0, 0x3F, 0xE0, 0x0F, 0xF8, 0x07, 0xFC, 0x0F, 0xC0,
        0x7E, 0x03, 0xF0, 0x07, 0xFC, 0x01, 0xFE, 0x03, 0xFE, 0x0F, 0xFF, 0xF0,
        0x3F, 0x80, 0x00, 0xFC, 0x00, 0xFC, 0x01, 0xFE, 0x00, 0x7F, 0x00, 0xFF,
        0x00, 0x7F, 0xC0, 0x07, 0xE0, 0x03, 0xF8, 0x01, 0xFC, 0x03, 0xFE, 0x03,
        0xFF, 0x80, 0xFF, 0x03, 0xF8, 0x0F, 0xC0, 0x7E, 0x00, 0xFF, 0x00, 0x7F,
        0x80, 0x7F, 0x81, 0xFF, 0xFE, 0x07, 0xF0, 0x00, 0x1F, 0x80, 0x3F, 0x80,
        0x7F, 0x80, 0x1F, 0xE0, 0x1F, 0xE0, 0x1F, 0xE3, 0x00, 0xFC, 0x00, 0x7E,
        0x00, 0x7F, 0x80, 0x7F, 0x80, 0x7F, 0xE0, 0x3F, 0xE0, 0x7E, 0x01, 0xF8,
        0x1F, 0xC0, 0x3F, 0xE0, 0x0F, 0xF0, 0x0F, 0xF0, 0x3F, 0xFF, 0x81, 0xFE,
        0x00, 0x03, 0xF0, 0x07, 0xE0, 0x0F, 0xF0, 0x03, 0xFC, 0x07, 0xFC, 0x01,
        0xFF, 0x00, 0x3F, 0x00, 0x0F, 0xC0, 0x0F, 0xF0, 0x0F, 0xF0, 0x1F, 0xFC,
        0x07, 0xFC, 0x07, 0xC0, 0x7E, 0x03, 0xF0, 0x07, 0xF8, 0x01, 0xFC, 0x03,
        0xFC, 0x0F, 0xFF, 0xE0, 0x7F, 0x80, 0x00, 0xFC, 0x01, 0xFC, 0x01, 0xFC,
        0x00, 0xFF, 0x01, 0xFF, 0x00, 0x7F, 0x80, 0x0F, 0xC0, 0x07, 0xF0, 0x03,
        0xFC, 0x03, 0xFC, 0x03, 0xFF, 0x01, 0xFF, 0x80, 0x00, 0x7E, 0x03, 0xF0,
        0x07, 0xFC, 0x01, 0xFE, 0x01, 0xFE, 0x07, 0xFF, 0xE0, 0x3F, 0xC0, 0x00,
        0xFC, 0x01, 0xFC, 0x01, 0xFE, 0x00, 0xFF, 0x80, 0xFF, 0x80, 0x7F, 0xE0,
        0x07, 0xE0, 0x03, 0xF0, 0x01, 0xFC, 0x03, 0xFE, 0x01, 0xFF, 0x01, 0xFF,
        0x81, 0xF0, 0x1F, 0x00, 0xFC, 0x01, 0xFE, 0x00, 0xFF, 0x00, 0xFF, 0x03,
        0xFF, 0xF8, 0x0F, 0xE0, 0x00, 0x3F, 0x00, 0x7F, 0x00, 0xFF, 0x00, 0x3F,
        0xC0, 0x7F, 0xC0, 0x1F, 0xE0, 0x03, 0xF0, 0x01, 0xFC, 0x00, 0xFF, 0x00,
        0xFF, 0x80, 0xFF, 0xC0, 0x7F, 0xE0, 0x00, 0x3F, 0x00, 0xFC, 0x01, 0xFF,
        0x00, 0x7F, 0x00, 0xFF, 0x01, 0xFF, 0xF8, 0x0F, 0xE0, 0x00, 0x3F, 0x00,
        0x7F, 0x00, 0xFF, 0x80, 0x3F, 0xC0, 0x3F, 0xE0, 0x0F, 0xF0, 0x03, 0xF0,
        0x01, 0xFC, 0x00, 0xFE, 0x01, 0xFF, 0x80, 0x7F, 0xC0, 0xFF, 0xE0, 0x38,
        0x0F, 0xC0, 0x7F, 0x00, 0xFF, 0x00, 0x3F, 0x80, 0x7F, 0x80, 0xFF, 0xFE,
        0x07, 0xF8, 0x00, 0x0F, 0x80, 0x3F, 0x80, 0x3F, 0xC0, 0x0F, 0xF0, 0x1F,
        0xF0, 0x0F, 0xF0, 0x01, 0xF8, 0x00, 0x7E, 0x00, 0x3F, 0x80, 0x7F, 0xE0,
        0x3F, 0xF0, 0x3F, 0xF8, 0x38, 0x07, 0xE0, 0x3F, 0x00, 0x7F, 0x80, 0x1F,
        0xC0, 0x1F, 0xE0, 0x7F, 0xFF, 0x03, 0xFC, 0x00, 0x07, 0xC0, 0x1F, 0xC0,
        0x1F, 0xE0, 0x07, 0xF8, 0x0F, 0xF8, 0x03, 0xFC, 0x00, 0xFC, 0x00, 0x3E,
        0x00, 0x1F, 0xC0, 0x3F, 0xE0, 0x7F, 0xF0, 0x1F, 0xF8, 0x07, 0x03, 0xF0,
        0x1F, 0x80, 0x3F, 0xC0, 0x0F, 0xE0, 0x1F, 0xE0, 0x7F, 0xFF, 0x81, 0xFE,
        0x00, 0x07, 0xE0, 0x0F, 0xE0, 0x1F, 0xF0, 0x03, 0xFC, 0x07, 0xF8, 0x03,
        0xFC, 0x00, 0x7E, 0x00, 0x1F, 0x00, 0x0F, 0xE0, 0x1F, 0xF0, 0x0F, 0xF8,
        0x0F, 0xFE, 0x0F, 0x01, 0xF0, 0x0F, 0xC0, 0x1F, 0xE0, 0x07, 0xF0, 0x0F,
        0xF0, 0x3F, 0xFF, 0x80, 0xFE, 0x00, 0x03, 0xF0, 0x03, 0xF0, 0x0F, 0xF8,
        0x03, 0xFE, 0x03, 0xFE, 0x00, 0xFC, 0x00, 0x3F, 0x00, 0x02, 0x90, 0x03,
        0xF8, 0x0F, 0xFE, 0x0F, 0xFC, 0x03, 0xFF, 0x00, 0x03, 0xF0, 0x1F, 0x80,
        0x3F, 0xE0, 0x0F, 0xF0, 0x0F, 0xF0, 0x3F, 0xFF, 0x80, 0xFF, 0x00, 0x07,
        0xE0, 0x07, 0xE0, 0x0F, 0xF0, 0x03, 0xFC, 0x07, 0xFC, 0x01, 0xFC, 0x00,
        0x7E, 0x00, 0x1F, 0x00, 0x0F, 0xE0, 0x1F, 0xF8, 0x1F, 0xFC, 0x0F
    ),
    "WH": (
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF,
        0xFF, 0xC0, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCC, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x07,
        0xC0, 0x00, 0x00, 0x00, 0x07, 0xE3, 0x8F, 0xFF, 0xE0, 0x01, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0x1E, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xC0, 0x00,
        0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF,
        0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFE, 0x84, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF,
        0xFF, 0xB1, 0xE3, 0xFF, 0xFF, 0xFF, 0xFF, 0xC6, 0x90, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x01,
        0xFF, 0xFF, 0xFF, 0xE7, 0x00, 0x01, 0xE7, 0xFF, 0xFE, 0xBF, 0x39, 0xFF,
        0xF7, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x1F, 0xFF, 0xFF, 0xFF, 0xF0, 0x00,
        0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x1E, 0x8F,
        0x81, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFF,
        0xFF, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xFF, 0xF0, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00,
        0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x07,
        0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF,
        0xFF, 0xE0, 0x00, 0x00, 0x0F, 0xFF, 0xE0, 0x00, 0x00, 0x00, 0xFF, 0xFF,
        0xFF, 0xFC, 0x00, 0x00, 0x00, 0x3F, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x03,
        0xFF, 0xF8, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x3F,
        0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00,
        0x03, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x3F, 0xFF, 0xE0, 0x00, 0x00, 0x00,
        0x7F, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFE, 0xE0, 0x00,
        0x00, 0x00, 0x18, 0x07, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x7F,
        0xFF, 0xFF, 0xFC, 0x60, 0x00, 0x00, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0xFF,
        0xF0, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFD, 0xE0, 0xEF, 0xFF, 0xFF, 0x00,
        0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF,
        0xE0, 0x30, 0x07, 0x83, 0xF0, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xF8, 0x00,
        0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0x80,
        0x00, 0x00, 0x00, 0x1E, 0x0F, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x1F,
        0xFF, 0xFF, 0xE1, 0xF0, 0x04, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFE,
        0x00, 0x00, 0x00, 0x27, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x07, 0xD9, 0xFF,
        0x60, 0x08, 0x00, 0x00, 0x01, 0xE7, 0xFF, 0xFF, 0xC0, 0x30, 0x07, 0x80,
        0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x07, 0xCF, 0xFF, 0xC1, 0xF0, 0x3F, 0x83,
        0xE0, 0x00, 0x00, 0x07, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0x01, 0xFF, 0xFF,
        0x80, 0x00, 0x23, 0x07, 0xC0, 0x00, 0x00, 0x7F, 0xFF, 0xE0, 0x00, 0x00,
        0x00, 0xFF, 0xFF, 0xE0, 0x00, 0x00, 0x03, 0xFF, 0xF7, 0x80, 0x00, 0x00,
        0x31, 0x40, 0x00, 0x00, 0x07, 0xFF, 0xEF, 0x80, 0x00, 0x00, 0x07, 0xFF,
        0xFF, 0xDC, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x39, 0xFF, 0xE0, 0x00,
        0x00, 0x00, 0x38, 0x77, 0xC0, 0x00, 0x00, 0x00, 0x73, 0xE6, 0x08, 0x00,
        0x08, 0x22, 0x00, 0x00, 0x08, 0x33, 0xFF, 0x00, 0x00, 0x00, 0x03, 0xFF,
        0xFF, 0xC0, 0x00, 0x00, 0x01, 0x78, 0x00, 0x00, 0x07, 0xFF, 0xF8, 0x00,
        0x00, 0x03, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x9E, 0xFE, 0x18, 0x00, 0x00,
        0x00, 0x60, 0x00, 0x00, 0x04, 0x10, 0x44, 0x00, 0x00, 0x00, 0x02
    ),
    "CH": (
        0x0F, 0xC0, 0x3F, 0x07, 0xC3, 0x9F, 0x07, 0xE0, 0x07, 0x80, 0x7E, 0x1F,
        0x78, 0x7E, 0x00, 0xF8, 0x1F, 0xC3, 0xF8, 0x7F, 0x0E, 0x3F, 0x07, 0x0F,
        0x03, 0xF0, 0x00, 0xF0, 0xE3, 0x83, 0xE0, 0x78, 0xF0, 0xF8, 0x03, 0xC0,
        0xF8, 0xE1, 0xFF, 0x07, 0x87, 0x87, 0xC3, 0xC3, 0x0F, 0xE0, 0xF1, 0xC0,
        0xFE, 0x60, 0x0F, 0x80, 0xF8, 0xF8, 0x7C, 0x78, 0x7C, 0x70, 0xF8, 0x77,
        0xF0, 0xC7, 0xE0, 0x7C, 0x7C, 0x00, 0xF8, 0x83, 0xF0, 0x3F, 0xF0, 0xC3,
        0x86, 0x38, 0x7E, 0x1F, 0x1E, 0x7C, 0x07, 0x8E, 0x0F, 0xE0, 0xFC, 0x0F,
        0x0F, 0x81, 0xC7, 0xC3, 0xF1, 0xC3, 0xC7, 0xE1, 0x8F, 0x03, 0xCE, 0x07,
        0xCE, 0x3C, 0x78, 0x3E, 0x3C, 0x71, 0xC7, 0x1E, 0x38, 0x7F, 0x0F, 0x3C,
        0x03, 0xE0, 0xF8, 0x1E, 0x70, 0x3E, 0x1E, 0x0F, 0xC3, 0xC3, 0x83, 0xC1,
        0xCF, 0x0F, 0xC0, 0xFB, 0x0C, 0x78, 0x1F, 0x08, 0xEF, 0x83, 0xC0, 0xFF,
        0x07, 0xC0, 0xF0, 0xF8, 0x3E, 0x3C, 0x3F, 0x03, 0xE0, 0xF0, 0xF8, 0x78,
        0xF3, 0x87, 0xE1, 0x8F, 0x38, 0x7E, 0x3F, 0xC3, 0x98, 0x78, 0x78, 0x1E,
        0x0F, 0x00, 0x78, 0x60, 0x7C, 0x31, 0xCC, 0x3F, 0x9E, 0x07, 0xC6, 0x03,
        0xE0, 0xFF, 0x03, 0xFC, 0x70, 0xF8, 0x78, 0xFC, 0x1F, 0xE3, 0x00, 0xFC,
        0x3F, 0x00, 0x78, 0x83, 0xF0, 0x3F, 0xE1, 0x07, 0x8E, 0x38, 0xFF, 0x03,
        0xE0, 0x07, 0xC3, 0x80, 0x1F, 0x87, 0xF8, 0xF8, 0x70, 0xE0, 0x3E, 0x1E,
        0x1C, 0x78, 0x7C, 0x0F, 0x83, 0x3F, 0x81, 0xF0, 0x7C, 0x03, 0xF0, 0xFC,
        0x78, 0x78, 0x1E, 0x31, 0xF0, 0xF1, 0xE0, 0xF8, 0x3F, 0xE0, 0x3C, 0x1F,
        0x0F, 0x1F, 0x0F, 0x80, 0xC7, 0x80, 0xFC, 0x1E, 0x1F, 0x86, 0x0F, 0x87,
        0xC3, 0x81, 0xE1, 0x87, 0xF8, 0x78, 0x31, 0xE0, 0x3C, 0xF0, 0x7C, 0x0E,
        0x03, 0xFC, 0x1F, 0x87, 0xE1, 0xC7, 0x30, 0xF3, 0x1F, 0xE3, 0xC7, 0x8F,
        0x00, 0xF8, 0x07, 0xCE, 0x3C, 0x7F, 0x1C, 0xF1, 0xE0, 0xFE, 0x3C, 0x3C,
        0x43, 0xC1, 0xE0, 0xF0, 0xE3, 0x0F, 0xC0, 0xFE, 0x30, 0xE3, 0x81, 0xC3,
        0xC1, 0xE0, 0x3C, 0x78, 0x78, 0x8E, 0x1C, 0x38, 0xFE, 0x1C, 0x7C, 0x78,
        0x78, 0x7C, 0x03, 0xFF, 0x1F, 0x07, 0x80, 0x3B, 0xE0, 0xC7, 0xF0, 0x07,
        0xCE, 0x03, 0xC3, 0x0F, 0x80, 0x0F, 0xC0, 0x70, 0x8E, 0x1F, 0xC1, 0x9F,
        0x00, 0x3C, 0xE0, 0x1F, 0xF0, 0xFF, 0x03, 0xF8, 0xE1, 0x9E, 0x01, 0xF0,
        0x83, 0xC7, 0x01, 0xEF, 0x07, 0x3E, 0x1C, 0x1F, 0xC2, 0x1F, 0xC3, 0x39,
        0xEF, 0x1C, 0xF0, 0x1F, 0x83, 0x00, 0xF0, 0x5F, 0x0E, 0x01, 0xC3, 0xC0,
        0x3F, 0x98, 0x3F, 0x83, 0x1F, 0x00, 0x39, 0xE0, 0x0F, 0x1E, 0x1F, 0x8E,
        0x1C, 0x67, 0x80, 0xC7, 0x06, 0xF0, 0xF0, 0xC3, 0x98, 0x70, 0xE1, 0xC2,
        0x1C, 0x71, 0xC1, 0x8F, 0x01, 0xF0, 0xF3, 0xF0, 0x7E, 0xF0, 0xF8, 0x1F,
        0xC3, 0x83, 0xF0, 0x18, 0xF8, 0x3F, 0x03, 0x8F, 0x07, 0xE0, 0xE1, 0xE2,
        0x01, 0xF1, 0xC1, 0xF3, 0x00, 0x7E, 0x00, 0xF8, 0x01, 0xF1, 0x81, 0xFF,
        0x03, 0x07, 0x8F, 0x80, 0xE1, 0xE3, 0xE1, 0x83, 0xF8, 0x01, 0xF7, 0x81,
        0xF1, 0x83, 0xFF, 0x0F, 0x0E, 0x1E, 0x38, 0x1F, 0x9C, 0x03, 0x8F, 0x80,
        0x7C, 0xFC, 0xC0, 0x7E, 0x0F, 0x1C, 0x1E, 0x3F, 0x00, 0x30, 0x1F, 0x80,
        0xF0, 0x01, 0xF0, 0x3C, 0x78, 0x20, 0x07, 0xE3, 0x83, 0x0F, 0x1E, 0x00,
        0xCE, 0x60, 0x3E, 0x3E, 0x07, 0xC0, 0x03, 0xC0, 0xFC, 0x70, 0x01, 0xFC,
        0x00, 0x7C, 0x00, 0x0F, 0x07, 0x0F, 0x00, 0x00, 0xF1, 0x81, 0xE0, 0x1C,
        0xE1, 0x00, 0x73, 0xE0, 0x01, 0xF0, 0x71, 0xE0, 0x3D, 0xF0, 0x61, 0xFC,
        0x00, 0x3F, 0xE0, 0x00, 0x78, 0xF8, 0xF0, 0x3F, 0xC0, 0x0E, 0x60, 0x0F,
        0x80, 0x00, 0x70, 0x00, 0x00, 0x78, 0xE0, 0x38, 0xF0, 0xFF, 0x06, 0x1F,
        0x01, 0x0F, 0x07, 0x18, 0x73, 0x0C, 0x38, 0x3E, 0x0F, 0x01, 0xFC, 0x00,
        0x3F, 0x00, 0x00, 0x00, 0x0C, 0x00, 0x03, 0x80, 0xE0, 0xE0, 0x1E, 0x70,
        0x00, 0x20, 0xC2, 0x00, 0xFF, 0xC0, 0x03, 0xFE, 0x10, 0x04, 0xC3, 0x80,
        0x00, 0xFF, 0x00, 0x0F, 0x19, 0x00, 0x0F, 0xC0, 0x03, 0xF0, 0x00
    ),
    "SH": (
        0x07, 0x81, 0xE0, 0x0E, 0x0F, 0x02, 0x1E, 0x3C, 0x1F, 0xF0, 0xC1, 0xF0,
        0x71, 0xFE, 0x07, 0xC0, 0xF8, 0x1E, 0x1F, 0x00, 0x1F, 0x83, 0xDF, 0x07,
        0x87, 0x00, 0xCF, 0x0F, 0x1C, 0x3E, 0x07, 0x03, 0xC4, 0x3E, 0x1E, 0x3C,
        0x3F, 0x03, 0xE0, 0x0F, 0xE0, 0xF8, 0x7C, 0x1F, 0x03, 0xF0, 0x3F, 0x07,
        0xFC, 0x0F, 0xFE, 0x07, 0xF0, 0x7C, 0x00, 0x7C, 0x1F, 0xC1, 0xF0, 0xF8,
        0x1F, 0x83, 0xC1, 0xC3, 0xC0, 0xCF, 0xE0, 0xC3, 0xE0, 0xFE, 0x0E, 0x3C,
        0x03, 0xC7, 0x80, 0xF0, 0x03, 0xC3, 0x80, 0x3E, 0x08, 0x7E, 0x0F, 0xC1,
        0xC0, 0xFE, 0x0F, 0xF0, 0x3C, 0x78, 0x1F, 0x83, 0xFF, 0x03, 0xFE, 0x01,
        0xF7, 0x03, 0xF0, 0xE3, 0xF0, 0x01, 0xF0, 0x7F, 0x00, 0xFE, 0x00, 0xFE,
        0x01, 0xFE, 0x18, 0x3C, 0x70, 0xFC, 0x0E, 0x7C, 0x3F, 0x38, 0x3C, 0x7C,
        0x03, 0xF0, 0x01, 0xF0, 0x03, 0xF0, 0x07, 0xF0, 0x3F, 0xF0, 0x3E, 0xE0,
        0x0F, 0x80, 0xFF, 0x80, 0xFE, 0x07, 0x3C, 0x3C, 0x3E, 0x03, 0xE1, 0xCE,
        0x1F, 0x03, 0xE0, 0xCF, 0x38, 0x3F, 0x83, 0x8F, 0x83, 0x0F, 0x80, 0x7E,
        0x10, 0xF0, 0xF0, 0x71, 0xC3, 0xE0, 0x3E, 0x1C, 0x07, 0x87, 0x80, 0x1E,
        0x1E, 0x38, 0xE0, 0xE1, 0xE0, 0xCF, 0x0F, 0xC1, 0xFF, 0x07, 0x81, 0xF8,
        0x3F, 0x07, 0x07, 0xFE, 0x0F, 0xCE, 0x0F, 0x07, 0x30, 0xE1, 0xE0, 0xE1,
        0xE1, 0x1F, 0x07, 0x07, 0x83, 0xFC, 0x3C, 0x3C, 0x38, 0x7C, 0x1F, 0x83,
        0xC0, 0x00, 0xF8, 0x1F, 0x07, 0x07, 0x87, 0x1E, 0x07, 0xC0, 0x1E, 0x1F,
        0x01, 0xFF, 0x80, 0xC1, 0xE0, 0xFE, 0x03, 0x3E, 0x60, 0x7F, 0x00, 0xE1,
        0xF0, 0x7E, 0x0F, 0x1F, 0x07, 0x9E, 0x00, 0xFF, 0x0E, 0x1F, 0x00, 0xF8,
        0x3C, 0x3F, 0x03, 0xF0, 0x1F, 0xC3, 0x83, 0xF8, 0x0F, 0xC0, 0x0F, 0xE0,
        0x1F, 0x8F, 0x0F, 0x80, 0x70, 0xE0, 0xF8, 0x10, 0xF8, 0x11, 0xF8, 0x0F,
        0xC0, 0x1E, 0x3C, 0x0F, 0x0F, 0x0F, 0x81, 0xF8, 0xC0, 0xFF, 0x80, 0x3E,
        0x1E, 0x01, 0xF8, 0x11, 0xF0, 0x1F, 0x03, 0xC7, 0x0E, 0x0F, 0xF0, 0x7C,
        0x40, 0xFE, 0x0F, 0x0F, 0x07, 0x1F, 0x0F, 0xC1, 0xE0, 0xF1, 0xC0, 0xFC,
        0x07, 0xC6, 0x0C, 0x7C, 0x30, 0xFC, 0x03, 0xF0, 0x78, 0x7C, 0x1C, 0x7C,
        0x1F, 0x00, 0x78, 0xF8, 0x1F, 0xF8, 0x61, 0xE1, 0xC0, 0x7E, 0x07, 0xC0,
        0x03, 0xF0, 0x31, 0xF8, 0x3F, 0x80, 0xFF, 0x87, 0x87, 0xE0, 0x7C, 0x3C,
        0x0F, 0xC0, 0xFC, 0x07, 0x8F, 0x03, 0xF0, 0x03, 0xFC, 0x0F, 0x83, 0x83,
        0xE1, 0xE1, 0xF8, 0x3F, 0x1C, 0x01, 0xF0, 0x7E, 0x07, 0x0F, 0xC0, 0x7F,
        0x01, 0xF8, 0x01, 0xF0, 0x78, 0xF0, 0x41, 0xF0, 0x70, 0xF0, 0x3C, 0x78,
        0x38, 0xE3, 0x07, 0x1E, 0x1C, 0x1F, 0x01, 0xE1, 0x83, 0xF0, 0xC3, 0xE0,
        0x7F, 0xE0, 0xF8, 0xF8, 0x07, 0xE0, 0xF0, 0xE1, 0xC3, 0xC1, 0xF3, 0xC0,
        0xF8, 0x3F, 0x0F, 0x07, 0x83, 0xC3, 0xC0, 0xFF, 0x03, 0xE0, 0x07, 0xE0,
        0x7F, 0x00, 0x3C, 0x78, 0x78, 0x3D, 0xE0, 0xF0, 0xF8, 0x0F, 0xF0, 0x07,
        0xE0, 0x78, 0x7C, 0x1F, 0x80, 0x1F, 0x07, 0x0F, 0x80, 0x7F, 0x81, 0xE1,
        0xE0, 0x0F, 0xC1, 0x07, 0xC0, 0xFF, 0x00, 0xF8, 0x3C, 0x03, 0xE0, 0xF8,
        0x7C, 0x03, 0x8F, 0x07, 0x83, 0xF0, 0xFF, 0x0C, 0x70, 0x3F, 0x0F, 0x0F,
        0x80, 0x78, 0xE1, 0xC0, 0xF0, 0x70, 0xFC, 0x1C, 0x1F, 0x1E, 0x38, 0xF8,
        0x78, 0x7C, 0x3C, 0x1E, 0x70, 0xE1, 0xF0, 0xF3, 0x83, 0x8E, 0x38, 0x60,
        0xF0, 0x79, 0xE0, 0xFC, 0x1E, 0x3C, 0x61, 0xF0, 0x73, 0xC0, 0x1E, 0x3C,
        0x1F, 0x01, 0xF0, 0xF1, 0xC3, 0xC1, 0xF0, 0x00, 0x7F, 0xC1, 0xFF, 0x80,
        0x3C, 0x3C, 0x7F, 0x03, 0xE0, 0xF8, 0x78, 0x3F, 0x81, 0xE0, 0xF0, 0x7F,
        0xC0, 0xFE, 0x00, 0xF0, 0xE0, 0x07, 0x81, 0xFC, 0x03, 0xE0, 0xF0, 0x7C,
        0x0E, 0x3C, 0x3E, 0x07, 0xC0, 0x73, 0xC3, 0xFC, 0x0F, 0xF8, 0x78, 0x7C,
        0x1F, 0x80, 0xF8, 0x07, 0x0F, 0x83, 0xF0, 0x78, 0x0F, 0xE0, 0xFC, 0x03,
        0x8F, 0x07, 0x87, 0xC0, 0xF8, 0xE0, 0x1F, 0x07, 0xF0, 0xF8, 0x7E, 0x38,
        0x3F, 0x00, 0x3F, 0x81, 0x9F, 0x81, 0xFE, 0x00, 0xFC, 0x03, 0xF0
    ),
    "TZ": (
        0xFE, 0xEF, 0x79, 0xCF, 0x73, 0x9C, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x38, 0xE1, 0xFF, 0x9E, 0xFF, 0xBF, 0xFF, 0xFB,
        0xFF, 0xFF, 0xFF, 0x1C, 0xF3, 0x80, 0x0E, 0x30, 0x8E, 0x40, 0x64, 0x20,
        0x87, 0x19, 0xFF, 0xF8, 0xFF, 0x7C, 0xEF, 0x9E, 0xF3, 0x9F, 0xFF, 0x3C,
        0xE3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0x0C,
        0x7D, 0xF7, 0xEF, 0xF7, 0xFF, 0xDF, 0xEF, 0xF7, 0xFF, 0xC7, 0xFC, 0xC0,
        0x1E, 0x00, 0x3E, 0x18, 0x80, 0x20, 0x03, 0x84, 0xE7, 0x3F, 0xBE, 0xE7,
        0xFF, 0xE3, 0x7F, 0x9C, 0xFF, 0x39, 0xEE, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x01, 0x00, 0x01, 0x80, 0x3F, 0xFF, 0xFF, 0xF3, 0xFF, 0xDD,
        0xFF, 0xBD, 0xFF, 0xE7, 0x3F, 0xE0, 0x03, 0x06, 0x1C, 0xC4, 0x61, 0x00,
        0x18, 0xC8, 0x77, 0xF3, 0x1E, 0xF1, 0xFC, 0xE7, 0x73, 0xFC, 0xFE, 0xE3,
        0x9E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x02, 0x3E,
        0x1F, 0xFF, 0xFF, 0xFE, 0xF3, 0xFF, 0xFF, 0xF7, 0x3F, 0xF9, 0xE7, 0xF8,
        0x80, 0x82, 0x03, 0x73, 0x00, 0x00, 0x08, 0xFC, 0x61, 0xFF, 0x9E, 0xFC,
        0xE7, 0xB8, 0xEF, 0xFE, 0xF3, 0xCF, 0xCF, 0xE0, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xC7, 0xFF, 0x3F, 0xFF, 0xFF, 0xFF,
        0xCF, 0x7F, 0xDF, 0x9C, 0xE7, 0xFC, 0x00, 0x70, 0x83, 0xE3, 0x10, 0x86,
        0x00, 0x7E, 0x38, 0xFC, 0x7E, 0xF3, 0x9F, 0xCF, 0x1F, 0xBF, 0x1F, 0xFE,
        0xFF, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x46,
        0x78, 0xFF, 0xF3, 0xDF, 0x8F, 0xFF, 0xF7, 0xFF, 0xBF, 0xEF, 0x73, 0xCF,
        0x20, 0x06, 0x00, 0x7C, 0x20, 0x31, 0x80, 0xC7, 0x30, 0xC7, 0xEE, 0xE7,
        0x3C, 0xFF, 0xF1, 0xFE, 0xF3, 0xFC, 0xFE, 0xFC, 0xC0, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0xC1, 0x8F, 0xFF, 0x7F, 0xFF, 0x9C,
        0xFF, 0xBF, 0xFF, 0xFF, 0xF9, 0x99, 0xE0, 0xC0, 0x61, 0x80, 0xEE, 0x02,
        0x38, 0x30, 0x7E, 0x33, 0xDC, 0xC7, 0xFF, 0x3F, 0x9C, 0xE7, 0x7F, 0x33,
        0xC3, 0x8F, 0xE6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00,
        0x07, 0x07, 0x1F, 0xBF, 0xFF, 0xFD, 0xF7, 0xDE, 0xFF, 0xFF, 0xFF, 0x79,
        0xFC, 0xE0, 0x01, 0x81, 0x07, 0x00, 0x04, 0x00, 0x61, 0xF3, 0x79, 0x8F,
        0x9C, 0xF0, 0xFD, 0xF6, 0xDC, 0xE6, 0xE7, 0x1F, 0x7E, 0xFC, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0xEC, 0xFF, 0xFB, 0xFF,
        0xCF, 0xFF, 0x9C, 0xE7, 0xF9, 0xFF, 0xFC, 0xC1, 0x80, 0x03, 0x00, 0x1F,
        0x00, 0x00, 0xC2, 0x03, 0xE3, 0x1F, 0xF1, 0xFF, 0xFC, 0xF3, 0x8E, 0x7F,
        0x73, 0xB9, 0xCF, 0x3E, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x10, 0x70, 0xED, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xEF, 0xFF,
        0xE3, 0x8F, 0x8C, 0x80, 0x0E, 0x30, 0xF9, 0xC0, 0x00, 0x00, 0x0F, 0x63,
        0x0F, 0x38, 0xDF, 0x1C, 0xFF, 0xF7, 0x3F, 0xCF, 0x7E, 0xF3, 0x7E, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xC0, 0x03, 0xE0, 0x1E, 0xF3,
        0xFF, 0xFF, 0xFF, 0xF8, 0xFE, 0xF3, 0x9C, 0xEC, 0x7B, 0x8C, 0x02, 0x00,
        0x07, 0x20, 0x03, 0x00, 0x00, 0xF1, 0x87, 0xF7, 0x3B, 0xBE, 0xFF, 0xF7,
        0x3F, 0xFC, 0xCE, 0x7B, 0x9E, 0xFC, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x03, 0x00, 0x0E, 0x30, 0xFF, 0xF3, 0xFF, 0xCF, 0xFF, 0xFF, 0xFE,
        0x7C, 0xF3, 0xB9, 0x79, 0x80, 0x07, 0x00, 0x33, 0x00, 0x71, 0x8C, 0x60,
        0xC3, 0xCF, 0x73, 0xBC, 0xCE, 0x79, 0xFE, 0x3F, 0xF7, 0x1E, 0xFC, 0xE7,
        0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x61, 0x01, 0xBF,
        0xDF, 0x7F, 0xFF, 0xFF, 0xFF, 0xCF, 0xFB, 0x9F, 0xEF, 0x77, 0x63, 0x00,
        0x18, 0x01, 0xC7, 0x00, 0x30, 0x18, 0xDE, 0x73, 0x7D, 0x8F, 0x9E, 0xFE,
        0xFF, 0x8F, 0x9F, 0x0F, 0xF3, 0x87, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x01, 0x80, 0x03, 0x0E, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF
    ),
    "TH": (
        0xC7, 0x37, 0xB3, 0x9C, 0x73, 0x98, 0xE3, 0x86, 0x40, 0xC6, 0x80, 0x38,
        0x30, 0x8E, 0x70, 0xE7, 0x1D, 0x87, 0x39, 0xBC, 0xC6, 0x71, 0xE3, 0x11,
        0xC7, 0x1C, 0xF3, 0x01, 0xCE, 0x64, 0x31, 0xCE, 0x60, 0xE2, 0x31, 0xC6,
        0x18, 0xE7, 0x87, 0x00, 0x80, 0x0C, 0x63, 0x1C, 0xE7, 0x79, 0xC3, 0xE0,
        0xC0, 0x00, 0x0C, 0x70, 0xC3, 0xE7, 0x8E, 0x60, 0x0E, 0x78, 0x38, 0x70,
        0xE1, 0x30, 0xC1, 0xC3, 0x39, 0x9C, 0x3E, 0x78, 0xF1, 0xCE, 0xC7, 0x1C,
        0x1C, 0x0F, 0x1C, 0x7E, 0x78, 0xD1, 0xC7, 0x07, 0xCE, 0x3E, 0x39, 0x99,
        0xF8, 0xE3, 0xB1, 0xCD, 0x8E, 0x39, 0xCE, 0x66, 0x18, 0xF8, 0xC7, 0x38,
        0xCE, 0x18, 0xE3, 0x8C, 0xE1, 0xC3, 0x81, 0xC7, 0x18, 0xC3, 0x38, 0x1C,
        0x71, 0xC0, 0xF0, 0xC7, 0x38, 0xCE, 0x38, 0x70, 0x0C, 0xC6, 0x33, 0x88,
        0x0E, 0x70, 0x30, 0xC7, 0x67, 0x18, 0xC3, 0x39, 0x9C, 0xE3, 0x1C, 0xCE,
        0x71, 0x88, 0x0C, 0x3C, 0x61, 0xF1, 0x8F, 0xFF, 0x8E, 0x70, 0x3C, 0x70,
        0xC1, 0x81, 0x0E, 0x23, 0x1C, 0x4E, 0x70, 0x61, 0x81, 0x86, 0x03, 0x00,
        0x00, 0x38, 0x03, 0xC3, 0x87, 0xC7, 0x87, 0x1E, 0x0E, 0x7C, 0xF1, 0xF1,
        0x8E, 0x73, 0x9F, 0xCF, 0x1E, 0x3B, 0x9C, 0xF0, 0xC1, 0xF3, 0x1C, 0xE3,
        0x1C, 0xCC, 0x78, 0x70, 0xF1, 0x8E, 0x0C, 0x87, 0x30, 0x18, 0xE1, 0x88,
        0x7C, 0x33, 0xCE, 0x38, 0x38, 0x61, 0x83, 0x0E, 0x01, 0x98, 0x00, 0xCE,
        0x31, 0xCC, 0x8F, 0x07, 0x0F, 0x38, 0x37, 0x1C, 0xE1, 0xC3, 0x78, 0xF1,
        0x8C, 0x38, 0x70, 0xC1, 0xC3, 0x9C, 0x8E, 0x4D, 0x1C, 0x60, 0x38, 0xCE,
        0x72, 0x1C, 0x70, 0x01, 0xC7, 0xC3, 0x03, 0xC7, 0x0F, 0x51, 0xF1, 0x98,
        0xE3, 0xE0, 0xDC, 0x71, 0x8E, 0x70, 0x38, 0xC6, 0x30, 0xC7, 0x0C, 0x03,
        0x82, 0x00, 0xC7, 0x1C, 0x39, 0x9F, 0x82, 0x01, 0x06, 0x70, 0x38, 0x00,
        0x00, 0x01, 0xB9, 0xC7, 0xFC, 0xF3, 0x9E, 0x67, 0xFF, 0xFF, 0xBD, 0xFC,
        0xE7, 0xC7, 0xCF, 0x79, 0x9E, 0x33, 0x38, 0xC4, 0x63, 0x0C, 0xE3, 0x1C,
        0xC6, 0x7D, 0xE6, 0x0F, 0x70, 0x78, 0xE6, 0x6F, 0x38, 0xE3, 0x00, 0x02,
        0x08, 0x73, 0x9C, 0xE7, 0xF3, 0x7F, 0x8F, 0x1C, 0x61, 0x80, 0xE1, 0x08,
        0xE3, 0x1E, 0xFC, 0x33, 0x8E, 0x7E, 0x70, 0xE7, 0x10, 0x8C, 0x00, 0x0E,
        0x3C, 0x62, 0x00, 0xC7, 0x01, 0xC6, 0x38, 0xCC, 0x71, 0x80, 0xF1, 0xC6,
        0x10, 0x66, 0x38, 0xC7, 0x3C, 0xC6, 0x73, 0x18, 0x3C, 0x30, 0xF8, 0x63,
        0x91, 0x30, 0xC7, 0x39, 0x8C, 0x67, 0x39, 0xCF, 0xE3, 0x99, 0x8E, 0x71,
        0xC8, 0xE3, 0x18, 0xC3, 0x03, 0x00, 0x0E, 0x70, 0x02, 0x1C, 0x1C, 0xC3,
        0xC3, 0x1C, 0x78, 0x71, 0xC1, 0xE7, 0x39, 0xC7, 0xF0, 0x78, 0x7C, 0x79,
        0x19, 0xC6, 0x39, 0xC7, 0x1E, 0x23, 0x06, 0x33, 0x38, 0xF1, 0xCF, 0x71,
        0x8C, 0x71, 0x38, 0x3C, 0xE7, 0x38, 0x07, 0x31, 0x84, 0x03, 0x8C, 0x18,
        0x60, 0xE1, 0xC6, 0x7F, 0x87, 0x39, 0x8E, 0x06, 0x18, 0xE3, 0x81, 0xC7,
        0x78, 0xF4, 0x78, 0xF0, 0xC8, 0x87, 0x1C, 0x0E, 0x38, 0x1C, 0x71, 0x18,
        0xC3, 0x08, 0x03, 0x0F, 0x3F, 0xF9, 0xC7, 0x39, 0xC6, 0x73, 0x9C, 0xE4,
        0x38, 0x7E, 0x38, 0x8E, 0x63, 0x1E, 0x06, 0x71, 0x86, 0xE3, 0x80, 0xC3,
        0x11, 0x8C, 0x00, 0x0E, 0x07, 0x04, 0x06, 0x30, 0xC1, 0xE7, 0x3D, 0xE1,
        0xC6, 0x77, 0x38, 0x38, 0x78, 0x30, 0xDC, 0x61, 0xCE, 0x33, 0x1C, 0xE2,
        0x38, 0xEC, 0xE3, 0x1C, 0xE3, 0x30, 0xE0, 0xC3, 0x01, 0xC7, 0x38, 0x39,
        0x99, 0x39, 0x87, 0xC1, 0xC7, 0x18, 0xC6, 0x63, 0x9C, 0xE7, 0x3E, 0x38,
        0x71, 0xCE, 0x23, 0x0F, 0x1E, 0x79, 0x01, 0x99, 0xC1, 0xC7, 0x83, 0x8C,
        0x78, 0xF0, 0xE0, 0x38, 0x78, 0x0E, 0x0F, 0x8E, 0x38, 0xC7, 0xC7, 0x0E,
        0xE6, 0x33, 0x8E, 0xC0, 0xE3, 0x1C, 0x70, 0x0E, 0x39, 0x8F, 0x0E, 0x1C,
        0xC3, 0xE7, 0x81, 0xE3, 0x82, 0x30, 0x20, 0x7C, 0x78, 0x71, 0x63, 0x87,
        0x0E, 0x63, 0x1E, 0x3C, 0x71, 0xF8, 0xE7, 0x38, 0xC2, 0xE3, 0x19, 0x8E,
        0x71, 0x8C, 0xC7, 0x39, 0x3F, 0xC7, 0x39, 0x8E, 0x30, 0xCE, 0x70
    ),
    "ZH": (
        0x00, 0xF8, 0x3F, 0xE1, 0xFF, 0xF7, 0x8F, 0xFF, 0xC1, 0xFC, 0x0F, 0x01,
        0xE3, 0xC0, 0xFF, 0x01, 0xC1, 0xE6, 0x0F, 0xF0, 0x03, 0xF8, 0x3F, 0x00,
        0x3F, 0x00, 0xFF, 0x80, 0x7F, 0xF0, 0x3F, 0xC0, 0x7F, 0x81, 0xFF, 0x06,
        0x1F, 0x00, 0x7C, 0x00, 0x0E, 0x01, 0xE0, 0x03, 0xC7, 0xF8, 0x3F, 0xFE,
        0x3F, 0xFC, 0x3F, 0x07, 0xDE, 0x1E, 0x06, 0x3C, 0x07, 0x83, 0x80, 0xFC,
        0x00, 0xFF, 0x87, 0x1E, 0x3C, 0x7C, 0x7C, 0x3F, 0x07, 0x80, 0x7C, 0x38,
        0x3C, 0x20, 0xF8, 0x3F, 0x00, 0x18, 0x07, 0xC0, 0x01, 0xC0, 0xF0, 0x03,
        0xE0, 0x07, 0xE0, 0x3F, 0xC1, 0xFF, 0xE0, 0x7F, 0xE0, 0xFC, 0x7C, 0x1C,
        0xC0, 0x1F, 0xC0, 0x3F, 0x80, 0x0C, 0x3E, 0x1E, 0x0F, 0xC0, 0xFC, 0x3F,
        0xC0, 0x1E, 0x38, 0x03, 0xF0, 0x3F, 0xF0, 0x78, 0xF8, 0xE0, 0xFE, 0x07,
        0x80, 0xF8, 0x00, 0x3C, 0x0F, 0x00, 0x07, 0x80, 0x1F, 0x88, 0x1F, 0xFE,
        0x7F, 0xFC, 0x7F, 0xF0, 0x1F, 0x87, 0x03, 0xE0, 0xC0, 0xF0, 0xC3, 0xC0,
        0x83, 0xE0, 0xFE, 0x07, 0xC7, 0x0F, 0xC0, 0x7C, 0x7C, 0x38, 0xFF, 0x03,
        0xFE, 0x07, 0x80, 0x7C, 0x1F, 0x00, 0x1C, 0x00, 0xF0, 0x03, 0xC0, 0x00,
        0x00, 0x40, 0x01, 0xFC, 0x0F, 0xC1, 0xFF, 0x0F, 0xFF, 0x07, 0xFE, 0x03,
        0xF8, 0x0F, 0xF8, 0x03, 0xF0, 0x00, 0xFC, 0x07, 0x1E, 0x01, 0xE3, 0xC0,
        0xFF, 0x00, 0xFF, 0xC0, 0xF8, 0x3C, 0x7C, 0x80, 0x1F, 0x07, 0x80, 0xF8,
        0xF0, 0x03, 0xE0, 0x00, 0xF0, 0x03, 0x00, 0x07, 0x00, 0x0F, 0xF0, 0x7C,
        0x7F, 0xF3, 0xFF, 0x1F, 0xE0, 0x3F, 0x87, 0x80, 0x3F, 0xC0, 0x0F, 0xC0,
        0x71, 0xF8, 0x18, 0xF0, 0x1F, 0xE0, 0xFC, 0x70, 0xF0, 0x7C, 0x1C, 0xE7,
        0x87, 0x1F, 0x07, 0x8F, 0x81, 0xFF, 0xE0, 0x78, 0x01, 0x80, 0x20, 0x00,
        0x00, 0x03, 0xE0, 0x07, 0xFE, 0x3C, 0x0F, 0xFC, 0x7E, 0x3F, 0xE0, 0x1F,
        0x80, 0xF8, 0x03, 0xF8, 0x01, 0xFF, 0x80, 0x7F, 0x07, 0x83, 0xF0, 0xF8,
        0xFE, 0x1F, 0x00, 0x39, 0xF0, 0x0F, 0x80, 0x3F, 0x03, 0xE3, 0xC0, 0x7F,
        0xE0, 0x0F, 0x80, 0xF0, 0x00, 0x86, 0x00, 0x00, 0x78, 0x00, 0xFC, 0x07,
        0xF1, 0xFF, 0xC0, 0xFF, 0x0F, 0xFC, 0x3F, 0xC0, 0xF3, 0x83, 0xC0, 0xE1,
        0xC0, 0x03, 0xE1, 0xC1, 0x8F, 0x83, 0xE0, 0xFC, 0x1F, 0xE3, 0x07, 0x87,
        0x1E, 0x3E, 0x0C, 0x3E, 0x07, 0xE0, 0xE1, 0xC0, 0x0F, 0xC0, 0x3F, 0x00,
        0x00, 0x00, 0xC0, 0x00, 0x03, 0xE0, 0x07, 0xFF, 0xE3, 0xFF, 0x0F, 0xCF,
        0xC1, 0xF8, 0x07, 0xE0, 0x7F, 0xC0, 0xE3, 0xC0, 0x7F, 0x0C, 0x3F, 0x00,
        0xFC, 0x0F, 0x8E, 0x1F, 0x3C, 0xC1, 0xFF, 0x03, 0xE7, 0xC0, 0xFF, 0x00,
        0xFF, 0x00, 0x3F, 0x80, 0x3F, 0x80, 0x3F, 0x00, 0xFF, 0x01, 0xFF, 0x01,
        0xFF, 0xFE, 0x1F, 0xFE, 0x70, 0xF8, 0x3F, 0x81, 0xF8, 0x70, 0x03, 0xFE,
        0x07, 0xF0, 0x00, 0x7C, 0x38, 0x78, 0xF8, 0x3F, 0xE0, 0xF0, 0xF9, 0xC0,
        0xFE, 0x07, 0xFF, 0x03, 0xF0, 0x1F, 0x83, 0x00, 0xFC, 0x00, 0xFE, 0x01,
        0xC0, 0x07, 0xC0, 0x3F, 0x00, 0xFC, 0x3F, 0xE3, 0xFF, 0xFB, 0xF0, 0x7F,
        0xC0, 0x0F, 0xE0, 0x00, 0x01, 0xFC, 0x07, 0xFF, 0xC0, 0x0F, 0xFC, 0x03,
        0xF8, 0x0F, 0xF0, 0x07, 0xE0, 0xF7, 0xC1, 0xE1, 0xFF, 0x80, 0xFE, 0x01,
        0xF0, 0x1F, 0xC0, 0x00, 0x00, 0x00, 0x3F, 0x80, 0x1F, 0xC0, 0x3F, 0x07,
        0xFF, 0x1F, 0xBF, 0xC0, 0x3F, 0x8F, 0xE0, 0x07, 0xF0, 0x60, 0x7F, 0x00,
        0xFF, 0xE0, 0x1F, 0x0F, 0x07, 0x0F, 0x9C, 0x3E, 0xF0, 0x7E, 0x03, 0xC3,
        0xE0, 0x86, 0xFC, 0x07, 0xE0, 0xF8, 0x00, 0x7E, 0x00, 0x38, 0x00, 0x00,
        0xC0, 0x00, 0x00, 0xFF, 0x01, 0xFF, 0xFE, 0x0F, 0xFF, 0x03, 0xFE, 0xF0,
        0x7C, 0xFC, 0x1E, 0x00, 0x7E, 0x00, 0xFE, 0x00, 0x3F, 0x00, 0xF8, 0x7E,
        0x3E, 0xF0, 0xF0, 0x70, 0xF3, 0x83, 0xC0, 0xF8, 0x78, 0x03, 0xF0, 0xE0,
        0x07, 0xF0, 0x07, 0xF0, 0x00, 0xE0, 0x00, 0x00, 0x01, 0xFF, 0x80, 0xFF,
        0x81, 0xFF, 0xF0, 0xFF, 0xE7, 0xE0, 0x3F, 0xF0, 0x03, 0x8F, 0x01, 0xC1,
        0xEF, 0x00, 0x7F, 0xF0, 0x3F, 0xC1, 0xFF, 0xC0, 0xFF, 0x00, 0x3F
    )
}

################################################################################
#                                                                              #
# text-to-phonemes translation                                                 #
#                                                                              #
################################################################################

def ensure_text_alphanumeric(
    text            = None,
    characters_pass =\
        " 0123456789abcdefghijklmnopqrstuvwxyABCDEFGHIJKLMNOPQRSTUVWXYZ"
    ):
    return "".join(filter(set(characters_pass).__contains__, text)).strip("\n")

def make_regex_fragment_from_rules_English_to_phonemes_special_symbols(
    rule_pattern = None
    ):
    regex = r""
    for character in rule_pattern:
        regex += rules_English_to_phonemes_special_symbols.get(
            character, character
        )
    return regex

def make_rule_regex(
    rule_text = None
    ):
    character_string, left_context, right_context, phoneme = rule_text.split("/")
    rule = r""
    if left_context:
        # Use a non-capturing group to match the left context.
        rule +=\
            r"(?:" +\
            make_regex_fragment_from_rules_English_to_phonemes_special_symbols(
                rule_pattern = left_context
            ) +\
            ")"
    # Create a capturing group for the character string.
    rule += r"(?P<found>" + character_string + ")" 
    if right_context:
        # Add a lookahead pattern.
        rule +=\
            r"(?=" +\
            make_regex_fragment_from_rules_English_to_phonemes_special_symbols(
                rule_pattern = right_context
            ) +\
            ")"
    # Return a tuple containing the regex created from the rule, a lower-case
    # representation of the phonemes between dashes and the original rule.
    return rule, "-{phoneme}-".format(phoneme = phoneme.lower()), rule_text

def match_and_replace(
    text    = None,
    rule    = None,
    phoneme = None
    ):
    """
    Replace found text from a single rule.
    """
    # Find all rule matches.
    matches = [(match.start(), match.end()) for \
        match in re.finditer(rule, text)]
    # Start from behind, so replace in-place.
    matches.reverse()
    # Convert to characters because strings are immutable.
    characters = list(text)
    for start, end in matches:
        characters[start:end] = phoneme
    # Convert back to string.
    return "".join(characters)

rules_English_to_phonemes_regex = [
    make_rule_regex(rule_text = rule) for rule in rules_English_to_phonemes
]

def text_to_phonemes(
    text                = None,
    explain             = False,
    phonemes_dictionary = phonemes_dictionary
    ):
    """
    Extract phonemes from words.
    """
    if explain:
        print("\ntranslation printout:")
        print("text: {text}".format(text = text))

    text = ensure_text_alphanumeric(text = text)

    # Add space around words for compatibility with rules containing spaces.
    result = " {text} ".format(text = text.upper())
    step = 0

    # Iterate over all the interesting tuples.
    for rule, phoneme, rule_text in rules_English_to_phonemes_regex:
        # For each rule, 'tmp' is the string in which all matches for 'rule'
        # have been replaced by 'phoneme'.
        tmp = match_and_replace(
            text    = result,
            rule    = rule,
            phoneme = phoneme
        )
        if explain and tmp != result:
            step += 1
            message =\
                "step {step}: {result} ---> {tmp} [rule: {rule_text} ({rule})]"
            print(message.format(
                step      = step,
                result    = result,
                tmp       = tmp,
                rule_text = rule_text,
                rule      = rule
            ))

        result = tmp

    # remove artifacts
    result_artifacts_removed = result.replace(
            "- -",
            " "
        ).replace(
            "--",
            "-"
        ).strip(
            " "
        ).strip(
            "-"
        ).replace(
            "--",
            "-"
        )

    if explain:
        print("result: {result}\n".format(result = result_artifacts_removed))
    # make uppercase
    result_uppercase = result_artifacts_removed.upper()
    # remove junk
    acceptable_phonemes = [
        key for key, value in phonemes_dictionary.iteritems()
    ]
    result_cleaning = []
    for word in result_uppercase.split(" "):
        tmp_word = []
        for word_phoneme in word.split("-"):
            if word_phoneme in acceptable_phonemes:
                tmp_word.append(word_phoneme)
            if word_phoneme == "I":
                tmp_word.append("AH-EE")
            if word_phoneme == "EEH":
                tmp_word.append("EH")
        result_cleaning.append("-".join(tmp_word))
   
    result = " ".join(result_cleaning).strip()
    return result

################################################################################
#                                                                              #
# amplitude data and sound output                                              #
#                                                                              #
################################################################################

def amplitude_data_to_binary_data(
    values,
    minimum = -1,
    maximum = 1
    ):
    values = datavision.normalize_to_range(
        values,
        minimum = -1,
        maximum = 1
    )
    values_binary = ""
    for value in values:
        values_binary = values_binary + chr(int(value * 127 + 128))
    return values_binary

def play_values(
    values  = None,
    bitrate = 15300
    ):
    binary_data = amplitude_data_to_binary_data(values)
    with propyte.silence():
        stream = pyaudio.PyAudio().open(
            format   = pyaudio.PyAudio().get_format_from_width(1),
            channels = 1,
            rate     = bitrate,
            output   = True
        )
    stream.write(binary_data)
    stream.stop_stream()
    stream.close()
    pyaudio.PyAudio().terminate()

def save_values_to_wave_file(
    values             = None,
    filename           = None,
    maximum_amplitude  = 65535, # maximum value of unsigned short 16 bit number
    sample_rate        = 44100, # Hz
    number_of_channels = 1,
    sample_width       = 2      # bytes per frame
    ):
    values = datavision.normalize_to_range(
        values,
        minimum = -(maximum_amplitude / 2),
        maximum = maximum_amplitude / 2
    )
    file_output = wave.open(filename, "w")
    file_output.setnchannels(number_of_channels)
    file_output.setsampwidth(sample_width)
    file_output.setframerate(sample_rate)
    for value in values:
        write_data = struct.pack("<h", value)
        file_output.writeframesraw(write_data)
    file_output.writeframes("")
    file_output.close()

def phoneme_values(
    phoneme    = None,
    length     = 575,
    dimensions = 1
    ):
    data = [int(str(i), 10) for i in phonemes_dictionary[phoneme]]
    if length == 575:
        if dimensions == 1:
            return data
        elif dimensions == 2:
            return (range(0, len(data)), data)
    else:
        if dimensions == 1:
            data = shijian.change_list_resolution(
                values = data,
                length = length
            )
            return data
        elif dimensions == 2:
            data_x, data_y = shijian.change_list_resolution(
                values     = data,
                length     = length,
                dimensions = 2
            )
            return (data_x, data_y)

def phonemes_values(
    phonemes_string     = None,
    phonemes_dictionary = phonemes_dictionary
    ):
    acceptable_phonemes =\
        [key for key, value in phonemes_dictionary.iteritems()]
    values = []
    for phoneme in phonemes_string.split("-"):
        if phoneme in acceptable_phonemes:
            values.extend(phoneme_values(phoneme = phoneme, length = 2000))
    return values

def phonemes_words_values(
    phonemes_words                        = None,
    change_waveform_to_rectangle_waveform = True
    ):
    """
    This function converts sentences in phoneme form to amplitude values.
    """
    values = []
    for phonemes_string in phonemes_words.split(" "):
        values.extend(
            phonemes_values(
                phonemes_string = phonemes_string
            )
        )
        values.extend(
            phoneme_values(
                phoneme = "space",
                length  = 2000
            )
        )
    values.extend(
        phoneme_values(
            phoneme = "space",
            length  = 2000
        )
    )
    if change_waveform_to_rectangle_waveform is True:
        values = shijian.change_waveform_to_rectangle_waveform(
            values = values
        )
    return values

def speak_phoneme(
    phoneme = None
    ):
    for value in phoneme_values(
        phoneme = phoneme,
        length  = 2000
    ):
        print(value)

def speak_phonemes(
    phonemes_string = None
    ):
    for phoneme in phonemes_string.split("-"):
        speak_phoneme(phoneme = phoneme)

def speak_phonemes_words(
    phonemes_words = None
    ):
    for phonemes_string in phonemes_words.split(" "):
        speak_phonemes(phonemes_string)
        speak_phoneme(
            phoneme = "space",
            length  = 2000
        )

def say(
    text              = None,
    phonemes          = None,
    save_to_file      = False,
    filename_output   = None,
    explain           = False,
    split_sentences   = True,
    translate_numbers = True
    ):
    text = ensure_text_alphanumeric(text = text)
    if text is not None:
        if translate_numbers is True:
            if explain:
                print("\nreplace numbers in text with English text:")
                print("text with numbers:\n{text}".format(text = text))
            text = shijian.replace_numbers_in_text_with_English_text(
                text = text
            )
            if explain:
                print("text with numbers replaced:\n{text}".format(text = text))
        if save_to_file is not True:
            if split_sentences is True:
                # Split text into sentences.
                text = text.split(".")
                for sentence in text:
                    _phonemes = text_to_phonemes(
                        text    = sentence,
                        explain = explain
                    )
                    _data = phonemes_words_values(
                        phonemes_words = _phonemes
                    )
                    play_values(
                        values = _data
                    )
            else:
                _phonemes = text_to_phonemes(
                    text    = text,
                    explain = explain
                )
                _data = phonemes_words_values(
                    phonemes_words = _phonemes
                )
                play_values(
                    values = _data
                )
        else:
            _phonemes = text_to_phonemes(
                text    = text,
                explain = explain
            )
            _data = phonemes_words_values(
                phonemes_words = _phonemes
            )
            save_values_to_wave_file(
                values      = _data,
                filename    = filename_output,
                sample_rate = 15300
            )
    elif text is None and phonemes is not None:
        if save_to_file is not True:
            _phonemes = phonemes
            _data = phonemes_words_values(
                phonemes_words = _phonemes
            )
            play_values(
                values = _data
            )
        else:
            _phonemes = phonemes
            _data = phonemes_words_values(
                phonemes_words = _phonemes
            )
            save_values_to_wave_file(
                values             = _data,
                filename           = filename_output,
                sample_rate        = 15300
            )

################################################################################
#                                                                              #
# analysis                                                                     #
#                                                                              #
################################################################################

def analysis(
    visual = True,
    sound  = True
    ):
    if visual is True:
        print("\nanalysis visual")
        print("\nsave histograms phonemes\n")
        save_histograms_phonemes(
            phonemes_dictionary = phonemes_dictionary
        )
        print("\nsave multigraph comparisons of phonemes resolutions\n")
        save_multigraph_comparison_resolutions_phonemes(
            phonemes_dictionary = phonemes_dictionary
        )
        print(
            "\nsave graph comparisons of phonemes data and "
            "FFT synthesized phonemes data\n"
        )
        save_graph_phoneme_data_versus_FFT_synthesized_data()
    if sound is True:
        print("\nanalysis sound")
        number_of_words = 50
        print("\nspeak {number} most frequent Brown Corpus words\n".format(
            number = number_of_words
        ))
        speak_most_frequent_Brown_Corpus_words(
            number = number_of_words
        )

def save_graph_phoneme(
    phoneme      = None,
    title        = None,
    title_axis_x = "time",
    title_axis_y = "amplitude",
    filename     = None,
    directory    = "images",
    overwrite    = True,
    color        = "black",
    LaTeX        = False,
    marker_size  = 1,
    aspect       = 0.3
    ):
    if title is None:
        title = "amplitude: phoneme {phoneme}".format(
            phoneme = phoneme
        )
    if filename is None:
        filename = "amplitude_phoneme_{phoneme}.png".format(
            phoneme = phoneme
        )
    datavision.save_graph_matplotlib(
        values       = phoneme_values(
                       phoneme = phoneme,
                       length  = 2000
                       ),
        title        = title,
        title_axis_x = title_axis_x,
        title_axis_y = title_axis_y,
        filename     = filename,
        directory    = directory,
        overwrite    = overwrite,
        color        = color,
        LaTeX        = LaTeX,
        markers      = False,
        marker_size  = marker_size,
        aspect       = aspect,
        line         = True,
        line_style   = "k-",
        font_size    = 4
    )

def save_graph_phoneme_data_versus_FFT_synthesized_data(
    sample_rate = 20000
    ):
    phonemes_frequency_contributions =\
        greatest_frequency_contributions_phonemes(
            save_plots = False
        )
    for key, value in phonemes_frequency_contributions.iteritems():
        message = "save graph comparison phoneme {phoneme} versus " +\
                  "FFT synthesized phoneme data"
        print(message.format(
            phoneme = key
        ))
        values_amplitude, values_time =\
            datavision.generate_composite_sine_values(
                frequencies = phonemes_frequency_contributions[key],
                sample_rate = sample_rate,
                time        = 1
            )
        data = phoneme_values(
            phoneme = key,
            length  = sample_rate
        )
        datavision.save_multigraph_matplotlib(
            variables        = [values_amplitude.tolist(), data],
            variables_names  = ["synthetic", "data"],
            title            = "synthetic_versus_data_" + key,
            label_x          = "time",
            label_y          = "amplitude",
            filename         = "synthetic_versus_data_" + key + ".png",
            directory        = "images",
            overwrite        = True,
            LaTeX            = False,
            marker_size      = 0.5,
            palette_name     = "palette1"
        )

def save_multigraph_comparison_resolution_phoneme(
    phoneme  = None,
    length_1 = 575,
    length_2 = 2000
    ):
    datavision.save_multigraph_2D_matplotlib(
        variables_x      = [
                           phoneme_values(
                               phoneme    = phoneme,
                               length     = length_1,
                               dimensions = 2
                           )[0],
                           phoneme_values(
                               phoneme    = phoneme,
                               length     = length_2,
                               dimensions = 2
                           )[0]
                           ],
        variables_y      = [
                           phoneme_values(
                               phoneme    = phoneme,
                               length     = length_1,
                               dimensions = 2
                           )[1],
                           phoneme_values(
                               phoneme    = phoneme,
                               length     = length_2,
                               dimensions = 2
                           )[1]
                           ],
        variables_names  = [
                           "575",
                           "2000"
                           ],
        title            = "resolutions phoneme {phoneme}".format(
                               phoneme = phoneme
                           ),
        label_x          = "time",
        label_y          = "amplitude",
        filename         = "resolutions_phoneme_{phoneme}.png".format(
                               phoneme = phoneme
                           ),
        directory        = "images",
        markers          = False,
        marker_size      = 2,
        line             = True,
        line_style       = "-",
        aspect           = 0.3,
        palette_name     = "palette1"
    )

def save_multigraph_comparison_resolutions_phonemes(
    phonemes_dictionary = phonemes_dictionary,
    length_1            = 575,
    length_2            = 2000,
    ):
    for key, value in phonemes_dictionary.iteritems():
        print("save phoneme {phoneme} resolutions comparison".format(
            phoneme = key
        ))
        save_multigraph_comparison_resolution_phoneme(
            phoneme  = key,
            length_1 = length_1,
            length_2 = length_2
        )

def save_histogram_phoneme(
    phoneme   = None,
    directory = "images"
    ):
    datavision.save_histogram_matplotlib(
        phoneme_values(
                       phoneme = phoneme,
                       length = 2000
                       ),
        filename     = "histogram_phoneme_{phoneme}.png".format(
                           phoneme = phoneme
                       ),
        directory    = directory,
        title        = "histogram: phoneme {phoneme}".format(
                           phoneme = phoneme
                       ),
        label_x      = "value",
        label_y      = "frequency",
        color_fill   = "#000000"
    )

def save_histograms_phonemes(
    phonemes_dictionary = phonemes_dictionary
    ):
    for key, value in phonemes_dictionary.iteritems():
        print("save histogram phoneme {phoneme}".format(
            phoneme = key
        ))
        save_histogram_phoneme(key)

def greatest_frequency_contributions_phonemes(
    phonemes_dictionary     = phonemes_dictionary,
    print_table             = True,
    save_plots              = True,
    number_of_contributions = 500,
    time                    = 1,
    sample_rate             = 15300
    ):
    acceptable_phonemes =\
        [key for key, value in phonemes_dictionary.iteritems()]
    phonemes_frequency_contributions = {}
    table_contents = [[
        "phoneme",
        "{number} greatest frequency contributions".format(
            number = number_of_contributions
        )
    ]]
    for phoneme in acceptable_phonemes:
        values_amplitude = phoneme_values(
            phoneme = phoneme,
            length  = 2000
        )
        frequencies = datavision.greatest_frequency_contributions_FFT(
            values_amplitude        = values_amplitude,
            time                    = time,
            sample_rate             = sample_rate,
            number_of_contributions = number_of_contributions
        )
        phonemes_frequency_contributions[phoneme] = frequencies
        table_contents.append([phoneme, str(frequencies)])
        if save_plots is True:
            filename = "FFT_phoneme_{phoneme}.png".format(phoneme = phoneme)
            print("save file {filename}".format(filename = filename))
            datavision.save_FFT_plot_matplotlib(
                values_amplitude = values_amplitude,
                time             = time,
                sample_rate      = sample_rate,
                filename         = filename
            )
    if print_table is True:
        print(
            pyprel.Table(
                contents = table_contents
            )
        )
    return phonemes_frequency_contributions

def most_frequent_Brown_Corpus_words():
    import nltk
    import nltk.corpus
    words = []
    for word in nltk.corpus.brown.words():
        if word not in [
            ",",
            ".",
            "``",
            "''",
            ";",
            "?",
            "--",
            ")",
            "(",
            ":",
            "!"
        ]:
            words.append(word.lower())
    frequencies_words = nltk.FreqDist(words).most_common()
    words_most_frequent = [word[0] for word in frequencies_words]
    return words_most_frequent

def speak_most_frequent_Brown_Corpus_words(
    number = 4000
    ):
    _text = " ".join(most_frequent_Brown_Corpus_words()[:number])
    print(_text)
    _phonemes = text_to_phonemes(text = _text)
    _data = phonemes_words_values(
        phonemes_words = _phonemes
    )
    play_values(
        values = _data
    )

################################################################################
#                                                                              #
# diagnostics                                                                  #
#                                                                              #
################################################################################

# upcoming PortAudio checks

if __name__ == "__main__":
    options = docopt.docopt(__doc__)
    if options["--version"]:
        print(version)
        exit()
    main(options)
